package de.uniulm.mathematik.typo.fonts.afm;

import java.util.HashMap;

/**
 * Adobe type-1 fonts have a limited encoding that supports just up to 256 code points.
 * Glyphs that are not mapped can be accessed through glyph names. This class helps to
 * map Unicode code points to glyph names and vice versa.
 */
public class AdobeGlyphList {
   private HashMap<Integer, String> byUnicode;
   private HashMap<String, Integer> byName;

   /**
    * Construct an empty Adobe glyph list.
    */
   public AdobeGlyphList() {
      byUnicode = new HashMap<Integer, String>();
      byName = new HashMap<String, Integer>();
   }

   /**
    * Add a mapping to the list.
    * @param code Unicode codepoint.
    * @param name Adobe glyph name.
    */
   public void add(int code, String name) {
      byUnicode.put(new Integer(code), name);
      byName.put(name, new Integer(code));
   }

   /**
    * Retrieve the Adobe glyph name for a codepoint.
    * @param code Unicode codepoint.
    * @return Adobe glyph name or null.
    */
   public String getName(int code) {
      return byUnicode.get(new Integer(code));
   }

   /**
    * Retrieve the Unicode codepoint for a glyph name.
    * @param name Adobe glyph name.
    * @return Unicode codepoint or -1, if the glyph name is not known.
    */
   public int getUnicode(String name) {
      Integer i = byName.get(name);
      if (i == null) {
	 return -1;
      } else {
	 return i.intValue();
      }
   }
}
