package de.uniulm.mathematik.typo.hyphen;

/**
 * General interface for hyphenators.
 */
public interface Hyphenator {

   /**
    * Return the minimal length of a word prefix that can be
    * cut off from a word through hyphenation.
    */
   public int getLeftMin();

   /**
    * Return the minimal length of a word suffix that
    * can be cut off from a word through hyphenation.
    */
   public int getRightMin();

   /**
    * Return possible hyphenation positions for a given string.
    * @param s Sequence of letters that constitute a to be hyphenated
    *          word.
    * @return  Integer array with hyphenation positions in ascending
    *          order. If <I>s</I> is of length <I>n</I> then
    *          the hyphenation positions range from <I>lefthyphenmin</I>
    *          to <I>n-righthyphenmin</I>.
    */
   public int[] hyphenate(String s);
}
