package de.uniulm.mathematik.typo.hyphen;

/**
 * A weighted hyphenation point is a tuple consisting of a
 * non-negative hyphenation position (taken relative to the
 * beginning of the word) and an associated weight.
 * The larger the weight the more favorable is a hyphenation
 * at that point. This class represents a single hyphenation
 * point.
 */
public class SingleWeightedHyphenationPoint
      implements WeightedHyphenationPoint {
   private int position;
   private int weight;

   /**
    * Construct a single weighted hyphenation point.
    * @param position absolute position within a word.
    * @param weight associated weight.
    */
   SingleWeightedHyphenationPoint(int position, int weight) {
      this.position = position;
      this.weight = weight;
   }

   /**
    * Returns the absolute position of this hyphenation point.
    */
   public int getPosition() {
      return position;
   }
   
   /**
    * Returns the weight position of this hyphenation point.
    */
   public int getWeight() {
      return weight;
   }
}
