package de.uniulm.mathematik.typo.items;

import java.util.*;

/**
 * Vertical stacks work like vertical boxes but they do not
 * take a baselineskip parameter in consideration. They have
 * just a height, their depth is 0.
 */

public class VerticalStack extends Box {
   private LinkedList<Item> items;
   private int width;
   private int height;

   /**
    * Construct a vertical stack.
    */
   public VerticalStack() {
      items = new LinkedList<Item>();
      width = 0;
      height = 0;
   }

   /**
    * Add this item to the vertical stack, i.e. put it below the
    * last item.
    * @param item item to be added.
    */
   public void add(Item item) {
      items.addLast(item);
      if (item.getWidth() > width) {
	 width = item.getWidth();
      }
      height += item.getHeight() + item.getDepth();
   }

   /**
    * Return the maximal width seen so far of all individual
    * items added to this vertical stack.
    */
   public int getWidth() {
      return width;
   }

   /**
    * Return the overall height of all boxes stacked so far.
    */
   public int getHeight() {
      return height;
   }

   /**
    * Return always 0.
    */
   public int getDepth() {
      return 0;
   }

   /**
    * Emit PostScript text that represents the contents of
    * this vertical stack.
    */
   public StringBuffer genPostScript(PostScriptContext context) {
      StringBuffer result = new StringBuffer("");
      int verticalpos = 0;
      if (items.size() > 0) {
	 int i = 0;
	 for (Item item:items) {
	    verticalpos += item.getHeight() + item.getDepth();
	    result.append(context.gsave());
	    if (i < items.size()-1) {
	       result.append("0 ");
	       result.append((double) (height - verticalpos) / 1000);
	       result.append(" rmoveto\n");
	    }
	    result.append(item.genPostScript(context));
	    result.append(context.closeString());
	    result.append(context.grestore());
	    ++i;
	 }
	 result.append((double) width / 1000);
	 result.append(" 0 rmoveto\n");
      }
      return result;
   }
} // class VerticalStack
