package de.uniulm.mathematik.typo.fonts.afm;

/**
 * This initializer provides a static init method that allows to fill a
 * AdobeGlyphList with the mappings for all known Adobe glyph names.
 * The list has been derived from
 * https://github.com/adobe-type-tools/agl-aglfn
 */
public class AdobeGlyphListInitializer {
   /**
    * This static method fills a Adobe glyph list object with all known
    * mappings.
    * @param list Adobe glyph list object that is to be filled.
    */
   public static void init(AdobeGlyphList list) {
      list.add(0x0041, "A");
      list.add(0x00C6, "AE");
      list.add(0x01FC, "AEacute");
      list.add(0x01E2, "AEmacron");
      list.add(0xF7E6, "AEsmall");
      list.add(0x00C1, "Aacute");
      list.add(0xF7E1, "Aacutesmall");
      list.add(0x0102, "Abreve");
      list.add(0x1EAE, "Abreveacute");
      list.add(0x04D0, "Abrevecyrillic");
      list.add(0x1EB6, "Abrevedotbelow");
      list.add(0x1EB0, "Abrevegrave");
      list.add(0x1EB2, "Abrevehookabove");
      list.add(0x1EB4, "Abrevetilde");
      list.add(0x01CD, "Acaron");
      list.add(0x24B6, "Acircle");
      list.add(0x00C2, "Acircumflex");
      list.add(0x1EA4, "Acircumflexacute");
      list.add(0x1EAC, "Acircumflexdotbelow");
      list.add(0x1EA6, "Acircumflexgrave");
      list.add(0x1EA8, "Acircumflexhookabove");
      list.add(0xF7E2, "Acircumflexsmall");
      list.add(0x1EAA, "Acircumflextilde");
      list.add(0xF6C9, "Acute");
      list.add(0xF7B4, "Acutesmall");
      list.add(0x0410, "Acyrillic");
      list.add(0x0200, "Adblgrave");
      list.add(0x00C4, "Adieresis");
      list.add(0x04D2, "Adieresiscyrillic");
      list.add(0x01DE, "Adieresismacron");
      list.add(0xF7E4, "Adieresissmall");
      list.add(0x1EA0, "Adotbelow");
      list.add(0x01E0, "Adotmacron");
      list.add(0x00C0, "Agrave");
      list.add(0xF7E0, "Agravesmall");
      list.add(0x1EA2, "Ahookabove");
      list.add(0x04D4, "Aiecyrillic");
      list.add(0x0202, "Ainvertedbreve");
      list.add(0x0391, "Alpha");
      list.add(0x0386, "Alphatonos");
      list.add(0x0100, "Amacron");
      list.add(0xFF21, "Amonospace");
      list.add(0x0104, "Aogonek");
      list.add(0x00C5, "Aring");
      list.add(0x01FA, "Aringacute");
      list.add(0x1E00, "Aringbelow");
      list.add(0xF7E5, "Aringsmall");
      list.add(0xF761, "Asmall");
      list.add(0x00C3, "Atilde");
      list.add(0xF7E3, "Atildesmall");
      list.add(0x0531, "Aybarmenian");
      list.add(0x0042, "B");
      list.add(0x24B7, "Bcircle");
      list.add(0x1E02, "Bdotaccent");
      list.add(0x1E04, "Bdotbelow");
      list.add(0x0411, "Becyrillic");
      list.add(0x0532, "Benarmenian");
      list.add(0x0392, "Beta");
      list.add(0x0181, "Bhook");
      list.add(0x1E06, "Blinebelow");
      list.add(0xFF22, "Bmonospace");
      list.add(0xF6F4, "Brevesmall");
      list.add(0xF762, "Bsmall");
      list.add(0x0182, "Btopbar");
      list.add(0x0043, "C");
      list.add(0x053E, "Caarmenian");
      list.add(0x0106, "Cacute");
      list.add(0xF6CA, "Caron");
      list.add(0xF6F5, "Caronsmall");
      list.add(0x010C, "Ccaron");
      list.add(0x00C7, "Ccedilla");
      list.add(0x1E08, "Ccedillaacute");
      list.add(0xF7E7, "Ccedillasmall");
      list.add(0x24B8, "Ccircle");
      list.add(0x0108, "Ccircumflex");
      list.add(0x010A, "Cdot");
      list.add(0x010A, "Cdotaccent");
      list.add(0xF7B8, "Cedillasmall");
      list.add(0x0549, "Chaarmenian");
      list.add(0x04BC, "Cheabkhasiancyrillic");
      list.add(0x0427, "Checyrillic");
      list.add(0x04BE, "Chedescenderabkhasiancyrillic");
      list.add(0x04B6, "Chedescendercyrillic");
      list.add(0x04F4, "Chedieresiscyrillic");
      list.add(0x0543, "Cheharmenian");
      list.add(0x04CB, "Chekhakassiancyrillic");
      list.add(0x04B8, "Cheverticalstrokecyrillic");
      list.add(0x03A7, "Chi");
      list.add(0x0187, "Chook");
      list.add(0xF6F6, "Circumflexsmall");
      list.add(0xFF23, "Cmonospace");
      list.add(0x0551, "Coarmenian");
      list.add(0xF763, "Csmall");
      list.add(0x0044, "D");
      list.add(0x01F1, "DZ");
      list.add(0x01C4, "DZcaron");
      list.add(0x0534, "Daarmenian");
      list.add(0x0189, "Dafrican");
      list.add(0x010E, "Dcaron");
      list.add(0x1E10, "Dcedilla");
      list.add(0x24B9, "Dcircle");
      list.add(0x1E12, "Dcircumflexbelow");
      list.add(0x0110, "Dcroat");
      list.add(0x1E0A, "Ddotaccent");
      list.add(0x1E0C, "Ddotbelow");
      list.add(0x0414, "Decyrillic");
      list.add(0x03EE, "Deicoptic");
      list.add(0x2206, "Delta");
      list.add(0x0394, "Deltagreek");
      list.add(0x018A, "Dhook");
      list.add(0xF6CB, "Dieresis");
      list.add(0xF6CC, "DieresisAcute");
      list.add(0xF6CD, "DieresisGrave");
      list.add(0xF7A8, "Dieresissmall");
      list.add(0x03DC, "Digammagreek");
      list.add(0x0402, "Djecyrillic");
      list.add(0x1E0E, "Dlinebelow");
      list.add(0xFF24, "Dmonospace");
      list.add(0xF6F7, "Dotaccentsmall");
      list.add(0x0110, "Dslash");
      list.add(0xF764, "Dsmall");
      list.add(0x018B, "Dtopbar");
      list.add(0x01F2, "Dz");
      list.add(0x01C5, "Dzcaron");
      list.add(0x04E0, "Dzeabkhasiancyrillic");
      list.add(0x0405, "Dzecyrillic");
      list.add(0x040F, "Dzhecyrillic");
      list.add(0x0045, "E");
      list.add(0x00C9, "Eacute");
      list.add(0xF7E9, "Eacutesmall");
      list.add(0x0114, "Ebreve");
      list.add(0x011A, "Ecaron");
      list.add(0x1E1C, "Ecedillabreve");
      list.add(0x0535, "Echarmenian");
      list.add(0x24BA, "Ecircle");
      list.add(0x00CA, "Ecircumflex");
      list.add(0x1EBE, "Ecircumflexacute");
      list.add(0x1E18, "Ecircumflexbelow");
      list.add(0x1EC6, "Ecircumflexdotbelow");
      list.add(0x1EC0, "Ecircumflexgrave");
      list.add(0x1EC2, "Ecircumflexhookabove");
      list.add(0xF7EA, "Ecircumflexsmall");
      list.add(0x1EC4, "Ecircumflextilde");
      list.add(0x0404, "Ecyrillic");
      list.add(0x0204, "Edblgrave");
      list.add(0x00CB, "Edieresis");
      list.add(0xF7EB, "Edieresissmall");
      list.add(0x0116, "Edot");
      list.add(0x0116, "Edotaccent");
      list.add(0x1EB8, "Edotbelow");
      list.add(0x0424, "Efcyrillic");
      list.add(0x00C8, "Egrave");
      list.add(0xF7E8, "Egravesmall");
      list.add(0x0537, "Eharmenian");
      list.add(0x1EBA, "Ehookabove");
      list.add(0x2167, "Eightroman");
      list.add(0x0206, "Einvertedbreve");
      list.add(0x0464, "Eiotifiedcyrillic");
      list.add(0x041B, "Elcyrillic");
      list.add(0x216A, "Elevenroman");
      list.add(0x0112, "Emacron");
      list.add(0x1E16, "Emacronacute");
      list.add(0x1E14, "Emacrongrave");
      list.add(0x041C, "Emcyrillic");
      list.add(0xFF25, "Emonospace");
      list.add(0x041D, "Encyrillic");
      list.add(0x04A2, "Endescendercyrillic");
      list.add(0x014A, "Eng");
      list.add(0x04A4, "Enghecyrillic");
      list.add(0x04C7, "Enhookcyrillic");
      list.add(0x0118, "Eogonek");
      list.add(0x0190, "Eopen");
      list.add(0x0395, "Epsilon");
      list.add(0x0388, "Epsilontonos");
      list.add(0x0420, "Ercyrillic");
      list.add(0x018E, "Ereversed");
      list.add(0x042D, "Ereversedcyrillic");
      list.add(0x0421, "Escyrillic");
      list.add(0x04AA, "Esdescendercyrillic");
      list.add(0x01A9, "Esh");
      list.add(0xF765, "Esmall");
      list.add(0x0397, "Eta");
      list.add(0x0538, "Etarmenian");
      list.add(0x0389, "Etatonos");
      list.add(0x00D0, "Eth");
      list.add(0xF7F0, "Ethsmall");
      list.add(0x1EBC, "Etilde");
      list.add(0x1E1A, "Etildebelow");
      list.add(0x20AC, "Euro");
      list.add(0x01B7, "Ezh");
      list.add(0x01EE, "Ezhcaron");
      list.add(0x01B8, "Ezhreversed");
      list.add(0x0046, "F");
      list.add(0x24BB, "Fcircle");
      list.add(0x1E1E, "Fdotaccent");
      list.add(0x0556, "Feharmenian");
      list.add(0x03E4, "Feicoptic");
      list.add(0x0191, "Fhook");
      list.add(0x0472, "Fitacyrillic");
      list.add(0x2164, "Fiveroman");
      list.add(0xFF26, "Fmonospace");
      list.add(0x2163, "Fourroman");
      list.add(0xF766, "Fsmall");
      list.add(0x0047, "G");
      list.add(0x3387, "GBsquare");
      list.add(0x01F4, "Gacute");
      list.add(0x0393, "Gamma");
      list.add(0x0194, "Gammaafrican");
      list.add(0x03EA, "Gangiacoptic");
      list.add(0x011E, "Gbreve");
      list.add(0x01E6, "Gcaron");
      list.add(0x0122, "Gcedilla");
      list.add(0x24BC, "Gcircle");
      list.add(0x011C, "Gcircumflex");
      list.add(0x0122, "Gcommaaccent");
      list.add(0x0120, "Gdot");
      list.add(0x0120, "Gdotaccent");
      list.add(0x0413, "Gecyrillic");
      list.add(0x0542, "Ghadarmenian");
      list.add(0x0494, "Ghemiddlehookcyrillic");
      list.add(0x0492, "Ghestrokecyrillic");
      list.add(0x0490, "Gheupturncyrillic");
      list.add(0x0193, "Ghook");
      list.add(0x0533, "Gimarmenian");
      list.add(0x0403, "Gjecyrillic");
      list.add(0x1E20, "Gmacron");
      list.add(0xFF27, "Gmonospace");
      list.add(0xF6CE, "Grave");
      list.add(0xF760, "Gravesmall");
      list.add(0xF767, "Gsmall");
      list.add(0x029B, "Gsmallhook");
      list.add(0x01E4, "Gstroke");
      list.add(0x0048, "H");
      list.add(0x25CF, "H18533");
      list.add(0x25AA, "H18543");
      list.add(0x25AB, "H18551");
      list.add(0x25A1, "H22073");
      list.add(0x33CB, "HPsquare");
      list.add(0x04A8, "Haabkhasiancyrillic");
      list.add(0x04B2, "Hadescendercyrillic");
      list.add(0x042A, "Hardsigncyrillic");
      list.add(0x0126, "Hbar");
      list.add(0x1E2A, "Hbrevebelow");
      list.add(0x1E28, "Hcedilla");
      list.add(0x24BD, "Hcircle");
      list.add(0x0124, "Hcircumflex");
      list.add(0x1E26, "Hdieresis");
      list.add(0x1E22, "Hdotaccent");
      list.add(0x1E24, "Hdotbelow");
      list.add(0xFF28, "Hmonospace");
      list.add(0x0540, "Hoarmenian");
      list.add(0x03E8, "Horicoptic");
      list.add(0xF768, "Hsmall");
      list.add(0xF6CF, "Hungarumlaut");
      list.add(0xF6F8, "Hungarumlautsmall");
      list.add(0x3390, "Hzsquare");
      list.add(0x0049, "I");
      list.add(0x042F, "IAcyrillic");
      list.add(0x0132, "IJ");
      list.add(0x042E, "IUcyrillic");
      list.add(0x00CD, "Iacute");
      list.add(0xF7ED, "Iacutesmall");
      list.add(0x012C, "Ibreve");
      list.add(0x01CF, "Icaron");
      list.add(0x24BE, "Icircle");
      list.add(0x00CE, "Icircumflex");
      list.add(0xF7EE, "Icircumflexsmall");
      list.add(0x0406, "Icyrillic");
      list.add(0x0208, "Idblgrave");
      list.add(0x00CF, "Idieresis");
      list.add(0x1E2E, "Idieresisacute");
      list.add(0x04E4, "Idieresiscyrillic");
      list.add(0xF7EF, "Idieresissmall");
      list.add(0x0130, "Idot");
      list.add(0x0130, "Idotaccent");
      list.add(0x1ECA, "Idotbelow");
      list.add(0x04D6, "Iebrevecyrillic");
      list.add(0x0415, "Iecyrillic");
      list.add(0x2111, "Ifraktur");
      list.add(0x00CC, "Igrave");
      list.add(0xF7EC, "Igravesmall");
      list.add(0x1EC8, "Ihookabove");
      list.add(0x0418, "Iicyrillic");
      list.add(0x020A, "Iinvertedbreve");
      list.add(0x0419, "Iishortcyrillic");
      list.add(0x012A, "Imacron");
      list.add(0x04E2, "Imacroncyrillic");
      list.add(0xFF29, "Imonospace");
      list.add(0x053B, "Iniarmenian");
      list.add(0x0401, "Iocyrillic");
      list.add(0x012E, "Iogonek");
      list.add(0x0399, "Iota");
      list.add(0x0196, "Iotaafrican");
      list.add(0x03AA, "Iotadieresis");
      list.add(0x038A, "Iotatonos");
      list.add(0xF769, "Ismall");
      list.add(0x0197, "Istroke");
      list.add(0x0128, "Itilde");
      list.add(0x1E2C, "Itildebelow");
      list.add(0x0474, "Izhitsacyrillic");
      list.add(0x0476, "Izhitsadblgravecyrillic");
      list.add(0x004A, "J");
      list.add(0x0541, "Jaarmenian");
      list.add(0x24BF, "Jcircle");
      list.add(0x0134, "Jcircumflex");
      list.add(0x0408, "Jecyrillic");
      list.add(0x054B, "Jheharmenian");
      list.add(0xFF2A, "Jmonospace");
      list.add(0xF76A, "Jsmall");
      list.add(0x004B, "K");
      list.add(0x3385, "KBsquare");
      list.add(0x33CD, "KKsquare");
      list.add(0x04A0, "Kabashkircyrillic");
      list.add(0x1E30, "Kacute");
      list.add(0x041A, "Kacyrillic");
      list.add(0x049A, "Kadescendercyrillic");
      list.add(0x04C3, "Kahookcyrillic");
      list.add(0x039A, "Kappa");
      list.add(0x049E, "Kastrokecyrillic");
      list.add(0x049C, "Kaverticalstrokecyrillic");
      list.add(0x01E8, "Kcaron");
      list.add(0x0136, "Kcedilla");
      list.add(0x24C0, "Kcircle");
      list.add(0x0136, "Kcommaaccent");
      list.add(0x1E32, "Kdotbelow");
      list.add(0x0554, "Keharmenian");
      list.add(0x053F, "Kenarmenian");
      list.add(0x0425, "Khacyrillic");
      list.add(0x03E6, "Kheicoptic");
      list.add(0x0198, "Khook");
      list.add(0x040C, "Kjecyrillic");
      list.add(0x1E34, "Klinebelow");
      list.add(0xFF2B, "Kmonospace");
      list.add(0x0480, "Koppacyrillic");
      list.add(0x03DE, "Koppagreek");
      list.add(0x046E, "Ksicyrillic");
      list.add(0xF76B, "Ksmall");
      list.add(0x004C, "L");
      list.add(0x01C7, "LJ");
      list.add(0xF6BF, "LL");
      list.add(0x0139, "Lacute");
      list.add(0x039B, "Lambda");
      list.add(0x013D, "Lcaron");
      list.add(0x013B, "Lcedilla");
      list.add(0x24C1, "Lcircle");
      list.add(0x1E3C, "Lcircumflexbelow");
      list.add(0x013B, "Lcommaaccent");
      list.add(0x013F, "Ldot");
      list.add(0x013F, "Ldotaccent");
      list.add(0x1E36, "Ldotbelow");
      list.add(0x1E38, "Ldotbelowmacron");
      list.add(0x053C, "Liwnarmenian");
      list.add(0x01C8, "Lj");
      list.add(0x0409, "Ljecyrillic");
      list.add(0x1E3A, "Llinebelow");
      list.add(0xFF2C, "Lmonospace");
      list.add(0x0141, "Lslash");
      list.add(0xF6F9, "Lslashsmall");
      list.add(0xF76C, "Lsmall");
      list.add(0x004D, "M");
      list.add(0x3386, "MBsquare");
      list.add(0xF6D0, "Macron");
      list.add(0xF7AF, "Macronsmall");
      list.add(0x1E3E, "Macute");
      list.add(0x24C2, "Mcircle");
      list.add(0x1E40, "Mdotaccent");
      list.add(0x1E42, "Mdotbelow");
      list.add(0x0544, "Menarmenian");
      list.add(0xFF2D, "Mmonospace");
      list.add(0xF76D, "Msmall");
      list.add(0x019C, "Mturned");
      list.add(0x039C, "Mu");
      list.add(0x004E, "N");
      list.add(0x01CA, "NJ");
      list.add(0x0143, "Nacute");
      list.add(0x0147, "Ncaron");
      list.add(0x0145, "Ncedilla");
      list.add(0x24C3, "Ncircle");
      list.add(0x1E4A, "Ncircumflexbelow");
      list.add(0x0145, "Ncommaaccent");
      list.add(0x1E44, "Ndotaccent");
      list.add(0x1E46, "Ndotbelow");
      list.add(0x019D, "Nhookleft");
      list.add(0x2168, "Nineroman");
      list.add(0x01CB, "Nj");
      list.add(0x040A, "Njecyrillic");
      list.add(0x1E48, "Nlinebelow");
      list.add(0xFF2E, "Nmonospace");
      list.add(0x0546, "Nowarmenian");
      list.add(0xF76E, "Nsmall");
      list.add(0x00D1, "Ntilde");
      list.add(0xF7F1, "Ntildesmall");
      list.add(0x039D, "Nu");
      list.add(0x004F, "O");
      list.add(0x0152, "OE");
      list.add(0xF6FA, "OEsmall");
      list.add(0x00D3, "Oacute");
      list.add(0xF7F3, "Oacutesmall");
      list.add(0x04E8, "Obarredcyrillic");
      list.add(0x04EA, "Obarreddieresiscyrillic");
      list.add(0x014E, "Obreve");
      list.add(0x01D1, "Ocaron");
      list.add(0x019F, "Ocenteredtilde");
      list.add(0x24C4, "Ocircle");
      list.add(0x00D4, "Ocircumflex");
      list.add(0x1ED0, "Ocircumflexacute");
      list.add(0x1ED8, "Ocircumflexdotbelow");
      list.add(0x1ED2, "Ocircumflexgrave");
      list.add(0x1ED4, "Ocircumflexhookabove");
      list.add(0xF7F4, "Ocircumflexsmall");
      list.add(0x1ED6, "Ocircumflextilde");
      list.add(0x041E, "Ocyrillic");
      list.add(0x0150, "Odblacute");
      list.add(0x020C, "Odblgrave");
      list.add(0x00D6, "Odieresis");
      list.add(0x04E6, "Odieresiscyrillic");
      list.add(0xF7F6, "Odieresissmall");
      list.add(0x1ECC, "Odotbelow");
      list.add(0xF6FB, "Ogoneksmall");
      list.add(0x00D2, "Ograve");
      list.add(0xF7F2, "Ogravesmall");
      list.add(0x0555, "Oharmenian");
      list.add(0x2126, "Ohm");
      list.add(0x1ECE, "Ohookabove");
      list.add(0x01A0, "Ohorn");
      list.add(0x1EDA, "Ohornacute");
      list.add(0x1EE2, "Ohorndotbelow");
      list.add(0x1EDC, "Ohorngrave");
      list.add(0x1EDE, "Ohornhookabove");
      list.add(0x1EE0, "Ohorntilde");
      list.add(0x0150, "Ohungarumlaut");
      list.add(0x01A2, "Oi");
      list.add(0x020E, "Oinvertedbreve");
      list.add(0x014C, "Omacron");
      list.add(0x1E52, "Omacronacute");
      list.add(0x1E50, "Omacrongrave");
      list.add(0x2126, "Omega");
      list.add(0x0460, "Omegacyrillic");
      list.add(0x03A9, "Omegagreek");
      list.add(0x047A, "Omegaroundcyrillic");
      list.add(0x047C, "Omegatitlocyrillic");
      list.add(0x038F, "Omegatonos");
      list.add(0x039F, "Omicron");
      list.add(0x038C, "Omicrontonos");
      list.add(0xFF2F, "Omonospace");
      list.add(0x2160, "Oneroman");
      list.add(0x01EA, "Oogonek");
      list.add(0x01EC, "Oogonekmacron");
      list.add(0x0186, "Oopen");
      list.add(0x00D8, "Oslash");
      list.add(0x01FE, "Oslashacute");
      list.add(0xF7F8, "Oslashsmall");
      list.add(0xF76F, "Osmall");
      list.add(0x01FE, "Ostrokeacute");
      list.add(0x047E, "Otcyrillic");
      list.add(0x00D5, "Otilde");
      list.add(0x1E4C, "Otildeacute");
      list.add(0x1E4E, "Otildedieresis");
      list.add(0xF7F5, "Otildesmall");
      list.add(0x0050, "P");
      list.add(0x1E54, "Pacute");
      list.add(0x24C5, "Pcircle");
      list.add(0x1E56, "Pdotaccent");
      list.add(0x041F, "Pecyrillic");
      list.add(0x054A, "Peharmenian");
      list.add(0x04A6, "Pemiddlehookcyrillic");
      list.add(0x03A6, "Phi");
      list.add(0x01A4, "Phook");
      list.add(0x03A0, "Pi");
      list.add(0x0553, "Piwrarmenian");
      list.add(0xFF30, "Pmonospace");
      list.add(0x03A8, "Psi");
      list.add(0x0470, "Psicyrillic");
      list.add(0xF770, "Psmall");
      list.add(0x0051, "Q");
      list.add(0x24C6, "Qcircle");
      list.add(0xFF31, "Qmonospace");
      list.add(0xF771, "Qsmall");
      list.add(0x0052, "R");
      list.add(0x054C, "Raarmenian");
      list.add(0x0154, "Racute");
      list.add(0x0158, "Rcaron");
      list.add(0x0156, "Rcedilla");
      list.add(0x24C7, "Rcircle");
      list.add(0x0156, "Rcommaaccent");
      list.add(0x0210, "Rdblgrave");
      list.add(0x1E58, "Rdotaccent");
      list.add(0x1E5A, "Rdotbelow");
      list.add(0x1E5C, "Rdotbelowmacron");
      list.add(0x0550, "Reharmenian");
      list.add(0x211C, "Rfraktur");
      list.add(0x03A1, "Rho");
      list.add(0xF6FC, "Ringsmall");
      list.add(0x0212, "Rinvertedbreve");
      list.add(0x1E5E, "Rlinebelow");
      list.add(0xFF32, "Rmonospace");
      list.add(0xF772, "Rsmall");
      list.add(0x0281, "Rsmallinverted");
      list.add(0x02B6, "Rsmallinvertedsuperior");
      list.add(0x0053, "S");
      list.add(0x250C, "SF010000");
      list.add(0x2514, "SF020000");
      list.add(0x2510, "SF030000");
      list.add(0x2518, "SF040000");
      list.add(0x253C, "SF050000");
      list.add(0x252C, "SF060000");
      list.add(0x2534, "SF070000");
      list.add(0x251C, "SF080000");
      list.add(0x2524, "SF090000");
      list.add(0x2500, "SF100000");
      list.add(0x2502, "SF110000");
      list.add(0x2561, "SF190000");
      list.add(0x2562, "SF200000");
      list.add(0x2556, "SF210000");
      list.add(0x2555, "SF220000");
      list.add(0x2563, "SF230000");
      list.add(0x2551, "SF240000");
      list.add(0x2557, "SF250000");
      list.add(0x255D, "SF260000");
      list.add(0x255C, "SF270000");
      list.add(0x255B, "SF280000");
      list.add(0x255E, "SF360000");
      list.add(0x255F, "SF370000");
      list.add(0x255A, "SF380000");
      list.add(0x2554, "SF390000");
      list.add(0x2569, "SF400000");
      list.add(0x2566, "SF410000");
      list.add(0x2560, "SF420000");
      list.add(0x2550, "SF430000");
      list.add(0x256C, "SF440000");
      list.add(0x2567, "SF450000");
      list.add(0x2568, "SF460000");
      list.add(0x2564, "SF470000");
      list.add(0x2565, "SF480000");
      list.add(0x2559, "SF490000");
      list.add(0x2558, "SF500000");
      list.add(0x2552, "SF510000");
      list.add(0x2553, "SF520000");
      list.add(0x256B, "SF530000");
      list.add(0x256A, "SF540000");
      list.add(0x015A, "Sacute");
      list.add(0x1E64, "Sacutedotaccent");
      list.add(0x03E0, "Sampigreek");
      list.add(0x0160, "Scaron");
      list.add(0x1E66, "Scarondotaccent");
      list.add(0xF6FD, "Scaronsmall");
      list.add(0x015E, "Scedilla");
      list.add(0x018F, "Schwa");
      list.add(0x04D8, "Schwacyrillic");
      list.add(0x04DA, "Schwadieresiscyrillic");
      list.add(0x24C8, "Scircle");
      list.add(0x015C, "Scircumflex");
      list.add(0x0218, "Scommaaccent");
      list.add(0x1E60, "Sdotaccent");
      list.add(0x1E62, "Sdotbelow");
      list.add(0x1E68, "Sdotbelowdotaccent");
      list.add(0x054D, "Seharmenian");
      list.add(0x2166, "Sevenroman");
      list.add(0x0547, "Shaarmenian");
      list.add(0x0428, "Shacyrillic");
      list.add(0x0429, "Shchacyrillic");
      list.add(0x03E2, "Sheicoptic");
      list.add(0x04BA, "Shhacyrillic");
      list.add(0x03EC, "Shimacoptic");
      list.add(0x03A3, "Sigma");
      list.add(0x2165, "Sixroman");
      list.add(0xFF33, "Smonospace");
      list.add(0x042C, "Softsigncyrillic");
      list.add(0xF773, "Ssmall");
      list.add(0x03DA, "Stigmagreek");
      list.add(0x0054, "T");
      list.add(0x03A4, "Tau");
      list.add(0x0166, "Tbar");
      list.add(0x0164, "Tcaron");
      list.add(0x0162, "Tcedilla");
      list.add(0x24C9, "Tcircle");
      list.add(0x1E70, "Tcircumflexbelow");
      list.add(0x0162, "Tcommaaccent");
      list.add(0x1E6A, "Tdotaccent");
      list.add(0x1E6C, "Tdotbelow");
      list.add(0x0422, "Tecyrillic");
      list.add(0x04AC, "Tedescendercyrillic");
      list.add(0x2169, "Tenroman");
      list.add(0x04B4, "Tetsecyrillic");
      list.add(0x0398, "Theta");
      list.add(0x01AC, "Thook");
      list.add(0x00DE, "Thorn");
      list.add(0xF7FE, "Thornsmall");
      list.add(0x2162, "Threeroman");
      list.add(0xF6FE, "Tildesmall");
      list.add(0x054F, "Tiwnarmenian");
      list.add(0x1E6E, "Tlinebelow");
      list.add(0xFF34, "Tmonospace");
      list.add(0x0539, "Toarmenian");
      list.add(0x01BC, "Tonefive");
      list.add(0x0184, "Tonesix");
      list.add(0x01A7, "Tonetwo");
      list.add(0x01AE, "Tretroflexhook");
      list.add(0x0426, "Tsecyrillic");
      list.add(0x040B, "Tshecyrillic");
      list.add(0xF774, "Tsmall");
      list.add(0x216B, "Twelveroman");
      list.add(0x2161, "Tworoman");
      list.add(0x0055, "U");
      list.add(0x00DA, "Uacute");
      list.add(0xF7FA, "Uacutesmall");
      list.add(0x016C, "Ubreve");
      list.add(0x01D3, "Ucaron");
      list.add(0x24CA, "Ucircle");
      list.add(0x00DB, "Ucircumflex");
      list.add(0x1E76, "Ucircumflexbelow");
      list.add(0xF7FB, "Ucircumflexsmall");
      list.add(0x0423, "Ucyrillic");
      list.add(0x0170, "Udblacute");
      list.add(0x0214, "Udblgrave");
      list.add(0x00DC, "Udieresis");
      list.add(0x01D7, "Udieresisacute");
      list.add(0x1E72, "Udieresisbelow");
      list.add(0x01D9, "Udieresiscaron");
      list.add(0x04F0, "Udieresiscyrillic");
      list.add(0x01DB, "Udieresisgrave");
      list.add(0x01D5, "Udieresismacron");
      list.add(0xF7FC, "Udieresissmall");
      list.add(0x1EE4, "Udotbelow");
      list.add(0x00D9, "Ugrave");
      list.add(0xF7F9, "Ugravesmall");
      list.add(0x1EE6, "Uhookabove");
      list.add(0x01AF, "Uhorn");
      list.add(0x1EE8, "Uhornacute");
      list.add(0x1EF0, "Uhorndotbelow");
      list.add(0x1EEA, "Uhorngrave");
      list.add(0x1EEC, "Uhornhookabove");
      list.add(0x1EEE, "Uhorntilde");
      list.add(0x0170, "Uhungarumlaut");
      list.add(0x04F2, "Uhungarumlautcyrillic");
      list.add(0x0216, "Uinvertedbreve");
      list.add(0x0478, "Ukcyrillic");
      list.add(0x016A, "Umacron");
      list.add(0x04EE, "Umacroncyrillic");
      list.add(0x1E7A, "Umacrondieresis");
      list.add(0xFF35, "Umonospace");
      list.add(0x0172, "Uogonek");
      list.add(0x03A5, "Upsilon");
      list.add(0x03D2, "Upsilon1");
      list.add(0x03D3, "Upsilonacutehooksymbolgreek");
      list.add(0x01B1, "Upsilonafrican");
      list.add(0x03AB, "Upsilondieresis");
      list.add(0x03D4, "Upsilondieresishooksymbolgreek");
      list.add(0x03D2, "Upsilonhooksymbol");
      list.add(0x038E, "Upsilontonos");
      list.add(0x016E, "Uring");
      list.add(0x040E, "Ushortcyrillic");
      list.add(0xF775, "Usmall");
      list.add(0x04AE, "Ustraightcyrillic");
      list.add(0x04B0, "Ustraightstrokecyrillic");
      list.add(0x0168, "Utilde");
      list.add(0x1E78, "Utildeacute");
      list.add(0x1E74, "Utildebelow");
      list.add(0x0056, "V");
      list.add(0x24CB, "Vcircle");
      list.add(0x1E7E, "Vdotbelow");
      list.add(0x0412, "Vecyrillic");
      list.add(0x054E, "Vewarmenian");
      list.add(0x01B2, "Vhook");
      list.add(0xFF36, "Vmonospace");
      list.add(0x0548, "Voarmenian");
      list.add(0xF776, "Vsmall");
      list.add(0x1E7C, "Vtilde");
      list.add(0x0057, "W");
      list.add(0x1E82, "Wacute");
      list.add(0x24CC, "Wcircle");
      list.add(0x0174, "Wcircumflex");
      list.add(0x1E84, "Wdieresis");
      list.add(0x1E86, "Wdotaccent");
      list.add(0x1E88, "Wdotbelow");
      list.add(0x1E80, "Wgrave");
      list.add(0xFF37, "Wmonospace");
      list.add(0xF777, "Wsmall");
      list.add(0x0058, "X");
      list.add(0x24CD, "Xcircle");
      list.add(0x1E8C, "Xdieresis");
      list.add(0x1E8A, "Xdotaccent");
      list.add(0x053D, "Xeharmenian");
      list.add(0x039E, "Xi");
      list.add(0xFF38, "Xmonospace");
      list.add(0xF778, "Xsmall");
      list.add(0x0059, "Y");
      list.add(0x00DD, "Yacute");
      list.add(0xF7FD, "Yacutesmall");
      list.add(0x0462, "Yatcyrillic");
      list.add(0x24CE, "Ycircle");
      list.add(0x0176, "Ycircumflex");
      list.add(0x0178, "Ydieresis");
      list.add(0xF7FF, "Ydieresissmall");
      list.add(0x1E8E, "Ydotaccent");
      list.add(0x1EF4, "Ydotbelow");
      list.add(0x042B, "Yericyrillic");
      list.add(0x04F8, "Yerudieresiscyrillic");
      list.add(0x1EF2, "Ygrave");
      list.add(0x01B3, "Yhook");
      list.add(0x1EF6, "Yhookabove");
      list.add(0x0545, "Yiarmenian");
      list.add(0x0407, "Yicyrillic");
      list.add(0x0552, "Yiwnarmenian");
      list.add(0xFF39, "Ymonospace");
      list.add(0xF779, "Ysmall");
      list.add(0x1EF8, "Ytilde");
      list.add(0x046A, "Yusbigcyrillic");
      list.add(0x046C, "Yusbigiotifiedcyrillic");
      list.add(0x0466, "Yuslittlecyrillic");
      list.add(0x0468, "Yuslittleiotifiedcyrillic");
      list.add(0x005A, "Z");
      list.add(0x0536, "Zaarmenian");
      list.add(0x0179, "Zacute");
      list.add(0x017D, "Zcaron");
      list.add(0xF6FF, "Zcaronsmall");
      list.add(0x24CF, "Zcircle");
      list.add(0x1E90, "Zcircumflex");
      list.add(0x017B, "Zdot");
      list.add(0x017B, "Zdotaccent");
      list.add(0x1E92, "Zdotbelow");
      list.add(0x0417, "Zecyrillic");
      list.add(0x0498, "Zedescendercyrillic");
      list.add(0x04DE, "Zedieresiscyrillic");
      list.add(0x0396, "Zeta");
      list.add(0x053A, "Zhearmenian");
      list.add(0x04C1, "Zhebrevecyrillic");
      list.add(0x0416, "Zhecyrillic");
      list.add(0x0496, "Zhedescendercyrillic");
      list.add(0x04DC, "Zhedieresiscyrillic");
      list.add(0x1E94, "Zlinebelow");
      list.add(0xFF3A, "Zmonospace");
      list.add(0xF77A, "Zsmall");
      list.add(0x01B5, "Zstroke");
      list.add(0x0061, "a");
      list.add(0x0986, "aabengali");
      list.add(0x00E1, "aacute");
      list.add(0x0906, "aadeva");
      list.add(0x0A86, "aagujarati");
      list.add(0x0A06, "aagurmukhi");
      list.add(0x0A3E, "aamatragurmukhi");
      list.add(0x3303, "aarusquare");
      list.add(0x09BE, "aavowelsignbengali");
      list.add(0x093E, "aavowelsigndeva");
      list.add(0x0ABE, "aavowelsigngujarati");
      list.add(0x055F, "abbreviationmarkarmenian");
      list.add(0x0970, "abbreviationsigndeva");
      list.add(0x0985, "abengali");
      list.add(0x311A, "abopomofo");
      list.add(0x0103, "abreve");
      list.add(0x1EAF, "abreveacute");
      list.add(0x04D1, "abrevecyrillic");
      list.add(0x1EB7, "abrevedotbelow");
      list.add(0x1EB1, "abrevegrave");
      list.add(0x1EB3, "abrevehookabove");
      list.add(0x1EB5, "abrevetilde");
      list.add(0x01CE, "acaron");
      list.add(0x24D0, "acircle");
      list.add(0x00E2, "acircumflex");
      list.add(0x1EA5, "acircumflexacute");
      list.add(0x1EAD, "acircumflexdotbelow");
      list.add(0x1EA7, "acircumflexgrave");
      list.add(0x1EA9, "acircumflexhookabove");
      list.add(0x1EAB, "acircumflextilde");
      list.add(0x00B4, "acute");
      list.add(0x0317, "acutebelowcmb");
      list.add(0x0301, "acutecmb");
      list.add(0x0301, "acutecomb");
      list.add(0x0954, "acutedeva");
      list.add(0x02CF, "acutelowmod");
      list.add(0x0341, "acutetonecmb");
      list.add(0x0430, "acyrillic");
      list.add(0x0201, "adblgrave");
      list.add(0x0A71, "addakgurmukhi");
      list.add(0x0905, "adeva");
      list.add(0x00E4, "adieresis");
      list.add(0x04D3, "adieresiscyrillic");
      list.add(0x01DF, "adieresismacron");
      list.add(0x1EA1, "adotbelow");
      list.add(0x01E1, "adotmacron");
      list.add(0x00E6, "ae");
      list.add(0x01FD, "aeacute");
      list.add(0x3150, "aekorean");
      list.add(0x01E3, "aemacron");
      list.add(0x2015, "afii00208");
      list.add(0x20A4, "afii08941");
      list.add(0x0410, "afii10017");
      list.add(0x0411, "afii10018");
      list.add(0x0412, "afii10019");
      list.add(0x0413, "afii10020");
      list.add(0x0414, "afii10021");
      list.add(0x0415, "afii10022");
      list.add(0x0401, "afii10023");
      list.add(0x0416, "afii10024");
      list.add(0x0417, "afii10025");
      list.add(0x0418, "afii10026");
      list.add(0x0419, "afii10027");
      list.add(0x041A, "afii10028");
      list.add(0x041B, "afii10029");
      list.add(0x041C, "afii10030");
      list.add(0x041D, "afii10031");
      list.add(0x041E, "afii10032");
      list.add(0x041F, "afii10033");
      list.add(0x0420, "afii10034");
      list.add(0x0421, "afii10035");
      list.add(0x0422, "afii10036");
      list.add(0x0423, "afii10037");
      list.add(0x0424, "afii10038");
      list.add(0x0425, "afii10039");
      list.add(0x0426, "afii10040");
      list.add(0x0427, "afii10041");
      list.add(0x0428, "afii10042");
      list.add(0x0429, "afii10043");
      list.add(0x042A, "afii10044");
      list.add(0x042B, "afii10045");
      list.add(0x042C, "afii10046");
      list.add(0x042D, "afii10047");
      list.add(0x042E, "afii10048");
      list.add(0x042F, "afii10049");
      list.add(0x0490, "afii10050");
      list.add(0x0402, "afii10051");
      list.add(0x0403, "afii10052");
      list.add(0x0404, "afii10053");
      list.add(0x0405, "afii10054");
      list.add(0x0406, "afii10055");
      list.add(0x0407, "afii10056");
      list.add(0x0408, "afii10057");
      list.add(0x0409, "afii10058");
      list.add(0x040A, "afii10059");
      list.add(0x040B, "afii10060");
      list.add(0x040C, "afii10061");
      list.add(0x040E, "afii10062");
      list.add(0xF6C4, "afii10063");
      list.add(0xF6C5, "afii10064");
      list.add(0x0430, "afii10065");
      list.add(0x0431, "afii10066");
      list.add(0x0432, "afii10067");
      list.add(0x0433, "afii10068");
      list.add(0x0434, "afii10069");
      list.add(0x0435, "afii10070");
      list.add(0x0451, "afii10071");
      list.add(0x0436, "afii10072");
      list.add(0x0437, "afii10073");
      list.add(0x0438, "afii10074");
      list.add(0x0439, "afii10075");
      list.add(0x043A, "afii10076");
      list.add(0x043B, "afii10077");
      list.add(0x043C, "afii10078");
      list.add(0x043D, "afii10079");
      list.add(0x043E, "afii10080");
      list.add(0x043F, "afii10081");
      list.add(0x0440, "afii10082");
      list.add(0x0441, "afii10083");
      list.add(0x0442, "afii10084");
      list.add(0x0443, "afii10085");
      list.add(0x0444, "afii10086");
      list.add(0x0445, "afii10087");
      list.add(0x0446, "afii10088");
      list.add(0x0447, "afii10089");
      list.add(0x0448, "afii10090");
      list.add(0x0449, "afii10091");
      list.add(0x044A, "afii10092");
      list.add(0x044B, "afii10093");
      list.add(0x044C, "afii10094");
      list.add(0x044D, "afii10095");
      list.add(0x044E, "afii10096");
      list.add(0x044F, "afii10097");
      list.add(0x0491, "afii10098");
      list.add(0x0452, "afii10099");
      list.add(0x0453, "afii10100");
      list.add(0x0454, "afii10101");
      list.add(0x0455, "afii10102");
      list.add(0x0456, "afii10103");
      list.add(0x0457, "afii10104");
      list.add(0x0458, "afii10105");
      list.add(0x0459, "afii10106");
      list.add(0x045A, "afii10107");
      list.add(0x045B, "afii10108");
      list.add(0x045C, "afii10109");
      list.add(0x045E, "afii10110");
      list.add(0x040F, "afii10145");
      list.add(0x0462, "afii10146");
      list.add(0x0472, "afii10147");
      list.add(0x0474, "afii10148");
      list.add(0xF6C6, "afii10192");
      list.add(0x045F, "afii10193");
      list.add(0x0463, "afii10194");
      list.add(0x0473, "afii10195");
      list.add(0x0475, "afii10196");
      list.add(0xF6C7, "afii10831");
      list.add(0xF6C8, "afii10832");
      list.add(0x04D9, "afii10846");
      list.add(0x200E, "afii299");
      list.add(0x200F, "afii300");
      list.add(0x200D, "afii301");
      list.add(0x066A, "afii57381");
      list.add(0x060C, "afii57388");
      list.add(0x0660, "afii57392");
      list.add(0x0661, "afii57393");
      list.add(0x0662, "afii57394");
      list.add(0x0663, "afii57395");
      list.add(0x0664, "afii57396");
      list.add(0x0665, "afii57397");
      list.add(0x0666, "afii57398");
      list.add(0x0667, "afii57399");
      list.add(0x0668, "afii57400");
      list.add(0x0669, "afii57401");
      list.add(0x061B, "afii57403");
      list.add(0x061F, "afii57407");
      list.add(0x0621, "afii57409");
      list.add(0x0622, "afii57410");
      list.add(0x0623, "afii57411");
      list.add(0x0624, "afii57412");
      list.add(0x0625, "afii57413");
      list.add(0x0626, "afii57414");
      list.add(0x0627, "afii57415");
      list.add(0x0628, "afii57416");
      list.add(0x0629, "afii57417");
      list.add(0x062A, "afii57418");
      list.add(0x062B, "afii57419");
      list.add(0x062C, "afii57420");
      list.add(0x062D, "afii57421");
      list.add(0x062E, "afii57422");
      list.add(0x062F, "afii57423");
      list.add(0x0630, "afii57424");
      list.add(0x0631, "afii57425");
      list.add(0x0632, "afii57426");
      list.add(0x0633, "afii57427");
      list.add(0x0634, "afii57428");
      list.add(0x0635, "afii57429");
      list.add(0x0636, "afii57430");
      list.add(0x0637, "afii57431");
      list.add(0x0638, "afii57432");
      list.add(0x0639, "afii57433");
      list.add(0x063A, "afii57434");
      list.add(0x0640, "afii57440");
      list.add(0x0641, "afii57441");
      list.add(0x0642, "afii57442");
      list.add(0x0643, "afii57443");
      list.add(0x0644, "afii57444");
      list.add(0x0645, "afii57445");
      list.add(0x0646, "afii57446");
      list.add(0x0648, "afii57448");
      list.add(0x0649, "afii57449");
      list.add(0x064A, "afii57450");
      list.add(0x064B, "afii57451");
      list.add(0x064C, "afii57452");
      list.add(0x064D, "afii57453");
      list.add(0x064E, "afii57454");
      list.add(0x064F, "afii57455");
      list.add(0x0650, "afii57456");
      list.add(0x0651, "afii57457");
      list.add(0x0652, "afii57458");
      list.add(0x0647, "afii57470");
      list.add(0x06A4, "afii57505");
      list.add(0x067E, "afii57506");
      list.add(0x0686, "afii57507");
      list.add(0x0698, "afii57508");
      list.add(0x06AF, "afii57509");
      list.add(0x0679, "afii57511");
      list.add(0x0688, "afii57512");
      list.add(0x0691, "afii57513");
      list.add(0x06BA, "afii57514");
      list.add(0x06D2, "afii57519");
      list.add(0x06D5, "afii57534");
      list.add(0x20AA, "afii57636");
      list.add(0x05BE, "afii57645");
      list.add(0x05C3, "afii57658");
      list.add(0x05D0, "afii57664");
      list.add(0x05D1, "afii57665");
      list.add(0x05D2, "afii57666");
      list.add(0x05D3, "afii57667");
      list.add(0x05D4, "afii57668");
      list.add(0x05D5, "afii57669");
      list.add(0x05D6, "afii57670");
      list.add(0x05D7, "afii57671");
      list.add(0x05D8, "afii57672");
      list.add(0x05D9, "afii57673");
      list.add(0x05DA, "afii57674");
      list.add(0x05DB, "afii57675");
      list.add(0x05DC, "afii57676");
      list.add(0x05DD, "afii57677");
      list.add(0x05DE, "afii57678");
      list.add(0x05DF, "afii57679");
      list.add(0x05E0, "afii57680");
      list.add(0x05E1, "afii57681");
      list.add(0x05E2, "afii57682");
      list.add(0x05E3, "afii57683");
      list.add(0x05E4, "afii57684");
      list.add(0x05E5, "afii57685");
      list.add(0x05E6, "afii57686");
      list.add(0x05E7, "afii57687");
      list.add(0x05E8, "afii57688");
      list.add(0x05E9, "afii57689");
      list.add(0x05EA, "afii57690");
      list.add(0xFB2A, "afii57694");
      list.add(0xFB2B, "afii57695");
      list.add(0xFB4B, "afii57700");
      list.add(0xFB1F, "afii57705");
      list.add(0x05F0, "afii57716");
      list.add(0x05F1, "afii57717");
      list.add(0x05F2, "afii57718");
      list.add(0xFB35, "afii57723");
      list.add(0x05B4, "afii57793");
      list.add(0x05B5, "afii57794");
      list.add(0x05B6, "afii57795");
      list.add(0x05BB, "afii57796");
      list.add(0x05B8, "afii57797");
      list.add(0x05B7, "afii57798");
      list.add(0x05B0, "afii57799");
      list.add(0x05B2, "afii57800");
      list.add(0x05B1, "afii57801");
      list.add(0x05B3, "afii57802");
      list.add(0x05C2, "afii57803");
      list.add(0x05C1, "afii57804");
      list.add(0x05B9, "afii57806");
      list.add(0x05BC, "afii57807");
      list.add(0x05BD, "afii57839");
      list.add(0x05BF, "afii57841");
      list.add(0x05C0, "afii57842");
      list.add(0x02BC, "afii57929");
      list.add(0x2105, "afii61248");
      list.add(0x2113, "afii61289");
      list.add(0x2116, "afii61352");
      list.add(0x202C, "afii61573");
      list.add(0x202D, "afii61574");
      list.add(0x202E, "afii61575");
      list.add(0x200C, "afii61664");
      list.add(0x066D, "afii63167");
      list.add(0x02BD, "afii64937");
      list.add(0x00E0, "agrave");
      list.add(0x0A85, "agujarati");
      list.add(0x0A05, "agurmukhi");
      list.add(0x3042, "ahiragana");
      list.add(0x1EA3, "ahookabove");
      list.add(0x0990, "aibengali");
      list.add(0x311E, "aibopomofo");
      list.add(0x0910, "aideva");
      list.add(0x04D5, "aiecyrillic");
      list.add(0x0A90, "aigujarati");
      list.add(0x0A10, "aigurmukhi");
      list.add(0x0A48, "aimatragurmukhi");
      list.add(0x0639, "ainarabic");
      list.add(0xFECA, "ainfinalarabic");
      list.add(0xFECB, "aininitialarabic");
      list.add(0xFECC, "ainmedialarabic");
      list.add(0x0203, "ainvertedbreve");
      list.add(0x09C8, "aivowelsignbengali");
      list.add(0x0948, "aivowelsigndeva");
      list.add(0x0AC8, "aivowelsigngujarati");
      list.add(0x30A2, "akatakana");
      list.add(0xFF71, "akatakanahalfwidth");
      list.add(0x314F, "akorean");
      list.add(0x05D0, "alef");
      list.add(0x0627, "alefarabic");
      list.add(0xFB30, "alefdageshhebrew");
      list.add(0xFE8E, "aleffinalarabic");
      list.add(0x0623, "alefhamzaabovearabic");
      list.add(0xFE84, "alefhamzaabovefinalarabic");
      list.add(0x0625, "alefhamzabelowarabic");
      list.add(0xFE88, "alefhamzabelowfinalarabic");
      list.add(0x05D0, "alefhebrew");
      list.add(0xFB4F, "aleflamedhebrew");
      list.add(0x0622, "alefmaddaabovearabic");
      list.add(0xFE82, "alefmaddaabovefinalarabic");
      list.add(0x0649, "alefmaksuraarabic");
      list.add(0xFEF0, "alefmaksurafinalarabic");
      list.add(0xFEF3, "alefmaksurainitialarabic");
      list.add(0xFEF4, "alefmaksuramedialarabic");
      list.add(0xFB2E, "alefpatahhebrew");
      list.add(0xFB2F, "alefqamatshebrew");
      list.add(0x2135, "aleph");
      list.add(0x224C, "allequal");
      list.add(0x03B1, "alpha");
      list.add(0x03AC, "alphatonos");
      list.add(0x0101, "amacron");
      list.add(0xFF41, "amonospace");
      list.add(0x0026, "ampersand");
      list.add(0xFF06, "ampersandmonospace");
      list.add(0xF726, "ampersandsmall");
      list.add(0x33C2, "amsquare");
      list.add(0x3122, "anbopomofo");
      list.add(0x3124, "angbopomofo");
      list.add(0x0E5A, "angkhankhuthai");
      list.add(0x2220, "angle");
      list.add(0x3008, "anglebracketleft");
      list.add(0xFE3F, "anglebracketleftvertical");
      list.add(0x3009, "anglebracketright");
      list.add(0xFE40, "anglebracketrightvertical");
      list.add(0x2329, "angleleft");
      list.add(0x232A, "angleright");
      list.add(0x212B, "angstrom");
      list.add(0x0387, "anoteleia");
      list.add(0x0952, "anudattadeva");
      list.add(0x0982, "anusvarabengali");
      list.add(0x0902, "anusvaradeva");
      list.add(0x0A82, "anusvaragujarati");
      list.add(0x0105, "aogonek");
      list.add(0x3300, "apaatosquare");
      list.add(0x249C, "aparen");
      list.add(0x055A, "apostrophearmenian");
      list.add(0x02BC, "apostrophemod");
      list.add(0xF8FF, "apple");
      list.add(0x2250, "approaches");
      list.add(0x2248, "approxequal");
      list.add(0x2252, "approxequalorimage");
      list.add(0x2245, "approximatelyequal");
      list.add(0x318E, "araeaekorean");
      list.add(0x318D, "araeakorean");
      list.add(0x2312, "arc");
      list.add(0x1E9A, "arighthalfring");
      list.add(0x00E5, "aring");
      list.add(0x01FB, "aringacute");
      list.add(0x1E01, "aringbelow");
      list.add(0x2194, "arrowboth");
      list.add(0x21E3, "arrowdashdown");
      list.add(0x21E0, "arrowdashleft");
      list.add(0x21E2, "arrowdashright");
      list.add(0x21E1, "arrowdashup");
      list.add(0x21D4, "arrowdblboth");
      list.add(0x21D3, "arrowdbldown");
      list.add(0x21D0, "arrowdblleft");
      list.add(0x21D2, "arrowdblright");
      list.add(0x21D1, "arrowdblup");
      list.add(0x2193, "arrowdown");
      list.add(0x2199, "arrowdownleft");
      list.add(0x2198, "arrowdownright");
      list.add(0x21E9, "arrowdownwhite");
      list.add(0x02C5, "arrowheaddownmod");
      list.add(0x02C2, "arrowheadleftmod");
      list.add(0x02C3, "arrowheadrightmod");
      list.add(0x02C4, "arrowheadupmod");
      list.add(0xF8E7, "arrowhorizex");
      list.add(0x2190, "arrowleft");
      list.add(0x21D0, "arrowleftdbl");
      list.add(0x21CD, "arrowleftdblstroke");
      list.add(0x21C6, "arrowleftoverright");
      list.add(0x21E6, "arrowleftwhite");
      list.add(0x2192, "arrowright");
      list.add(0x21CF, "arrowrightdblstroke");
      list.add(0x279E, "arrowrightheavy");
      list.add(0x21C4, "arrowrightoverleft");
      list.add(0x21E8, "arrowrightwhite");
      list.add(0x21E4, "arrowtableft");
      list.add(0x21E5, "arrowtabright");
      list.add(0x2191, "arrowup");
      list.add(0x2195, "arrowupdn");
      list.add(0x21A8, "arrowupdnbse");
      list.add(0x21A8, "arrowupdownbase");
      list.add(0x2196, "arrowupleft");
      list.add(0x21C5, "arrowupleftofdown");
      list.add(0x2197, "arrowupright");
      list.add(0x21E7, "arrowupwhite");
      list.add(0xF8E6, "arrowvertex");
      list.add(0x005E, "asciicircum");
      list.add(0xFF3E, "asciicircummonospace");
      list.add(0x007E, "asciitilde");
      list.add(0xFF5E, "asciitildemonospace");
      list.add(0x0251, "ascript");
      list.add(0x0252, "ascriptturned");
      list.add(0x3041, "asmallhiragana");
      list.add(0x30A1, "asmallkatakana");
      list.add(0xFF67, "asmallkatakanahalfwidth");
      list.add(0x002A, "asterisk");
      list.add(0x066D, "asteriskaltonearabic");
      list.add(0x066D, "asteriskarabic");
      list.add(0x2217, "asteriskmath");
      list.add(0xFF0A, "asteriskmonospace");
      list.add(0xFE61, "asterisksmall");
      list.add(0x2042, "asterism");
      list.add(0xF6E9, "asuperior");
      list.add(0x2243, "asymptoticallyequal");
      list.add(0x0040, "at");
      list.add(0x00E3, "atilde");
      list.add(0xFF20, "atmonospace");
      list.add(0xFE6B, "atsmall");
      list.add(0x0250, "aturned");
      list.add(0x0994, "aubengali");
      list.add(0x3120, "aubopomofo");
      list.add(0x0914, "audeva");
      list.add(0x0A94, "augujarati");
      list.add(0x0A14, "augurmukhi");
      list.add(0x09D7, "aulengthmarkbengali");
      list.add(0x0A4C, "aumatragurmukhi");
      list.add(0x09CC, "auvowelsignbengali");
      list.add(0x094C, "auvowelsigndeva");
      list.add(0x0ACC, "auvowelsigngujarati");
      list.add(0x093D, "avagrahadeva");
      list.add(0x0561, "aybarmenian");
      list.add(0x05E2, "ayin");
      list.add(0xFB20, "ayinaltonehebrew");
      list.add(0x05E2, "ayinhebrew");
      list.add(0x0062, "b");
      list.add(0x09AC, "babengali");
      list.add(0x005C, "backslash");
      list.add(0xFF3C, "backslashmonospace");
      list.add(0x092C, "badeva");
      list.add(0x0AAC, "bagujarati");
      list.add(0x0A2C, "bagurmukhi");
      list.add(0x3070, "bahiragana");
      list.add(0x0E3F, "bahtthai");
      list.add(0x30D0, "bakatakana");
      list.add(0x007C, "bar");
      list.add(0xFF5C, "barmonospace");
      list.add(0x3105, "bbopomofo");
      list.add(0x24D1, "bcircle");
      list.add(0x1E03, "bdotaccent");
      list.add(0x1E05, "bdotbelow");
      list.add(0x266C, "beamedsixteenthnotes");
      list.add(0x2235, "because");
      list.add(0x0431, "becyrillic");
      list.add(0x0628, "beharabic");
      list.add(0xFE90, "behfinalarabic");
      list.add(0xFE91, "behinitialarabic");
      list.add(0x3079, "behiragana");
      list.add(0xFE92, "behmedialarabic");
      list.add(0xFC9F, "behmeeminitialarabic");
      list.add(0xFC08, "behmeemisolatedarabic");
      list.add(0xFC6D, "behnoonfinalarabic");
      list.add(0x30D9, "bekatakana");
      list.add(0x0562, "benarmenian");
      list.add(0x05D1, "bet");
      list.add(0x03B2, "beta");
      list.add(0x03D0, "betasymbolgreek");
      list.add(0xFB31, "betdagesh");
      list.add(0xFB31, "betdageshhebrew");
      list.add(0x05D1, "bethebrew");
      list.add(0xFB4C, "betrafehebrew");
      list.add(0x09AD, "bhabengali");
      list.add(0x092D, "bhadeva");
      list.add(0x0AAD, "bhagujarati");
      list.add(0x0A2D, "bhagurmukhi");
      list.add(0x0253, "bhook");
      list.add(0x3073, "bihiragana");
      list.add(0x30D3, "bikatakana");
      list.add(0x0298, "bilabialclick");
      list.add(0x0A02, "bindigurmukhi");
      list.add(0x3331, "birusquare");
      list.add(0x25CF, "blackcircle");
      list.add(0x25C6, "blackdiamond");
      list.add(0x25BC, "blackdownpointingtriangle");
      list.add(0x25C4, "blackleftpointingpointer");
      list.add(0x25C0, "blackleftpointingtriangle");
      list.add(0x3010, "blacklenticularbracketleft");
      list.add(0xFE3B, "blacklenticularbracketleftvertical");
      list.add(0x3011, "blacklenticularbracketright");
      list.add(0xFE3C, "blacklenticularbracketrightvertical");
      list.add(0x25E3, "blacklowerlefttriangle");
      list.add(0x25E2, "blacklowerrighttriangle");
      list.add(0x25AC, "blackrectangle");
      list.add(0x25BA, "blackrightpointingpointer");
      list.add(0x25B6, "blackrightpointingtriangle");
      list.add(0x25AA, "blacksmallsquare");
      list.add(0x263B, "blacksmilingface");
      list.add(0x25A0, "blacksquare");
      list.add(0x2605, "blackstar");
      list.add(0x25E4, "blackupperlefttriangle");
      list.add(0x25E5, "blackupperrighttriangle");
      list.add(0x25B4, "blackuppointingsmalltriangle");
      list.add(0x25B2, "blackuppointingtriangle");
      list.add(0x2423, "blank");
      list.add(0x1E07, "blinebelow");
      list.add(0x2588, "block");
      list.add(0xFF42, "bmonospace");
      list.add(0x0E1A, "bobaimaithai");
      list.add(0x307C, "bohiragana");
      list.add(0x30DC, "bokatakana");
      list.add(0x249D, "bparen");
      list.add(0x33C3, "bqsquare");
      list.add(0xF8F4, "braceex");
      list.add(0x007B, "braceleft");
      list.add(0xF8F3, "braceleftbt");
      list.add(0xF8F2, "braceleftmid");
      list.add(0xFF5B, "braceleftmonospace");
      list.add(0xFE5B, "braceleftsmall");
      list.add(0xF8F1, "bracelefttp");
      list.add(0xFE37, "braceleftvertical");
      list.add(0x007D, "braceright");
      list.add(0xF8FE, "bracerightbt");
      list.add(0xF8FD, "bracerightmid");
      list.add(0xFF5D, "bracerightmonospace");
      list.add(0xFE5C, "bracerightsmall");
      list.add(0xF8FC, "bracerighttp");
      list.add(0xFE38, "bracerightvertical");
      list.add(0x005B, "bracketleft");
      list.add(0xF8F0, "bracketleftbt");
      list.add(0xF8EF, "bracketleftex");
      list.add(0xFF3B, "bracketleftmonospace");
      list.add(0xF8EE, "bracketlefttp");
      list.add(0x005D, "bracketright");
      list.add(0xF8FB, "bracketrightbt");
      list.add(0xF8FA, "bracketrightex");
      list.add(0xFF3D, "bracketrightmonospace");
      list.add(0xF8F9, "bracketrighttp");
      list.add(0x02D8, "breve");
      list.add(0x032E, "brevebelowcmb");
      list.add(0x0306, "brevecmb");
      list.add(0x032F, "breveinvertedbelowcmb");
      list.add(0x0311, "breveinvertedcmb");
      list.add(0x0361, "breveinverteddoublecmb");
      list.add(0x032A, "bridgebelowcmb");
      list.add(0x033A, "bridgeinvertedbelowcmb");
      list.add(0x00A6, "brokenbar");
      list.add(0x0180, "bstroke");
      list.add(0xF6EA, "bsuperior");
      list.add(0x0183, "btopbar");
      list.add(0x3076, "buhiragana");
      list.add(0x30D6, "bukatakana");
      list.add(0x2022, "bullet");
      list.add(0x25D8, "bulletinverse");
      list.add(0x2219, "bulletoperator");
      list.add(0x25CE, "bullseye");
      list.add(0x0063, "c");
      list.add(0x056E, "caarmenian");
      list.add(0x099A, "cabengali");
      list.add(0x0107, "cacute");
      list.add(0x091A, "cadeva");
      list.add(0x0A9A, "cagujarati");
      list.add(0x0A1A, "cagurmukhi");
      list.add(0x3388, "calsquare");
      list.add(0x0981, "candrabindubengali");
      list.add(0x0310, "candrabinducmb");
      list.add(0x0901, "candrabindudeva");
      list.add(0x0A81, "candrabindugujarati");
      list.add(0x21EA, "capslock");
      list.add(0x2105, "careof");
      list.add(0x02C7, "caron");
      list.add(0x032C, "caronbelowcmb");
      list.add(0x030C, "caroncmb");
      list.add(0x21B5, "carriagereturn");
      list.add(0x3118, "cbopomofo");
      list.add(0x010D, "ccaron");
      list.add(0x00E7, "ccedilla");
      list.add(0x1E09, "ccedillaacute");
      list.add(0x24D2, "ccircle");
      list.add(0x0109, "ccircumflex");
      list.add(0x0255, "ccurl");
      list.add(0x010B, "cdot");
      list.add(0x010B, "cdotaccent");
      list.add(0x33C5, "cdsquare");
      list.add(0x00B8, "cedilla");
      list.add(0x0327, "cedillacmb");
      list.add(0x00A2, "cent");
      list.add(0x2103, "centigrade");
      list.add(0xF6DF, "centinferior");
      list.add(0xFFE0, "centmonospace");
      list.add(0xF7A2, "centoldstyle");
      list.add(0xF6E0, "centsuperior");
      list.add(0x0579, "chaarmenian");
      list.add(0x099B, "chabengali");
      list.add(0x091B, "chadeva");
      list.add(0x0A9B, "chagujarati");
      list.add(0x0A1B, "chagurmukhi");
      list.add(0x3114, "chbopomofo");
      list.add(0x04BD, "cheabkhasiancyrillic");
      list.add(0x2713, "checkmark");
      list.add(0x0447, "checyrillic");
      list.add(0x04BF, "chedescenderabkhasiancyrillic");
      list.add(0x04B7, "chedescendercyrillic");
      list.add(0x04F5, "chedieresiscyrillic");
      list.add(0x0573, "cheharmenian");
      list.add(0x04CC, "chekhakassiancyrillic");
      list.add(0x04B9, "cheverticalstrokecyrillic");
      list.add(0x03C7, "chi");
      list.add(0x3277, "chieuchacirclekorean");
      list.add(0x3217, "chieuchaparenkorean");
      list.add(0x3269, "chieuchcirclekorean");
      list.add(0x314A, "chieuchkorean");
      list.add(0x3209, "chieuchparenkorean");
      list.add(0x0E0A, "chochangthai");
      list.add(0x0E08, "chochanthai");
      list.add(0x0E09, "chochingthai");
      list.add(0x0E0C, "chochoethai");
      list.add(0x0188, "chook");
      list.add(0x3276, "cieucacirclekorean");
      list.add(0x3216, "cieucaparenkorean");
      list.add(0x3268, "cieuccirclekorean");
      list.add(0x3148, "cieuckorean");
      list.add(0x3208, "cieucparenkorean");
      list.add(0x321C, "cieucuparenkorean");
      list.add(0x25CB, "circle");
      list.add(0x2297, "circlemultiply");
      list.add(0x2299, "circleot");
      list.add(0x2295, "circleplus");
      list.add(0x3036, "circlepostalmark");
      list.add(0x25D0, "circlewithlefthalfblack");
      list.add(0x25D1, "circlewithrighthalfblack");
      list.add(0x02C6, "circumflex");
      list.add(0x032D, "circumflexbelowcmb");
      list.add(0x0302, "circumflexcmb");
      list.add(0x2327, "clear");
      list.add(0x01C2, "clickalveolar");
      list.add(0x01C0, "clickdental");
      list.add(0x01C1, "clicklateral");
      list.add(0x01C3, "clickretroflex");
      list.add(0x2663, "club");
      list.add(0x2663, "clubsuitblack");
      list.add(0x2667, "clubsuitwhite");
      list.add(0x33A4, "cmcubedsquare");
      list.add(0xFF43, "cmonospace");
      list.add(0x33A0, "cmsquaredsquare");
      list.add(0x0581, "coarmenian");
      list.add(0x003A, "colon");
      list.add(0x20A1, "colonmonetary");
      list.add(0xFF1A, "colonmonospace");
      list.add(0x20A1, "colonsign");
      list.add(0xFE55, "colonsmall");
      list.add(0x02D1, "colontriangularhalfmod");
      list.add(0x02D0, "colontriangularmod");
      list.add(0x002C, "comma");
      list.add(0x0313, "commaabovecmb");
      list.add(0x0315, "commaaboverightcmb");
      list.add(0xF6C3, "commaaccent");
      list.add(0x060C, "commaarabic");
      list.add(0x055D, "commaarmenian");
      list.add(0xF6E1, "commainferior");
      list.add(0xFF0C, "commamonospace");
      list.add(0x0314, "commareversedabovecmb");
      list.add(0x02BD, "commareversedmod");
      list.add(0xFE50, "commasmall");
      list.add(0xF6E2, "commasuperior");
      list.add(0x0312, "commaturnedabovecmb");
      list.add(0x02BB, "commaturnedmod");
      list.add(0x263C, "compass");
      list.add(0x2245, "congruent");
      list.add(0x222E, "contourintegral");
      list.add(0x2303, "control");
      list.add(0x0006, "controlACK");
      list.add(0x0007, "controlBEL");
      list.add(0x0008, "controlBS");
      list.add(0x0018, "controlCAN");
      list.add(0x000D, "controlCR");
      list.add(0x0011, "controlDC1");
      list.add(0x0012, "controlDC2");
      list.add(0x0013, "controlDC3");
      list.add(0x0014, "controlDC4");
      list.add(0x007F, "controlDEL");
      list.add(0x0010, "controlDLE");
      list.add(0x0019, "controlEM");
      list.add(0x0005, "controlENQ");
      list.add(0x0004, "controlEOT");
      list.add(0x001B, "controlESC");
      list.add(0x0017, "controlETB");
      list.add(0x0003, "controlETX");
      list.add(0x000C, "controlFF");
      list.add(0x001C, "controlFS");
      list.add(0x001D, "controlGS");
      list.add(0x0009, "controlHT");
      list.add(0x000A, "controlLF");
      list.add(0x0015, "controlNAK");
      list.add(0x001E, "controlRS");
      list.add(0x000F, "controlSI");
      list.add(0x000E, "controlSO");
      list.add(0x0002, "controlSOT");
      list.add(0x0001, "controlSTX");
      list.add(0x001A, "controlSUB");
      list.add(0x0016, "controlSYN");
      list.add(0x001F, "controlUS");
      list.add(0x000B, "controlVT");
      list.add(0x00A9, "copyright");
      list.add(0xF8E9, "copyrightsans");
      list.add(0xF6D9, "copyrightserif");
      list.add(0x300C, "cornerbracketleft");
      list.add(0xFF62, "cornerbracketlefthalfwidth");
      list.add(0xFE41, "cornerbracketleftvertical");
      list.add(0x300D, "cornerbracketright");
      list.add(0xFF63, "cornerbracketrighthalfwidth");
      list.add(0xFE42, "cornerbracketrightvertical");
      list.add(0x337F, "corporationsquare");
      list.add(0x33C7, "cosquare");
      list.add(0x33C6, "coverkgsquare");
      list.add(0x249E, "cparen");
      list.add(0x20A2, "cruzeiro");
      list.add(0x0297, "cstretched");
      list.add(0x22CF, "curlyand");
      list.add(0x22CE, "curlyor");
      list.add(0x00A4, "currency");
      list.add(0xF6D1, "cyrBreve");
      list.add(0xF6D2, "cyrFlex");
      list.add(0xF6D4, "cyrbreve");
      list.add(0xF6D5, "cyrflex");
      list.add(0x0064, "d");
      list.add(0x0564, "daarmenian");
      list.add(0x09A6, "dabengali");
      list.add(0x0636, "dadarabic");
      list.add(0x0926, "dadeva");
      list.add(0xFEBE, "dadfinalarabic");
      list.add(0xFEBF, "dadinitialarabic");
      list.add(0xFEC0, "dadmedialarabic");
      list.add(0x05BC, "dagesh");
      list.add(0x05BC, "dageshhebrew");
      list.add(0x2020, "dagger");
      list.add(0x2021, "daggerdbl");
      list.add(0x0AA6, "dagujarati");
      list.add(0x0A26, "dagurmukhi");
      list.add(0x3060, "dahiragana");
      list.add(0x30C0, "dakatakana");
      list.add(0x062F, "dalarabic");
      list.add(0x05D3, "dalet");
      list.add(0xFB33, "daletdagesh");
      list.add(0xFB33, "daletdageshhebrew");
      list.add(0x05D3, "dalethebrew");
      list.add(0xFEAA, "dalfinalarabic");
      list.add(0x064F, "dammaarabic");
      list.add(0x064F, "dammalowarabic");
      list.add(0x064C, "dammatanaltonearabic");
      list.add(0x064C, "dammatanarabic");
      list.add(0x0964, "danda");
      list.add(0x05A7, "dargahebrew");
      list.add(0x05A7, "dargalefthebrew");
      list.add(0x0485, "dasiapneumatacyrilliccmb");
      list.add(0xF6D3, "dblGrave");
      list.add(0x300A, "dblanglebracketleft");
      list.add(0xFE3D, "dblanglebracketleftvertical");
      list.add(0x300B, "dblanglebracketright");
      list.add(0xFE3E, "dblanglebracketrightvertical");
      list.add(0x032B, "dblarchinvertedbelowcmb");
      list.add(0x21D4, "dblarrowleft");
      list.add(0x21D2, "dblarrowright");
      list.add(0x0965, "dbldanda");
      list.add(0xF6D6, "dblgrave");
      list.add(0x030F, "dblgravecmb");
      list.add(0x222C, "dblintegral");
      list.add(0x2017, "dbllowline");
      list.add(0x0333, "dbllowlinecmb");
      list.add(0x033F, "dbloverlinecmb");
      list.add(0x02BA, "dblprimemod");
      list.add(0x2016, "dblverticalbar");
      list.add(0x030E, "dblverticallineabovecmb");
      list.add(0x3109, "dbopomofo");
      list.add(0x33C8, "dbsquare");
      list.add(0x010F, "dcaron");
      list.add(0x1E11, "dcedilla");
      list.add(0x24D3, "dcircle");
      list.add(0x1E13, "dcircumflexbelow");
      list.add(0x0111, "dcroat");
      list.add(0x09A1, "ddabengali");
      list.add(0x0921, "ddadeva");
      list.add(0x0AA1, "ddagujarati");
      list.add(0x0A21, "ddagurmukhi");
      list.add(0x0688, "ddalarabic");
      list.add(0xFB89, "ddalfinalarabic");
      list.add(0x095C, "dddhadeva");
      list.add(0x09A2, "ddhabengali");
      list.add(0x0922, "ddhadeva");
      list.add(0x0AA2, "ddhagujarati");
      list.add(0x0A22, "ddhagurmukhi");
      list.add(0x1E0B, "ddotaccent");
      list.add(0x1E0D, "ddotbelow");
      list.add(0x066B, "decimalseparatorarabic");
      list.add(0x066B, "decimalseparatorpersian");
      list.add(0x0434, "decyrillic");
      list.add(0x00B0, "degree");
      list.add(0x05AD, "dehihebrew");
      list.add(0x3067, "dehiragana");
      list.add(0x03EF, "deicoptic");
      list.add(0x30C7, "dekatakana");
      list.add(0x232B, "deleteleft");
      list.add(0x2326, "deleteright");
      list.add(0x03B4, "delta");
      list.add(0x018D, "deltaturned");
      list.add(0x09F8, "denominatorminusonenumeratorbengali");
      list.add(0x02A4, "dezh");
      list.add(0x09A7, "dhabengali");
      list.add(0x0927, "dhadeva");
      list.add(0x0AA7, "dhagujarati");
      list.add(0x0A27, "dhagurmukhi");
      list.add(0x0257, "dhook");
      list.add(0x0385, "dialytikatonos");
      list.add(0x0344, "dialytikatonoscmb");
      list.add(0x2666, "diamond");
      list.add(0x2662, "diamondsuitwhite");
      list.add(0x00A8, "dieresis");
      list.add(0xF6D7, "dieresisacute");
      list.add(0x0324, "dieresisbelowcmb");
      list.add(0x0308, "dieresiscmb");
      list.add(0xF6D8, "dieresisgrave");
      list.add(0x0385, "dieresistonos");
      list.add(0x3062, "dihiragana");
      list.add(0x30C2, "dikatakana");
      list.add(0x3003, "dittomark");
      list.add(0x00F7, "divide");
      list.add(0x2223, "divides");
      list.add(0x2215, "divisionslash");
      list.add(0x0452, "djecyrillic");
      list.add(0x2593, "dkshade");
      list.add(0x1E0F, "dlinebelow");
      list.add(0x3397, "dlsquare");
      list.add(0x0111, "dmacron");
      list.add(0xFF44, "dmonospace");
      list.add(0x2584, "dnblock");
      list.add(0x0E0E, "dochadathai");
      list.add(0x0E14, "dodekthai");
      list.add(0x3069, "dohiragana");
      list.add(0x30C9, "dokatakana");
      list.add(0x0024, "dollar");
      list.add(0xF6E3, "dollarinferior");
      list.add(0xFF04, "dollarmonospace");
      list.add(0xF724, "dollaroldstyle");
      list.add(0xFE69, "dollarsmall");
      list.add(0xF6E4, "dollarsuperior");
      list.add(0x20AB, "dong");
      list.add(0x3326, "dorusquare");
      list.add(0x02D9, "dotaccent");
      list.add(0x0307, "dotaccentcmb");
      list.add(0x0323, "dotbelowcmb");
      list.add(0x0323, "dotbelowcomb");
      list.add(0x30FB, "dotkatakana");
      list.add(0x0131, "dotlessi");
      list.add(0xF6BE, "dotlessj");
      list.add(0x0284, "dotlessjstrokehook");
      list.add(0x22C5, "dotmath");
      list.add(0x25CC, "dottedcircle");
      list.add(0xFB1F, "doubleyodpatah");
      list.add(0xFB1F, "doubleyodpatahhebrew");
      list.add(0x031E, "downtackbelowcmb");
      list.add(0x02D5, "downtackmod");
      list.add(0x249F, "dparen");
      list.add(0xF6EB, "dsuperior");
      list.add(0x0256, "dtail");
      list.add(0x018C, "dtopbar");
      list.add(0x3065, "duhiragana");
      list.add(0x30C5, "dukatakana");
      list.add(0x01F3, "dz");
      list.add(0x02A3, "dzaltone");
      list.add(0x01C6, "dzcaron");
      list.add(0x02A5, "dzcurl");
      list.add(0x04E1, "dzeabkhasiancyrillic");
      list.add(0x0455, "dzecyrillic");
      list.add(0x045F, "dzhecyrillic");
      list.add(0x0065, "e");
      list.add(0x00E9, "eacute");
      list.add(0x2641, "earth");
      list.add(0x098F, "ebengali");
      list.add(0x311C, "ebopomofo");
      list.add(0x0115, "ebreve");
      list.add(0x090D, "ecandradeva");
      list.add(0x0A8D, "ecandragujarati");
      list.add(0x0945, "ecandravowelsigndeva");
      list.add(0x0AC5, "ecandravowelsigngujarati");
      list.add(0x011B, "ecaron");
      list.add(0x1E1D, "ecedillabreve");
      list.add(0x0565, "echarmenian");
      list.add(0x0587, "echyiwnarmenian");
      list.add(0x24D4, "ecircle");
      list.add(0x00EA, "ecircumflex");
      list.add(0x1EBF, "ecircumflexacute");
      list.add(0x1E19, "ecircumflexbelow");
      list.add(0x1EC7, "ecircumflexdotbelow");
      list.add(0x1EC1, "ecircumflexgrave");
      list.add(0x1EC3, "ecircumflexhookabove");
      list.add(0x1EC5, "ecircumflextilde");
      list.add(0x0454, "ecyrillic");
      list.add(0x0205, "edblgrave");
      list.add(0x090F, "edeva");
      list.add(0x00EB, "edieresis");
      list.add(0x0117, "edot");
      list.add(0x0117, "edotaccent");
      list.add(0x1EB9, "edotbelow");
      list.add(0x0A0F, "eegurmukhi");
      list.add(0x0A47, "eematragurmukhi");
      list.add(0x0444, "efcyrillic");
      list.add(0x00E8, "egrave");
      list.add(0x0A8F, "egujarati");
      list.add(0x0567, "eharmenian");
      list.add(0x311D, "ehbopomofo");
      list.add(0x3048, "ehiragana");
      list.add(0x1EBB, "ehookabove");
      list.add(0x311F, "eibopomofo");
      list.add(0x0038, "eight");
      list.add(0x0668, "eightarabic");
      list.add(0x09EE, "eightbengali");
      list.add(0x2467, "eightcircle");
      list.add(0x2791, "eightcircleinversesansserif");
      list.add(0x096E, "eightdeva");
      list.add(0x2471, "eighteencircle");
      list.add(0x2485, "eighteenparen");
      list.add(0x2499, "eighteenperiod");
      list.add(0x0AEE, "eightgujarati");
      list.add(0x0A6E, "eightgurmukhi");
      list.add(0x0668, "eighthackarabic");
      list.add(0x3028, "eighthangzhou");
      list.add(0x266B, "eighthnotebeamed");
      list.add(0x3227, "eightideographicparen");
      list.add(0x2088, "eightinferior");
      list.add(0xFF18, "eightmonospace");
      list.add(0xF738, "eightoldstyle");
      list.add(0x247B, "eightparen");
      list.add(0x248F, "eightperiod");
      list.add(0x06F8, "eightpersian");
      list.add(0x2177, "eightroman");
      list.add(0x2078, "eightsuperior");
      list.add(0x0E58, "eightthai");
      list.add(0x0207, "einvertedbreve");
      list.add(0x0465, "eiotifiedcyrillic");
      list.add(0x30A8, "ekatakana");
      list.add(0xFF74, "ekatakanahalfwidth");
      list.add(0x0A74, "ekonkargurmukhi");
      list.add(0x3154, "ekorean");
      list.add(0x043B, "elcyrillic");
      list.add(0x2208, "element");
      list.add(0x246A, "elevencircle");
      list.add(0x247E, "elevenparen");
      list.add(0x2492, "elevenperiod");
      list.add(0x217A, "elevenroman");
      list.add(0x2026, "ellipsis");
      list.add(0x22EE, "ellipsisvertical");
      list.add(0x0113, "emacron");
      list.add(0x1E17, "emacronacute");
      list.add(0x1E15, "emacrongrave");
      list.add(0x043C, "emcyrillic");
      list.add(0x2014, "emdash");
      list.add(0xFE31, "emdashvertical");
      list.add(0xFF45, "emonospace");
      list.add(0x055B, "emphasismarkarmenian");
      list.add(0x2205, "emptyset");
      list.add(0x3123, "enbopomofo");
      list.add(0x043D, "encyrillic");
      list.add(0x2013, "endash");
      list.add(0xFE32, "endashvertical");
      list.add(0x04A3, "endescendercyrillic");
      list.add(0x014B, "eng");
      list.add(0x3125, "engbopomofo");
      list.add(0x04A5, "enghecyrillic");
      list.add(0x04C8, "enhookcyrillic");
      list.add(0x2002, "enspace");
      list.add(0x0119, "eogonek");
      list.add(0x3153, "eokorean");
      list.add(0x025B, "eopen");
      list.add(0x029A, "eopenclosed");
      list.add(0x025C, "eopenreversed");
      list.add(0x025E, "eopenreversedclosed");
      list.add(0x025D, "eopenreversedhook");
      list.add(0x24A0, "eparen");
      list.add(0x03B5, "epsilon");
      list.add(0x03AD, "epsilontonos");
      list.add(0x003D, "equal");
      list.add(0xFF1D, "equalmonospace");
      list.add(0xFE66, "equalsmall");
      list.add(0x207C, "equalsuperior");
      list.add(0x2261, "equivalence");
      list.add(0x3126, "erbopomofo");
      list.add(0x0440, "ercyrillic");
      list.add(0x0258, "ereversed");
      list.add(0x044D, "ereversedcyrillic");
      list.add(0x0441, "escyrillic");
      list.add(0x04AB, "esdescendercyrillic");
      list.add(0x0283, "esh");
      list.add(0x0286, "eshcurl");
      list.add(0x090E, "eshortdeva");
      list.add(0x0946, "eshortvowelsigndeva");
      list.add(0x01AA, "eshreversedloop");
      list.add(0x0285, "eshsquatreversed");
      list.add(0x3047, "esmallhiragana");
      list.add(0x30A7, "esmallkatakana");
      list.add(0xFF6A, "esmallkatakanahalfwidth");
      list.add(0x212E, "estimated");
      list.add(0xF6EC, "esuperior");
      list.add(0x03B7, "eta");
      list.add(0x0568, "etarmenian");
      list.add(0x03AE, "etatonos");
      list.add(0x00F0, "eth");
      list.add(0x1EBD, "etilde");
      list.add(0x1E1B, "etildebelow");
      list.add(0x0591, "etnahtafoukhhebrew");
      list.add(0x0591, "etnahtafoukhlefthebrew");
      list.add(0x0591, "etnahtahebrew");
      list.add(0x0591, "etnahtalefthebrew");
      list.add(0x01DD, "eturned");
      list.add(0x3161, "eukorean");
      list.add(0x20AC, "euro");
      list.add(0x09C7, "evowelsignbengali");
      list.add(0x0947, "evowelsigndeva");
      list.add(0x0AC7, "evowelsigngujarati");
      list.add(0x0021, "exclam");
      list.add(0x055C, "exclamarmenian");
      list.add(0x203C, "exclamdbl");
      list.add(0x00A1, "exclamdown");
      list.add(0xF7A1, "exclamdownsmall");
      list.add(0xFF01, "exclammonospace");
      list.add(0xF721, "exclamsmall");
      list.add(0x2203, "existential");
      list.add(0x0292, "ezh");
      list.add(0x01EF, "ezhcaron");
      list.add(0x0293, "ezhcurl");
      list.add(0x01B9, "ezhreversed");
      list.add(0x01BA, "ezhtail");
      list.add(0x0066, "f");
      list.add(0x095E, "fadeva");
      list.add(0x0A5E, "fagurmukhi");
      list.add(0x2109, "fahrenheit");
      list.add(0x064E, "fathaarabic");
      list.add(0x064E, "fathalowarabic");
      list.add(0x064B, "fathatanarabic");
      list.add(0x3108, "fbopomofo");
      list.add(0x24D5, "fcircle");
      list.add(0x1E1F, "fdotaccent");
      list.add(0x0641, "feharabic");
      list.add(0x0586, "feharmenian");
      list.add(0xFED2, "fehfinalarabic");
      list.add(0xFED3, "fehinitialarabic");
      list.add(0xFED4, "fehmedialarabic");
      list.add(0x03E5, "feicoptic");
      list.add(0x2640, "female");
      list.add(0xFB00, "ff");
      list.add(0xFB03, "ffi");
      list.add(0xFB04, "ffl");
      list.add(0xFB01, "fi");
      list.add(0x246E, "fifteencircle");
      list.add(0x2482, "fifteenparen");
      list.add(0x2496, "fifteenperiod");
      list.add(0x2012, "figuredash");
      list.add(0x25A0, "filledbox");
      list.add(0x25AC, "filledrect");
      list.add(0x05DA, "finalkaf");
      list.add(0xFB3A, "finalkafdagesh");
      list.add(0xFB3A, "finalkafdageshhebrew");
      list.add(0x05DA, "finalkafhebrew");
      list.add(0x05DD, "finalmem");
      list.add(0x05DD, "finalmemhebrew");
      list.add(0x05DF, "finalnun");
      list.add(0x05DF, "finalnunhebrew");
      list.add(0x05E3, "finalpe");
      list.add(0x05E3, "finalpehebrew");
      list.add(0x05E5, "finaltsadi");
      list.add(0x05E5, "finaltsadihebrew");
      list.add(0x02C9, "firsttonechinese");
      list.add(0x25C9, "fisheye");
      list.add(0x0473, "fitacyrillic");
      list.add(0x0035, "five");
      list.add(0x0665, "fivearabic");
      list.add(0x09EB, "fivebengali");
      list.add(0x2464, "fivecircle");
      list.add(0x278E, "fivecircleinversesansserif");
      list.add(0x096B, "fivedeva");
      list.add(0x215D, "fiveeighths");
      list.add(0x0AEB, "fivegujarati");
      list.add(0x0A6B, "fivegurmukhi");
      list.add(0x0665, "fivehackarabic");
      list.add(0x3025, "fivehangzhou");
      list.add(0x3224, "fiveideographicparen");
      list.add(0x2085, "fiveinferior");
      list.add(0xFF15, "fivemonospace");
      list.add(0xF735, "fiveoldstyle");
      list.add(0x2478, "fiveparen");
      list.add(0x248C, "fiveperiod");
      list.add(0x06F5, "fivepersian");
      list.add(0x2174, "fiveroman");
      list.add(0x2075, "fivesuperior");
      list.add(0x0E55, "fivethai");
      list.add(0xFB02, "fl");
      list.add(0x0192, "florin");
      list.add(0xFF46, "fmonospace");
      list.add(0x3399, "fmsquare");
      list.add(0x0E1F, "fofanthai");
      list.add(0x0E1D, "fofathai");
      list.add(0x0E4F, "fongmanthai");
      list.add(0x2200, "forall");
      list.add(0x0034, "four");
      list.add(0x0664, "fourarabic");
      list.add(0x09EA, "fourbengali");
      list.add(0x2463, "fourcircle");
      list.add(0x278D, "fourcircleinversesansserif");
      list.add(0x096A, "fourdeva");
      list.add(0x0AEA, "fourgujarati");
      list.add(0x0A6A, "fourgurmukhi");
      list.add(0x0664, "fourhackarabic");
      list.add(0x3024, "fourhangzhou");
      list.add(0x3223, "fourideographicparen");
      list.add(0x2084, "fourinferior");
      list.add(0xFF14, "fourmonospace");
      list.add(0x09F7, "fournumeratorbengali");
      list.add(0xF734, "fouroldstyle");
      list.add(0x2477, "fourparen");
      list.add(0x248B, "fourperiod");
      list.add(0x06F4, "fourpersian");
      list.add(0x2173, "fourroman");
      list.add(0x2074, "foursuperior");
      list.add(0x246D, "fourteencircle");
      list.add(0x2481, "fourteenparen");
      list.add(0x2495, "fourteenperiod");
      list.add(0x0E54, "fourthai");
      list.add(0x02CB, "fourthtonechinese");
      list.add(0x24A1, "fparen");
      list.add(0x2044, "fraction");
      list.add(0x20A3, "franc");
      list.add(0x0067, "g");
      list.add(0x0997, "gabengali");
      list.add(0x01F5, "gacute");
      list.add(0x0917, "gadeva");
      list.add(0x06AF, "gafarabic");
      list.add(0xFB93, "gaffinalarabic");
      list.add(0xFB94, "gafinitialarabic");
      list.add(0xFB95, "gafmedialarabic");
      list.add(0x0A97, "gagujarati");
      list.add(0x0A17, "gagurmukhi");
      list.add(0x304C, "gahiragana");
      list.add(0x30AC, "gakatakana");
      list.add(0x03B3, "gamma");
      list.add(0x0263, "gammalatinsmall");
      list.add(0x02E0, "gammasuperior");
      list.add(0x03EB, "gangiacoptic");
      list.add(0x310D, "gbopomofo");
      list.add(0x011F, "gbreve");
      list.add(0x01E7, "gcaron");
      list.add(0x0123, "gcedilla");
      list.add(0x24D6, "gcircle");
      list.add(0x011D, "gcircumflex");
      list.add(0x0123, "gcommaaccent");
      list.add(0x0121, "gdot");
      list.add(0x0121, "gdotaccent");
      list.add(0x0433, "gecyrillic");
      list.add(0x3052, "gehiragana");
      list.add(0x30B2, "gekatakana");
      list.add(0x2251, "geometricallyequal");
      list.add(0x059C, "gereshaccenthebrew");
      list.add(0x05F3, "gereshhebrew");
      list.add(0x059D, "gereshmuqdamhebrew");
      list.add(0x00DF, "germandbls");
      list.add(0x059E, "gershayimaccenthebrew");
      list.add(0x05F4, "gershayimhebrew");
      list.add(0x3013, "getamark");
      list.add(0x0998, "ghabengali");
      list.add(0x0572, "ghadarmenian");
      list.add(0x0918, "ghadeva");
      list.add(0x0A98, "ghagujarati");
      list.add(0x0A18, "ghagurmukhi");
      list.add(0x063A, "ghainarabic");
      list.add(0xFECE, "ghainfinalarabic");
      list.add(0xFECF, "ghaininitialarabic");
      list.add(0xFED0, "ghainmedialarabic");
      list.add(0x0495, "ghemiddlehookcyrillic");
      list.add(0x0493, "ghestrokecyrillic");
      list.add(0x0491, "gheupturncyrillic");
      list.add(0x095A, "ghhadeva");
      list.add(0x0A5A, "ghhagurmukhi");
      list.add(0x0260, "ghook");
      list.add(0x3393, "ghzsquare");
      list.add(0x304E, "gihiragana");
      list.add(0x30AE, "gikatakana");
      list.add(0x0563, "gimarmenian");
      list.add(0x05D2, "gimel");
      list.add(0xFB32, "gimeldagesh");
      list.add(0xFB32, "gimeldageshhebrew");
      list.add(0x05D2, "gimelhebrew");
      list.add(0x0453, "gjecyrillic");
      list.add(0x01BE, "glottalinvertedstroke");
      list.add(0x0294, "glottalstop");
      list.add(0x0296, "glottalstopinverted");
      list.add(0x02C0, "glottalstopmod");
      list.add(0x0295, "glottalstopreversed");
      list.add(0x02C1, "glottalstopreversedmod");
      list.add(0x02E4, "glottalstopreversedsuperior");
      list.add(0x02A1, "glottalstopstroke");
      list.add(0x02A2, "glottalstopstrokereversed");
      list.add(0x1E21, "gmacron");
      list.add(0xFF47, "gmonospace");
      list.add(0x3054, "gohiragana");
      list.add(0x30B4, "gokatakana");
      list.add(0x24A2, "gparen");
      list.add(0x33AC, "gpasquare");
      list.add(0x2207, "gradient");
      list.add(0x0060, "grave");
      list.add(0x0316, "gravebelowcmb");
      list.add(0x0300, "gravecmb");
      list.add(0x0300, "gravecomb");
      list.add(0x0953, "gravedeva");
      list.add(0x02CE, "gravelowmod");
      list.add(0xFF40, "gravemonospace");
      list.add(0x0340, "gravetonecmb");
      list.add(0x003E, "greater");
      list.add(0x2265, "greaterequal");
      list.add(0x22DB, "greaterequalorless");
      list.add(0xFF1E, "greatermonospace");
      list.add(0x2273, "greaterorequivalent");
      list.add(0x2277, "greaterorless");
      list.add(0x2267, "greateroverequal");
      list.add(0xFE65, "greatersmall");
      list.add(0x0261, "gscript");
      list.add(0x01E5, "gstroke");
      list.add(0x3050, "guhiragana");
      list.add(0x00AB, "guillemotleft");
      list.add(0x00BB, "guillemotright");
      list.add(0x2039, "guilsinglleft");
      list.add(0x203A, "guilsinglright");
      list.add(0x30B0, "gukatakana");
      list.add(0x3318, "guramusquare");
      list.add(0x33C9, "gysquare");
      list.add(0x0068, "h");
      list.add(0x04A9, "haabkhasiancyrillic");
      list.add(0x06C1, "haaltonearabic");
      list.add(0x09B9, "habengali");
      list.add(0x04B3, "hadescendercyrillic");
      list.add(0x0939, "hadeva");
      list.add(0x0AB9, "hagujarati");
      list.add(0x0A39, "hagurmukhi");
      list.add(0x062D, "haharabic");
      list.add(0xFEA2, "hahfinalarabic");
      list.add(0xFEA3, "hahinitialarabic");
      list.add(0x306F, "hahiragana");
      list.add(0xFEA4, "hahmedialarabic");
      list.add(0x332A, "haitusquare");
      list.add(0x30CF, "hakatakana");
      list.add(0xFF8A, "hakatakanahalfwidth");
      list.add(0x0A4D, "halantgurmukhi");
      list.add(0x0621, "hamzaarabic");
      list.add(0x0621, "hamzalowarabic");
      list.add(0x3164, "hangulfiller");
      list.add(0x044A, "hardsigncyrillic");
      list.add(0x21BC, "harpoonleftbarbup");
      list.add(0x21C0, "harpoonrightbarbup");
      list.add(0x33CA, "hasquare");
      list.add(0x05B2, "hatafpatah");
      list.add(0x05B2, "hatafpatah16");
      list.add(0x05B2, "hatafpatah23");
      list.add(0x05B2, "hatafpatah2f");
      list.add(0x05B2, "hatafpatahhebrew");
      list.add(0x05B2, "hatafpatahnarrowhebrew");
      list.add(0x05B2, "hatafpatahquarterhebrew");
      list.add(0x05B2, "hatafpatahwidehebrew");
      list.add(0x05B3, "hatafqamats");
      list.add(0x05B3, "hatafqamats1b");
      list.add(0x05B3, "hatafqamats28");
      list.add(0x05B3, "hatafqamats34");
      list.add(0x05B3, "hatafqamatshebrew");
      list.add(0x05B3, "hatafqamatsnarrowhebrew");
      list.add(0x05B3, "hatafqamatsquarterhebrew");
      list.add(0x05B3, "hatafqamatswidehebrew");
      list.add(0x05B1, "hatafsegol");
      list.add(0x05B1, "hatafsegol17");
      list.add(0x05B1, "hatafsegol24");
      list.add(0x05B1, "hatafsegol30");
      list.add(0x05B1, "hatafsegolhebrew");
      list.add(0x05B1, "hatafsegolnarrowhebrew");
      list.add(0x05B1, "hatafsegolquarterhebrew");
      list.add(0x05B1, "hatafsegolwidehebrew");
      list.add(0x0127, "hbar");
      list.add(0x310F, "hbopomofo");
      list.add(0x1E2B, "hbrevebelow");
      list.add(0x1E29, "hcedilla");
      list.add(0x24D7, "hcircle");
      list.add(0x0125, "hcircumflex");
      list.add(0x1E27, "hdieresis");
      list.add(0x1E23, "hdotaccent");
      list.add(0x1E25, "hdotbelow");
      list.add(0x05D4, "he");
      list.add(0x2665, "heart");
      list.add(0x2665, "heartsuitblack");
      list.add(0x2661, "heartsuitwhite");
      list.add(0xFB34, "hedagesh");
      list.add(0xFB34, "hedageshhebrew");
      list.add(0x06C1, "hehaltonearabic");
      list.add(0x0647, "heharabic");
      list.add(0x05D4, "hehebrew");
      list.add(0xFBA7, "hehfinalaltonearabic");
      list.add(0xFEEA, "hehfinalalttwoarabic");
      list.add(0xFEEA, "hehfinalarabic");
      list.add(0xFBA5, "hehhamzaabovefinalarabic");
      list.add(0xFBA4, "hehhamzaaboveisolatedarabic");
      list.add(0xFBA8, "hehinitialaltonearabic");
      list.add(0xFEEB, "hehinitialarabic");
      list.add(0x3078, "hehiragana");
      list.add(0xFBA9, "hehmedialaltonearabic");
      list.add(0xFEEC, "hehmedialarabic");
      list.add(0x337B, "heiseierasquare");
      list.add(0x30D8, "hekatakana");
      list.add(0xFF8D, "hekatakanahalfwidth");
      list.add(0x3336, "hekutaarusquare");
      list.add(0x0267, "henghook");
      list.add(0x3339, "herutusquare");
      list.add(0x05D7, "het");
      list.add(0x05D7, "hethebrew");
      list.add(0x0266, "hhook");
      list.add(0x02B1, "hhooksuperior");
      list.add(0x327B, "hieuhacirclekorean");
      list.add(0x321B, "hieuhaparenkorean");
      list.add(0x326D, "hieuhcirclekorean");
      list.add(0x314E, "hieuhkorean");
      list.add(0x320D, "hieuhparenkorean");
      list.add(0x3072, "hihiragana");
      list.add(0x30D2, "hikatakana");
      list.add(0xFF8B, "hikatakanahalfwidth");
      list.add(0x05B4, "hiriq");
      list.add(0x05B4, "hiriq14");
      list.add(0x05B4, "hiriq21");
      list.add(0x05B4, "hiriq2d");
      list.add(0x05B4, "hiriqhebrew");
      list.add(0x05B4, "hiriqnarrowhebrew");
      list.add(0x05B4, "hiriqquarterhebrew");
      list.add(0x05B4, "hiriqwidehebrew");
      list.add(0x1E96, "hlinebelow");
      list.add(0xFF48, "hmonospace");
      list.add(0x0570, "hoarmenian");
      list.add(0x0E2B, "hohipthai");
      list.add(0x307B, "hohiragana");
      list.add(0x30DB, "hokatakana");
      list.add(0xFF8E, "hokatakanahalfwidth");
      list.add(0x05B9, "holam");
      list.add(0x05B9, "holam19");
      list.add(0x05B9, "holam26");
      list.add(0x05B9, "holam32");
      list.add(0x05B9, "holamhebrew");
      list.add(0x05B9, "holamnarrowhebrew");
      list.add(0x05B9, "holamquarterhebrew");
      list.add(0x05B9, "holamwidehebrew");
      list.add(0x0E2E, "honokhukthai");
      list.add(0x0309, "hookabovecomb");
      list.add(0x0309, "hookcmb");
      list.add(0x0321, "hookpalatalizedbelowcmb");
      list.add(0x0322, "hookretroflexbelowcmb");
      list.add(0x3342, "hoonsquare");
      list.add(0x03E9, "horicoptic");
      list.add(0x2015, "horizontalbar");
      list.add(0x031B, "horncmb");
      list.add(0x2668, "hotsprings");
      list.add(0x2302, "house");
      list.add(0x24A3, "hparen");
      list.add(0x02B0, "hsuperior");
      list.add(0x0265, "hturned");
      list.add(0x3075, "huhiragana");
      list.add(0x3333, "huiitosquare");
      list.add(0x30D5, "hukatakana");
      list.add(0xFF8C, "hukatakanahalfwidth");
      list.add(0x02DD, "hungarumlaut");
      list.add(0x030B, "hungarumlautcmb");
      list.add(0x0195, "hv");
      list.add(0x002D, "hyphen");
      list.add(0xF6E5, "hypheninferior");
      list.add(0xFF0D, "hyphenmonospace");
      list.add(0xFE63, "hyphensmall");
      list.add(0xF6E6, "hyphensuperior");
      list.add(0x2010, "hyphentwo");
      list.add(0x0069, "i");
      list.add(0x00ED, "iacute");
      list.add(0x044F, "iacyrillic");
      list.add(0x0987, "ibengali");
      list.add(0x3127, "ibopomofo");
      list.add(0x012D, "ibreve");
      list.add(0x01D0, "icaron");
      list.add(0x24D8, "icircle");
      list.add(0x00EE, "icircumflex");
      list.add(0x0456, "icyrillic");
      list.add(0x0209, "idblgrave");
      list.add(0x328F, "ideographearthcircle");
      list.add(0x328B, "ideographfirecircle");
      list.add(0x323F, "ideographicallianceparen");
      list.add(0x323A, "ideographiccallparen");
      list.add(0x32A5, "ideographiccentrecircle");
      list.add(0x3006, "ideographicclose");
      list.add(0x3001, "ideographiccomma");
      list.add(0xFF64, "ideographiccommaleft");
      list.add(0x3237, "ideographiccongratulationparen");
      list.add(0x32A3, "ideographiccorrectcircle");
      list.add(0x322F, "ideographicearthparen");
      list.add(0x323D, "ideographicenterpriseparen");
      list.add(0x329D, "ideographicexcellentcircle");
      list.add(0x3240, "ideographicfestivalparen");
      list.add(0x3296, "ideographicfinancialcircle");
      list.add(0x3236, "ideographicfinancialparen");
      list.add(0x322B, "ideographicfireparen");
      list.add(0x3232, "ideographichaveparen");
      list.add(0x32A4, "ideographichighcircle");
      list.add(0x3005, "ideographiciterationmark");
      list.add(0x3298, "ideographiclaborcircle");
      list.add(0x3238, "ideographiclaborparen");
      list.add(0x32A7, "ideographicleftcircle");
      list.add(0x32A6, "ideographiclowcircle");
      list.add(0x32A9, "ideographicmedicinecircle");
      list.add(0x322E, "ideographicmetalparen");
      list.add(0x322A, "ideographicmoonparen");
      list.add(0x3234, "ideographicnameparen");
      list.add(0x3002, "ideographicperiod");
      list.add(0x329E, "ideographicprintcircle");
      list.add(0x3243, "ideographicreachparen");
      list.add(0x3239, "ideographicrepresentparen");
      list.add(0x323E, "ideographicresourceparen");
      list.add(0x32A8, "ideographicrightcircle");
      list.add(0x3299, "ideographicsecretcircle");
      list.add(0x3242, "ideographicselfparen");
      list.add(0x3233, "ideographicsocietyparen");
      list.add(0x3000, "ideographicspace");
      list.add(0x3235, "ideographicspecialparen");
      list.add(0x3231, "ideographicstockparen");
      list.add(0x323B, "ideographicstudyparen");
      list.add(0x3230, "ideographicsunparen");
      list.add(0x323C, "ideographicsuperviseparen");
      list.add(0x322C, "ideographicwaterparen");
      list.add(0x322D, "ideographicwoodparen");
      list.add(0x3007, "ideographiczero");
      list.add(0x328E, "ideographmetalcircle");
      list.add(0x328A, "ideographmooncircle");
      list.add(0x3294, "ideographnamecircle");
      list.add(0x3290, "ideographsuncircle");
      list.add(0x328C, "ideographwatercircle");
      list.add(0x328D, "ideographwoodcircle");
      list.add(0x0907, "ideva");
      list.add(0x00EF, "idieresis");
      list.add(0x1E2F, "idieresisacute");
      list.add(0x04E5, "idieresiscyrillic");
      list.add(0x1ECB, "idotbelow");
      list.add(0x04D7, "iebrevecyrillic");
      list.add(0x0435, "iecyrillic");
      list.add(0x3275, "ieungacirclekorean");
      list.add(0x3215, "ieungaparenkorean");
      list.add(0x3267, "ieungcirclekorean");
      list.add(0x3147, "ieungkorean");
      list.add(0x3207, "ieungparenkorean");
      list.add(0x00EC, "igrave");
      list.add(0x0A87, "igujarati");
      list.add(0x0A07, "igurmukhi");
      list.add(0x3044, "ihiragana");
      list.add(0x1EC9, "ihookabove");
      list.add(0x0988, "iibengali");
      list.add(0x0438, "iicyrillic");
      list.add(0x0908, "iideva");
      list.add(0x0A88, "iigujarati");
      list.add(0x0A08, "iigurmukhi");
      list.add(0x0A40, "iimatragurmukhi");
      list.add(0x020B, "iinvertedbreve");
      list.add(0x0439, "iishortcyrillic");
      list.add(0x09C0, "iivowelsignbengali");
      list.add(0x0940, "iivowelsigndeva");
      list.add(0x0AC0, "iivowelsigngujarati");
      list.add(0x0133, "ij");
      list.add(0x30A4, "ikatakana");
      list.add(0xFF72, "ikatakanahalfwidth");
      list.add(0x3163, "ikorean");
      list.add(0x02DC, "ilde");
      list.add(0x05AC, "iluyhebrew");
      list.add(0x012B, "imacron");
      list.add(0x04E3, "imacroncyrillic");
      list.add(0x2253, "imageorapproximatelyequal");
      list.add(0x0A3F, "imatragurmukhi");
      list.add(0xFF49, "imonospace");
      list.add(0x2206, "increment");
      list.add(0x221E, "infinity");
      list.add(0x056B, "iniarmenian");
      list.add(0x222B, "integral");
      list.add(0x2321, "integralbottom");
      list.add(0x2321, "integralbt");
      list.add(0xF8F5, "integralex");
      list.add(0x2320, "integraltop");
      list.add(0x2320, "integraltp");
      list.add(0x2229, "intersection");
      list.add(0x3305, "intisquare");
      list.add(0x25D8, "invbullet");
      list.add(0x25D9, "invcircle");
      list.add(0x263B, "invsmileface");
      list.add(0x0451, "iocyrillic");
      list.add(0x012F, "iogonek");
      list.add(0x03B9, "iota");
      list.add(0x03CA, "iotadieresis");
      list.add(0x0390, "iotadieresistonos");
      list.add(0x0269, "iotalatin");
      list.add(0x03AF, "iotatonos");
      list.add(0x24A4, "iparen");
      list.add(0x0A72, "irigurmukhi");
      list.add(0x3043, "ismallhiragana");
      list.add(0x30A3, "ismallkatakana");
      list.add(0xFF68, "ismallkatakanahalfwidth");
      list.add(0x09FA, "issharbengali");
      list.add(0x0268, "istroke");
      list.add(0xF6ED, "isuperior");
      list.add(0x309D, "iterationhiragana");
      list.add(0x30FD, "iterationkatakana");
      list.add(0x0129, "itilde");
      list.add(0x1E2D, "itildebelow");
      list.add(0x3129, "iubopomofo");
      list.add(0x044E, "iucyrillic");
      list.add(0x09BF, "ivowelsignbengali");
      list.add(0x093F, "ivowelsigndeva");
      list.add(0x0ABF, "ivowelsigngujarati");
      list.add(0x0475, "izhitsacyrillic");
      list.add(0x0477, "izhitsadblgravecyrillic");
      list.add(0x006A, "j");
      list.add(0x0571, "jaarmenian");
      list.add(0x099C, "jabengali");
      list.add(0x091C, "jadeva");
      list.add(0x0A9C, "jagujarati");
      list.add(0x0A1C, "jagurmukhi");
      list.add(0x3110, "jbopomofo");
      list.add(0x01F0, "jcaron");
      list.add(0x24D9, "jcircle");
      list.add(0x0135, "jcircumflex");
      list.add(0x029D, "jcrossedtail");
      list.add(0x025F, "jdotlessstroke");
      list.add(0x0458, "jecyrillic");
      list.add(0x062C, "jeemarabic");
      list.add(0xFE9E, "jeemfinalarabic");
      list.add(0xFE9F, "jeeminitialarabic");
      list.add(0xFEA0, "jeemmedialarabic");
      list.add(0x0698, "jeharabic");
      list.add(0xFB8B, "jehfinalarabic");
      list.add(0x099D, "jhabengali");
      list.add(0x091D, "jhadeva");
      list.add(0x0A9D, "jhagujarati");
      list.add(0x0A1D, "jhagurmukhi");
      list.add(0x057B, "jheharmenian");
      list.add(0x3004, "jis");
      list.add(0xFF4A, "jmonospace");
      list.add(0x24A5, "jparen");
      list.add(0x02B2, "jsuperior");
      list.add(0x006B, "k");
      list.add(0x04A1, "kabashkircyrillic");
      list.add(0x0995, "kabengali");
      list.add(0x1E31, "kacute");
      list.add(0x043A, "kacyrillic");
      list.add(0x049B, "kadescendercyrillic");
      list.add(0x0915, "kadeva");
      list.add(0x05DB, "kaf");
      list.add(0x0643, "kafarabic");
      list.add(0xFB3B, "kafdagesh");
      list.add(0xFB3B, "kafdageshhebrew");
      list.add(0xFEDA, "kaffinalarabic");
      list.add(0x05DB, "kafhebrew");
      list.add(0xFEDB, "kafinitialarabic");
      list.add(0xFEDC, "kafmedialarabic");
      list.add(0xFB4D, "kafrafehebrew");
      list.add(0x0A95, "kagujarati");
      list.add(0x0A15, "kagurmukhi");
      list.add(0x304B, "kahiragana");
      list.add(0x04C4, "kahookcyrillic");
      list.add(0x30AB, "kakatakana");
      list.add(0xFF76, "kakatakanahalfwidth");
      list.add(0x03BA, "kappa");
      list.add(0x03F0, "kappasymbolgreek");
      list.add(0x3171, "kapyeounmieumkorean");
      list.add(0x3184, "kapyeounphieuphkorean");
      list.add(0x3178, "kapyeounpieupkorean");
      list.add(0x3179, "kapyeounssangpieupkorean");
      list.add(0x330D, "karoriisquare");
      list.add(0x0640, "kashidaautoarabic");
      list.add(0x0640, "kashidaautonosidebearingarabic");
      list.add(0x30F5, "kasmallkatakana");
      list.add(0x3384, "kasquare");
      list.add(0x0650, "kasraarabic");
      list.add(0x064D, "kasratanarabic");
      list.add(0x049F, "kastrokecyrillic");
      list.add(0xFF70, "katahiraprolongmarkhalfwidth");
      list.add(0x049D, "kaverticalstrokecyrillic");
      list.add(0x310E, "kbopomofo");
      list.add(0x3389, "kcalsquare");
      list.add(0x01E9, "kcaron");
      list.add(0x0137, "kcedilla");
      list.add(0x24DA, "kcircle");
      list.add(0x0137, "kcommaaccent");
      list.add(0x1E33, "kdotbelow");
      list.add(0x0584, "keharmenian");
      list.add(0x3051, "kehiragana");
      list.add(0x30B1, "kekatakana");
      list.add(0xFF79, "kekatakanahalfwidth");
      list.add(0x056F, "kenarmenian");
      list.add(0x30F6, "kesmallkatakana");
      list.add(0x0138, "kgreenlandic");
      list.add(0x0996, "khabengali");
      list.add(0x0445, "khacyrillic");
      list.add(0x0916, "khadeva");
      list.add(0x0A96, "khagujarati");
      list.add(0x0A16, "khagurmukhi");
      list.add(0x062E, "khaharabic");
      list.add(0xFEA6, "khahfinalarabic");
      list.add(0xFEA7, "khahinitialarabic");
      list.add(0xFEA8, "khahmedialarabic");
      list.add(0x03E7, "kheicoptic");
      list.add(0x0959, "khhadeva");
      list.add(0x0A59, "khhagurmukhi");
      list.add(0x3278, "khieukhacirclekorean");
      list.add(0x3218, "khieukhaparenkorean");
      list.add(0x326A, "khieukhcirclekorean");
      list.add(0x314B, "khieukhkorean");
      list.add(0x320A, "khieukhparenkorean");
      list.add(0x0E02, "khokhaithai");
      list.add(0x0E05, "khokhonthai");
      list.add(0x0E03, "khokhuatthai");
      list.add(0x0E04, "khokhwaithai");
      list.add(0x0E5B, "khomutthai");
      list.add(0x0199, "khook");
      list.add(0x0E06, "khorakhangthai");
      list.add(0x3391, "khzsquare");
      list.add(0x304D, "kihiragana");
      list.add(0x30AD, "kikatakana");
      list.add(0xFF77, "kikatakanahalfwidth");
      list.add(0x3315, "kiroguramusquare");
      list.add(0x3316, "kiromeetorusquare");
      list.add(0x3314, "kirosquare");
      list.add(0x326E, "kiyeokacirclekorean");
      list.add(0x320E, "kiyeokaparenkorean");
      list.add(0x3260, "kiyeokcirclekorean");
      list.add(0x3131, "kiyeokkorean");
      list.add(0x3200, "kiyeokparenkorean");
      list.add(0x3133, "kiyeoksioskorean");
      list.add(0x045C, "kjecyrillic");
      list.add(0x1E35, "klinebelow");
      list.add(0x3398, "klsquare");
      list.add(0x33A6, "kmcubedsquare");
      list.add(0xFF4B, "kmonospace");
      list.add(0x33A2, "kmsquaredsquare");
      list.add(0x3053, "kohiragana");
      list.add(0x33C0, "kohmsquare");
      list.add(0x0E01, "kokaithai");
      list.add(0x30B3, "kokatakana");
      list.add(0xFF7A, "kokatakanahalfwidth");
      list.add(0x331E, "kooposquare");
      list.add(0x0481, "koppacyrillic");
      list.add(0x327F, "koreanstandardsymbol");
      list.add(0x0343, "koroniscmb");
      list.add(0x24A6, "kparen");
      list.add(0x33AA, "kpasquare");
      list.add(0x046F, "ksicyrillic");
      list.add(0x33CF, "ktsquare");
      list.add(0x029E, "kturned");
      list.add(0x304F, "kuhiragana");
      list.add(0x30AF, "kukatakana");
      list.add(0xFF78, "kukatakanahalfwidth");
      list.add(0x33B8, "kvsquare");
      list.add(0x33BE, "kwsquare");
      list.add(0x006C, "l");
      list.add(0x09B2, "labengali");
      list.add(0x013A, "lacute");
      list.add(0x0932, "ladeva");
      list.add(0x0AB2, "lagujarati");
      list.add(0x0A32, "lagurmukhi");
      list.add(0x0E45, "lakkhangyaothai");
      list.add(0xFEFC, "lamaleffinalarabic");
      list.add(0xFEF8, "lamalefhamzaabovefinalarabic");
      list.add(0xFEF7, "lamalefhamzaaboveisolatedarabic");
      list.add(0xFEFA, "lamalefhamzabelowfinalarabic");
      list.add(0xFEF9, "lamalefhamzabelowisolatedarabic");
      list.add(0xFEFB, "lamalefisolatedarabic");
      list.add(0xFEF6, "lamalefmaddaabovefinalarabic");
      list.add(0xFEF5, "lamalefmaddaaboveisolatedarabic");
      list.add(0x0644, "lamarabic");
      list.add(0x03BB, "lambda");
      list.add(0x019B, "lambdastroke");
      list.add(0x05DC, "lamed");
      list.add(0xFB3C, "lameddagesh");
      list.add(0xFB3C, "lameddageshhebrew");
      list.add(0x05DC, "lamedhebrew");
      list.add(0xFEDE, "lamfinalarabic");
      list.add(0xFCCA, "lamhahinitialarabic");
      list.add(0xFEDF, "laminitialarabic");
      list.add(0xFCC9, "lamjeeminitialarabic");
      list.add(0xFCCB, "lamkhahinitialarabic");
      list.add(0xFDF2, "lamlamhehisolatedarabic");
      list.add(0xFEE0, "lammedialarabic");
      list.add(0xFD88, "lammeemhahinitialarabic");
      list.add(0xFCCC, "lammeeminitialarabic");
      list.add(0x25EF, "largecircle");
      list.add(0x019A, "lbar");
      list.add(0x026C, "lbelt");
      list.add(0x310C, "lbopomofo");
      list.add(0x013E, "lcaron");
      list.add(0x013C, "lcedilla");
      list.add(0x24DB, "lcircle");
      list.add(0x1E3D, "lcircumflexbelow");
      list.add(0x013C, "lcommaaccent");
      list.add(0x0140, "ldot");
      list.add(0x0140, "ldotaccent");
      list.add(0x1E37, "ldotbelow");
      list.add(0x1E39, "ldotbelowmacron");
      list.add(0x031A, "leftangleabovecmb");
      list.add(0x0318, "lefttackbelowcmb");
      list.add(0x003C, "less");
      list.add(0x2264, "lessequal");
      list.add(0x22DA, "lessequalorgreater");
      list.add(0xFF1C, "lessmonospace");
      list.add(0x2272, "lessorequivalent");
      list.add(0x2276, "lessorgreater");
      list.add(0x2266, "lessoverequal");
      list.add(0xFE64, "lesssmall");
      list.add(0x026E, "lezh");
      list.add(0x258C, "lfblock");
      list.add(0x026D, "lhookretroflex");
      list.add(0x20A4, "lira");
      list.add(0x056C, "liwnarmenian");
      list.add(0x01C9, "lj");
      list.add(0x0459, "ljecyrillic");
      list.add(0xF6C0, "ll");
      list.add(0x0933, "lladeva");
      list.add(0x0AB3, "llagujarati");
      list.add(0x1E3B, "llinebelow");
      list.add(0x0934, "llladeva");
      list.add(0x09E1, "llvocalicbengali");
      list.add(0x0961, "llvocalicdeva");
      list.add(0x09E3, "llvocalicvowelsignbengali");
      list.add(0x0963, "llvocalicvowelsigndeva");
      list.add(0x026B, "lmiddletilde");
      list.add(0xFF4C, "lmonospace");
      list.add(0x33D0, "lmsquare");
      list.add(0x0E2C, "lochulathai");
      list.add(0x2227, "logicaland");
      list.add(0x00AC, "logicalnot");
      list.add(0x2310, "logicalnotreversed");
      list.add(0x2228, "logicalor");
      list.add(0x0E25, "lolingthai");
      list.add(0x017F, "longs");
      list.add(0xFE4E, "lowlinecenterline");
      list.add(0x0332, "lowlinecmb");
      list.add(0xFE4D, "lowlinedashed");
      list.add(0x25CA, "lozenge");
      list.add(0x24A7, "lparen");
      list.add(0x0142, "lslash");
      list.add(0x2113, "lsquare");
      list.add(0xF6EE, "lsuperior");
      list.add(0x2591, "ltshade");
      list.add(0x0E26, "luthai");
      list.add(0x098C, "lvocalicbengali");
      list.add(0x090C, "lvocalicdeva");
      list.add(0x09E2, "lvocalicvowelsignbengali");
      list.add(0x0962, "lvocalicvowelsigndeva");
      list.add(0x33D3, "lxsquare");
      list.add(0x006D, "m");
      list.add(0x09AE, "mabengali");
      list.add(0x00AF, "macron");
      list.add(0x0331, "macronbelowcmb");
      list.add(0x0304, "macroncmb");
      list.add(0x02CD, "macronlowmod");
      list.add(0xFFE3, "macronmonospace");
      list.add(0x1E3F, "macute");
      list.add(0x092E, "madeva");
      list.add(0x0AAE, "magujarati");
      list.add(0x0A2E, "magurmukhi");
      list.add(0x05A4, "mahapakhhebrew");
      list.add(0x05A4, "mahapakhlefthebrew");
      list.add(0x307E, "mahiragana");
      list.add(0xF895, "maichattawalowleftthai");
      list.add(0xF894, "maichattawalowrightthai");
      list.add(0x0E4B, "maichattawathai");
      list.add(0xF893, "maichattawaupperleftthai");
      list.add(0xF88C, "maieklowleftthai");
      list.add(0xF88B, "maieklowrightthai");
      list.add(0x0E48, "maiekthai");
      list.add(0xF88A, "maiekupperleftthai");
      list.add(0xF884, "maihanakatleftthai");
      list.add(0x0E31, "maihanakatthai");
      list.add(0xF889, "maitaikhuleftthai");
      list.add(0x0E47, "maitaikhuthai");
      list.add(0xF88F, "maitholowleftthai");
      list.add(0xF88E, "maitholowrightthai");
      list.add(0x0E49, "maithothai");
      list.add(0xF88D, "maithoupperleftthai");
      list.add(0xF892, "maitrilowleftthai");
      list.add(0xF891, "maitrilowrightthai");
      list.add(0x0E4A, "maitrithai");
      list.add(0xF890, "maitriupperleftthai");
      list.add(0x0E46, "maiyamokthai");
      list.add(0x30DE, "makatakana");
      list.add(0xFF8F, "makatakanahalfwidth");
      list.add(0x2642, "male");
      list.add(0x3347, "mansyonsquare");
      list.add(0x05BE, "maqafhebrew");
      list.add(0x2642, "mars");
      list.add(0x05AF, "masoracirclehebrew");
      list.add(0x3383, "masquare");
      list.add(0x3107, "mbopomofo");
      list.add(0x33D4, "mbsquare");
      list.add(0x24DC, "mcircle");
      list.add(0x33A5, "mcubedsquare");
      list.add(0x1E41, "mdotaccent");
      list.add(0x1E43, "mdotbelow");
      list.add(0x0645, "meemarabic");
      list.add(0xFEE2, "meemfinalarabic");
      list.add(0xFEE3, "meeminitialarabic");
      list.add(0xFEE4, "meemmedialarabic");
      list.add(0xFCD1, "meemmeeminitialarabic");
      list.add(0xFC48, "meemmeemisolatedarabic");
      list.add(0x334D, "meetorusquare");
      list.add(0x3081, "mehiragana");
      list.add(0x337E, "meizierasquare");
      list.add(0x30E1, "mekatakana");
      list.add(0xFF92, "mekatakanahalfwidth");
      list.add(0x05DE, "mem");
      list.add(0xFB3E, "memdagesh");
      list.add(0xFB3E, "memdageshhebrew");
      list.add(0x05DE, "memhebrew");
      list.add(0x0574, "menarmenian");
      list.add(0x05A5, "merkhahebrew");
      list.add(0x05A6, "merkhakefulahebrew");
      list.add(0x05A6, "merkhakefulalefthebrew");
      list.add(0x05A5, "merkhalefthebrew");
      list.add(0x0271, "mhook");
      list.add(0x3392, "mhzsquare");
      list.add(0xFF65, "middledotkatakanahalfwidth");
      list.add(0x00B7, "middot");
      list.add(0x3272, "mieumacirclekorean");
      list.add(0x3212, "mieumaparenkorean");
      list.add(0x3264, "mieumcirclekorean");
      list.add(0x3141, "mieumkorean");
      list.add(0x3170, "mieumpansioskorean");
      list.add(0x3204, "mieumparenkorean");
      list.add(0x316E, "mieumpieupkorean");
      list.add(0x316F, "mieumsioskorean");
      list.add(0x307F, "mihiragana");
      list.add(0x30DF, "mikatakana");
      list.add(0xFF90, "mikatakanahalfwidth");
      list.add(0x2212, "minus");
      list.add(0x0320, "minusbelowcmb");
      list.add(0x2296, "minuscircle");
      list.add(0x02D7, "minusmod");
      list.add(0x2213, "minusplus");
      list.add(0x2032, "minute");
      list.add(0x334A, "miribaarusquare");
      list.add(0x3349, "mirisquare");
      list.add(0x0270, "mlonglegturned");
      list.add(0x3396, "mlsquare");
      list.add(0x33A3, "mmcubedsquare");
      list.add(0xFF4D, "mmonospace");
      list.add(0x339F, "mmsquaredsquare");
      list.add(0x3082, "mohiragana");
      list.add(0x33C1, "mohmsquare");
      list.add(0x30E2, "mokatakana");
      list.add(0xFF93, "mokatakanahalfwidth");
      list.add(0x33D6, "molsquare");
      list.add(0x0E21, "momathai");
      list.add(0x33A7, "moverssquare");
      list.add(0x33A8, "moverssquaredsquare");
      list.add(0x24A8, "mparen");
      list.add(0x33AB, "mpasquare");
      list.add(0x33B3, "mssquare");
      list.add(0xF6EF, "msuperior");
      list.add(0x026F, "mturned");
      list.add(0x00B5, "mu");
      list.add(0x00B5, "mu1");
      list.add(0x3382, "muasquare");
      list.add(0x226B, "muchgreater");
      list.add(0x226A, "muchless");
      list.add(0x338C, "mufsquare");
      list.add(0x03BC, "mugreek");
      list.add(0x338D, "mugsquare");
      list.add(0x3080, "muhiragana");
      list.add(0x30E0, "mukatakana");
      list.add(0xFF91, "mukatakanahalfwidth");
      list.add(0x3395, "mulsquare");
      list.add(0x00D7, "multiply");
      list.add(0x339B, "mumsquare");
      list.add(0x05A3, "munahhebrew");
      list.add(0x05A3, "munahlefthebrew");
      list.add(0x266A, "musicalnote");
      list.add(0x266B, "musicalnotedbl");
      list.add(0x266D, "musicflatsign");
      list.add(0x266F, "musicsharpsign");
      list.add(0x33B2, "mussquare");
      list.add(0x33B6, "muvsquare");
      list.add(0x33BC, "muwsquare");
      list.add(0x33B9, "mvmegasquare");
      list.add(0x33B7, "mvsquare");
      list.add(0x33BF, "mwmegasquare");
      list.add(0x33BD, "mwsquare");
      list.add(0x006E, "n");
      list.add(0x09A8, "nabengali");
      list.add(0x2207, "nabla");
      list.add(0x0144, "nacute");
      list.add(0x0928, "nadeva");
      list.add(0x0AA8, "nagujarati");
      list.add(0x0A28, "nagurmukhi");
      list.add(0x306A, "nahiragana");
      list.add(0x30CA, "nakatakana");
      list.add(0xFF85, "nakatakanahalfwidth");
      list.add(0x0149, "napostrophe");
      list.add(0x3381, "nasquare");
      list.add(0x310B, "nbopomofo");
      list.add(0x00A0, "nbspace");
      list.add(0x0148, "ncaron");
      list.add(0x0146, "ncedilla");
      list.add(0x24DD, "ncircle");
      list.add(0x1E4B, "ncircumflexbelow");
      list.add(0x0146, "ncommaaccent");
      list.add(0x1E45, "ndotaccent");
      list.add(0x1E47, "ndotbelow");
      list.add(0x306D, "nehiragana");
      list.add(0x30CD, "nekatakana");
      list.add(0xFF88, "nekatakanahalfwidth");
      list.add(0x20AA, "newsheqelsign");
      list.add(0x338B, "nfsquare");
      list.add(0x0999, "ngabengali");
      list.add(0x0919, "ngadeva");
      list.add(0x0A99, "ngagujarati");
      list.add(0x0A19, "ngagurmukhi");
      list.add(0x0E07, "ngonguthai");
      list.add(0x3093, "nhiragana");
      list.add(0x0272, "nhookleft");
      list.add(0x0273, "nhookretroflex");
      list.add(0x326F, "nieunacirclekorean");
      list.add(0x320F, "nieunaparenkorean");
      list.add(0x3135, "nieuncieuckorean");
      list.add(0x3261, "nieuncirclekorean");
      list.add(0x3136, "nieunhieuhkorean");
      list.add(0x3134, "nieunkorean");
      list.add(0x3168, "nieunpansioskorean");
      list.add(0x3201, "nieunparenkorean");
      list.add(0x3167, "nieunsioskorean");
      list.add(0x3166, "nieuntikeutkorean");
      list.add(0x306B, "nihiragana");
      list.add(0x30CB, "nikatakana");
      list.add(0xFF86, "nikatakanahalfwidth");
      list.add(0xF899, "nikhahitleftthai");
      list.add(0x0E4D, "nikhahitthai");
      list.add(0x0039, "nine");
      list.add(0x0669, "ninearabic");
      list.add(0x09EF, "ninebengali");
      list.add(0x2468, "ninecircle");
      list.add(0x2792, "ninecircleinversesansserif");
      list.add(0x096F, "ninedeva");
      list.add(0x0AEF, "ninegujarati");
      list.add(0x0A6F, "ninegurmukhi");
      list.add(0x0669, "ninehackarabic");
      list.add(0x3029, "ninehangzhou");
      list.add(0x3228, "nineideographicparen");
      list.add(0x2089, "nineinferior");
      list.add(0xFF19, "ninemonospace");
      list.add(0xF739, "nineoldstyle");
      list.add(0x247C, "nineparen");
      list.add(0x2490, "nineperiod");
      list.add(0x06F9, "ninepersian");
      list.add(0x2178, "nineroman");
      list.add(0x2079, "ninesuperior");
      list.add(0x2472, "nineteencircle");
      list.add(0x2486, "nineteenparen");
      list.add(0x249A, "nineteenperiod");
      list.add(0x0E59, "ninethai");
      list.add(0x01CC, "nj");
      list.add(0x045A, "njecyrillic");
      list.add(0x30F3, "nkatakana");
      list.add(0xFF9D, "nkatakanahalfwidth");
      list.add(0x019E, "nlegrightlong");
      list.add(0x1E49, "nlinebelow");
      list.add(0xFF4E, "nmonospace");
      list.add(0x339A, "nmsquare");
      list.add(0x09A3, "nnabengali");
      list.add(0x0923, "nnadeva");
      list.add(0x0AA3, "nnagujarati");
      list.add(0x0A23, "nnagurmukhi");
      list.add(0x0929, "nnnadeva");
      list.add(0x306E, "nohiragana");
      list.add(0x30CE, "nokatakana");
      list.add(0xFF89, "nokatakanahalfwidth");
      list.add(0x00A0, "nonbreakingspace");
      list.add(0x0E13, "nonenthai");
      list.add(0x0E19, "nonuthai");
      list.add(0x0646, "noonarabic");
      list.add(0xFEE6, "noonfinalarabic");
      list.add(0x06BA, "noonghunnaarabic");
      list.add(0xFB9F, "noonghunnafinalarabic");
      list.add(0xFEE7, "nooninitialarabic");
      list.add(0xFCD2, "noonjeeminitialarabic");
      list.add(0xFC4B, "noonjeemisolatedarabic");
      list.add(0xFEE8, "noonmedialarabic");
      list.add(0xFCD5, "noonmeeminitialarabic");
      list.add(0xFC4E, "noonmeemisolatedarabic");
      list.add(0xFC8D, "noonnoonfinalarabic");
      list.add(0x220C, "notcontains");
      list.add(0x2209, "notelement");
      list.add(0x2209, "notelementof");
      list.add(0x2260, "notequal");
      list.add(0x226F, "notgreater");
      list.add(0x2271, "notgreaternorequal");
      list.add(0x2279, "notgreaternorless");
      list.add(0x2262, "notidentical");
      list.add(0x226E, "notless");
      list.add(0x2270, "notlessnorequal");
      list.add(0x2226, "notparallel");
      list.add(0x2280, "notprecedes");
      list.add(0x2284, "notsubset");
      list.add(0x2281, "notsucceeds");
      list.add(0x2285, "notsuperset");
      list.add(0x0576, "nowarmenian");
      list.add(0x24A9, "nparen");
      list.add(0x33B1, "nssquare");
      list.add(0x207F, "nsuperior");
      list.add(0x00F1, "ntilde");
      list.add(0x03BD, "nu");
      list.add(0x306C, "nuhiragana");
      list.add(0x30CC, "nukatakana");
      list.add(0xFF87, "nukatakanahalfwidth");
      list.add(0x09BC, "nuktabengali");
      list.add(0x093C, "nuktadeva");
      list.add(0x0ABC, "nuktagujarati");
      list.add(0x0A3C, "nuktagurmukhi");
      list.add(0x0023, "numbersign");
      list.add(0xFF03, "numbersignmonospace");
      list.add(0xFE5F, "numbersignsmall");
      list.add(0x0374, "numeralsigngreek");
      list.add(0x0375, "numeralsignlowergreek");
      list.add(0x2116, "numero");
      list.add(0x05E0, "nun");
      list.add(0xFB40, "nundagesh");
      list.add(0xFB40, "nundageshhebrew");
      list.add(0x05E0, "nunhebrew");
      list.add(0x33B5, "nvsquare");
      list.add(0x33BB, "nwsquare");
      list.add(0x099E, "nyabengali");
      list.add(0x091E, "nyadeva");
      list.add(0x0A9E, "nyagujarati");
      list.add(0x0A1E, "nyagurmukhi");
      list.add(0x006F, "o");
      list.add(0x00F3, "oacute");
      list.add(0x0E2D, "oangthai");
      list.add(0x0275, "obarred");
      list.add(0x04E9, "obarredcyrillic");
      list.add(0x04EB, "obarreddieresiscyrillic");
      list.add(0x0993, "obengali");
      list.add(0x311B, "obopomofo");
      list.add(0x014F, "obreve");
      list.add(0x0911, "ocandradeva");
      list.add(0x0A91, "ocandragujarati");
      list.add(0x0949, "ocandravowelsigndeva");
      list.add(0x0AC9, "ocandravowelsigngujarati");
      list.add(0x01D2, "ocaron");
      list.add(0x24DE, "ocircle");
      list.add(0x00F4, "ocircumflex");
      list.add(0x1ED1, "ocircumflexacute");
      list.add(0x1ED9, "ocircumflexdotbelow");
      list.add(0x1ED3, "ocircumflexgrave");
      list.add(0x1ED5, "ocircumflexhookabove");
      list.add(0x1ED7, "ocircumflextilde");
      list.add(0x043E, "ocyrillic");
      list.add(0x0151, "odblacute");
      list.add(0x020D, "odblgrave");
      list.add(0x0913, "odeva");
      list.add(0x00F6, "odieresis");
      list.add(0x04E7, "odieresiscyrillic");
      list.add(0x1ECD, "odotbelow");
      list.add(0x0153, "oe");
      list.add(0x315A, "oekorean");
      list.add(0x02DB, "ogonek");
      list.add(0x0328, "ogonekcmb");
      list.add(0x00F2, "ograve");
      list.add(0x0A93, "ogujarati");
      list.add(0x0585, "oharmenian");
      list.add(0x304A, "ohiragana");
      list.add(0x1ECF, "ohookabove");
      list.add(0x01A1, "ohorn");
      list.add(0x1EDB, "ohornacute");
      list.add(0x1EE3, "ohorndotbelow");
      list.add(0x1EDD, "ohorngrave");
      list.add(0x1EDF, "ohornhookabove");
      list.add(0x1EE1, "ohorntilde");
      list.add(0x0151, "ohungarumlaut");
      list.add(0x01A3, "oi");
      list.add(0x020F, "oinvertedbreve");
      list.add(0x30AA, "okatakana");
      list.add(0xFF75, "okatakanahalfwidth");
      list.add(0x3157, "okorean");
      list.add(0x05AB, "olehebrew");
      list.add(0x014D, "omacron");
      list.add(0x1E53, "omacronacute");
      list.add(0x1E51, "omacrongrave");
      list.add(0x0950, "omdeva");
      list.add(0x03C9, "omega");
      list.add(0x03D6, "omega1");
      list.add(0x0461, "omegacyrillic");
      list.add(0x0277, "omegalatinclosed");
      list.add(0x047B, "omegaroundcyrillic");
      list.add(0x047D, "omegatitlocyrillic");
      list.add(0x03CE, "omegatonos");
      list.add(0x0AD0, "omgujarati");
      list.add(0x03BF, "omicron");
      list.add(0x03CC, "omicrontonos");
      list.add(0xFF4F, "omonospace");
      list.add(0x0031, "one");
      list.add(0x0661, "onearabic");
      list.add(0x09E7, "onebengali");
      list.add(0x2460, "onecircle");
      list.add(0x278A, "onecircleinversesansserif");
      list.add(0x0967, "onedeva");
      list.add(0x2024, "onedotenleader");
      list.add(0x215B, "oneeighth");
      list.add(0xF6DC, "onefitted");
      list.add(0x0AE7, "onegujarati");
      list.add(0x0A67, "onegurmukhi");
      list.add(0x0661, "onehackarabic");
      list.add(0x00BD, "onehalf");
      list.add(0x3021, "onehangzhou");
      list.add(0x3220, "oneideographicparen");
      list.add(0x2081, "oneinferior");
      list.add(0xFF11, "onemonospace");
      list.add(0x09F4, "onenumeratorbengali");
      list.add(0xF731, "oneoldstyle");
      list.add(0x2474, "oneparen");
      list.add(0x2488, "oneperiod");
      list.add(0x06F1, "onepersian");
      list.add(0x00BC, "onequarter");
      list.add(0x2170, "oneroman");
      list.add(0x00B9, "onesuperior");
      list.add(0x0E51, "onethai");
      list.add(0x2153, "onethird");
      list.add(0x01EB, "oogonek");
      list.add(0x01ED, "oogonekmacron");
      list.add(0x0A13, "oogurmukhi");
      list.add(0x0A4B, "oomatragurmukhi");
      list.add(0x0254, "oopen");
      list.add(0x24AA, "oparen");
      list.add(0x25E6, "openbullet");
      list.add(0x2325, "option");
      list.add(0x00AA, "ordfeminine");
      list.add(0x00BA, "ordmasculine");
      list.add(0x221F, "orthogonal");
      list.add(0x0912, "oshortdeva");
      list.add(0x094A, "oshortvowelsigndeva");
      list.add(0x00F8, "oslash");
      list.add(0x01FF, "oslashacute");
      list.add(0x3049, "osmallhiragana");
      list.add(0x30A9, "osmallkatakana");
      list.add(0xFF6B, "osmallkatakanahalfwidth");
      list.add(0x01FF, "ostrokeacute");
      list.add(0xF6F0, "osuperior");
      list.add(0x047F, "otcyrillic");
      list.add(0x00F5, "otilde");
      list.add(0x1E4D, "otildeacute");
      list.add(0x1E4F, "otildedieresis");
      list.add(0x3121, "oubopomofo");
      list.add(0x203E, "overline");
      list.add(0xFE4A, "overlinecenterline");
      list.add(0x0305, "overlinecmb");
      list.add(0xFE49, "overlinedashed");
      list.add(0xFE4C, "overlinedblwavy");
      list.add(0xFE4B, "overlinewavy");
      list.add(0x00AF, "overscore");
      list.add(0x09CB, "ovowelsignbengali");
      list.add(0x094B, "ovowelsigndeva");
      list.add(0x0ACB, "ovowelsigngujarati");
      list.add(0x0070, "p");
      list.add(0x3380, "paampssquare");
      list.add(0x332B, "paasentosquare");
      list.add(0x09AA, "pabengali");
      list.add(0x1E55, "pacute");
      list.add(0x092A, "padeva");
      list.add(0x21DF, "pagedown");
      list.add(0x21DE, "pageup");
      list.add(0x0AAA, "pagujarati");
      list.add(0x0A2A, "pagurmukhi");
      list.add(0x3071, "pahiragana");
      list.add(0x0E2F, "paiyannoithai");
      list.add(0x30D1, "pakatakana");
      list.add(0x0484, "palatalizationcyrilliccmb");
      list.add(0x04C0, "palochkacyrillic");
      list.add(0x317F, "pansioskorean");
      list.add(0x00B6, "paragraph");
      list.add(0x2225, "parallel");
      list.add(0x0028, "parenleft");
      list.add(0xFD3E, "parenleftaltonearabic");
      list.add(0xF8ED, "parenleftbt");
      list.add(0xF8EC, "parenleftex");
      list.add(0x208D, "parenleftinferior");
      list.add(0xFF08, "parenleftmonospace");
      list.add(0xFE59, "parenleftsmall");
      list.add(0x207D, "parenleftsuperior");
      list.add(0xF8EB, "parenlefttp");
      list.add(0xFE35, "parenleftvertical");
      list.add(0x0029, "parenright");
      list.add(0xFD3F, "parenrightaltonearabic");
      list.add(0xF8F8, "parenrightbt");
      list.add(0xF8F7, "parenrightex");
      list.add(0x208E, "parenrightinferior");
      list.add(0xFF09, "parenrightmonospace");
      list.add(0xFE5A, "parenrightsmall");
      list.add(0x207E, "parenrightsuperior");
      list.add(0xF8F6, "parenrighttp");
      list.add(0xFE36, "parenrightvertical");
      list.add(0x2202, "partialdiff");
      list.add(0x05C0, "paseqhebrew");
      list.add(0x0599, "pashtahebrew");
      list.add(0x33A9, "pasquare");
      list.add(0x05B7, "patah");
      list.add(0x05B7, "patah11");
      list.add(0x05B7, "patah1d");
      list.add(0x05B7, "patah2a");
      list.add(0x05B7, "patahhebrew");
      list.add(0x05B7, "patahnarrowhebrew");
      list.add(0x05B7, "patahquarterhebrew");
      list.add(0x05B7, "patahwidehebrew");
      list.add(0x05A1, "pazerhebrew");
      list.add(0x3106, "pbopomofo");
      list.add(0x24DF, "pcircle");
      list.add(0x1E57, "pdotaccent");
      list.add(0x05E4, "pe");
      list.add(0x043F, "pecyrillic");
      list.add(0xFB44, "pedagesh");
      list.add(0xFB44, "pedageshhebrew");
      list.add(0x333B, "peezisquare");
      list.add(0xFB43, "pefinaldageshhebrew");
      list.add(0x067E, "peharabic");
      list.add(0x057A, "peharmenian");
      list.add(0x05E4, "pehebrew");
      list.add(0xFB57, "pehfinalarabic");
      list.add(0xFB58, "pehinitialarabic");
      list.add(0x307A, "pehiragana");
      list.add(0xFB59, "pehmedialarabic");
      list.add(0x30DA, "pekatakana");
      list.add(0x04A7, "pemiddlehookcyrillic");
      list.add(0xFB4E, "perafehebrew");
      list.add(0x0025, "percent");
      list.add(0x066A, "percentarabic");
      list.add(0xFF05, "percentmonospace");
      list.add(0xFE6A, "percentsmall");
      list.add(0x002E, "period");
      list.add(0x0589, "periodarmenian");
      list.add(0x00B7, "periodcentered");
      list.add(0xFF61, "periodhalfwidth");
      list.add(0xF6E7, "periodinferior");
      list.add(0xFF0E, "periodmonospace");
      list.add(0xFE52, "periodsmall");
      list.add(0xF6E8, "periodsuperior");
      list.add(0x0342, "perispomenigreekcmb");
      list.add(0x22A5, "perpendicular");
      list.add(0x2030, "perthousand");
      list.add(0x20A7, "peseta");
      list.add(0x338A, "pfsquare");
      list.add(0x09AB, "phabengali");
      list.add(0x092B, "phadeva");
      list.add(0x0AAB, "phagujarati");
      list.add(0x0A2B, "phagurmukhi");
      list.add(0x03C6, "phi");
      list.add(0x03D5, "phi1");
      list.add(0x327A, "phieuphacirclekorean");
      list.add(0x321A, "phieuphaparenkorean");
      list.add(0x326C, "phieuphcirclekorean");
      list.add(0x314D, "phieuphkorean");
      list.add(0x320C, "phieuphparenkorean");
      list.add(0x0278, "philatin");
      list.add(0x0E3A, "phinthuthai");
      list.add(0x03D5, "phisymbolgreek");
      list.add(0x01A5, "phook");
      list.add(0x0E1E, "phophanthai");
      list.add(0x0E1C, "phophungthai");
      list.add(0x0E20, "phosamphaothai");
      list.add(0x03C0, "pi");
      list.add(0x3273, "pieupacirclekorean");
      list.add(0x3213, "pieupaparenkorean");
      list.add(0x3176, "pieupcieuckorean");
      list.add(0x3265, "pieupcirclekorean");
      list.add(0x3172, "pieupkiyeokkorean");
      list.add(0x3142, "pieupkorean");
      list.add(0x3205, "pieupparenkorean");
      list.add(0x3174, "pieupsioskiyeokkorean");
      list.add(0x3144, "pieupsioskorean");
      list.add(0x3175, "pieupsiostikeutkorean");
      list.add(0x3177, "pieupthieuthkorean");
      list.add(0x3173, "pieuptikeutkorean");
      list.add(0x3074, "pihiragana");
      list.add(0x30D4, "pikatakana");
      list.add(0x03D6, "pisymbolgreek");
      list.add(0x0583, "piwrarmenian");
      list.add(0x002B, "plus");
      list.add(0x031F, "plusbelowcmb");
      list.add(0x2295, "pluscircle");
      list.add(0x00B1, "plusminus");
      list.add(0x02D6, "plusmod");
      list.add(0xFF0B, "plusmonospace");
      list.add(0xFE62, "plussmall");
      list.add(0x207A, "plussuperior");
      list.add(0xFF50, "pmonospace");
      list.add(0x33D8, "pmsquare");
      list.add(0x307D, "pohiragana");
      list.add(0x261F, "pointingindexdownwhite");
      list.add(0x261C, "pointingindexleftwhite");
      list.add(0x261E, "pointingindexrightwhite");
      list.add(0x261D, "pointingindexupwhite");
      list.add(0x30DD, "pokatakana");
      list.add(0x0E1B, "poplathai");
      list.add(0x3012, "postalmark");
      list.add(0x3020, "postalmarkface");
      list.add(0x24AB, "pparen");
      list.add(0x227A, "precedes");
      list.add(0x211E, "prescription");
      list.add(0x02B9, "primemod");
      list.add(0x2035, "primereversed");
      list.add(0x220F, "product");
      list.add(0x2305, "projective");
      list.add(0x30FC, "prolongedkana");
      list.add(0x2318, "propellor");
      list.add(0x2282, "propersubset");
      list.add(0x2283, "propersuperset");
      list.add(0x2237, "proportion");
      list.add(0x221D, "proportional");
      list.add(0x03C8, "psi");
      list.add(0x0471, "psicyrillic");
      list.add(0x0486, "psilipneumatacyrilliccmb");
      list.add(0x33B0, "pssquare");
      list.add(0x3077, "puhiragana");
      list.add(0x30D7, "pukatakana");
      list.add(0x33B4, "pvsquare");
      list.add(0x33BA, "pwsquare");
      list.add(0x0071, "q");
      list.add(0x0958, "qadeva");
      list.add(0x05A8, "qadmahebrew");
      list.add(0x0642, "qafarabic");
      list.add(0xFED6, "qaffinalarabic");
      list.add(0xFED7, "qafinitialarabic");
      list.add(0xFED8, "qafmedialarabic");
      list.add(0x05B8, "qamats");
      list.add(0x05B8, "qamats10");
      list.add(0x05B8, "qamats1a");
      list.add(0x05B8, "qamats1c");
      list.add(0x05B8, "qamats27");
      list.add(0x05B8, "qamats29");
      list.add(0x05B8, "qamats33");
      list.add(0x05B8, "qamatsde");
      list.add(0x05B8, "qamatshebrew");
      list.add(0x05B8, "qamatsnarrowhebrew");
      list.add(0x05B8, "qamatsqatanhebrew");
      list.add(0x05B8, "qamatsqatannarrowhebrew");
      list.add(0x05B8, "qamatsqatanquarterhebrew");
      list.add(0x05B8, "qamatsqatanwidehebrew");
      list.add(0x05B8, "qamatsquarterhebrew");
      list.add(0x05B8, "qamatswidehebrew");
      list.add(0x059F, "qarneyparahebrew");
      list.add(0x3111, "qbopomofo");
      list.add(0x24E0, "qcircle");
      list.add(0x02A0, "qhook");
      list.add(0xFF51, "qmonospace");
      list.add(0x05E7, "qof");
      list.add(0xFB47, "qofdagesh");
      list.add(0xFB47, "qofdageshhebrew");
      list.add(0x05E7, "qofhebrew");
      list.add(0x24AC, "qparen");
      list.add(0x2669, "quarternote");
      list.add(0x05BB, "qubuts");
      list.add(0x05BB, "qubuts18");
      list.add(0x05BB, "qubuts25");
      list.add(0x05BB, "qubuts31");
      list.add(0x05BB, "qubutshebrew");
      list.add(0x05BB, "qubutsnarrowhebrew");
      list.add(0x05BB, "qubutsquarterhebrew");
      list.add(0x05BB, "qubutswidehebrew");
      list.add(0x003F, "question");
      list.add(0x061F, "questionarabic");
      list.add(0x055E, "questionarmenian");
      list.add(0x00BF, "questiondown");
      list.add(0xF7BF, "questiondownsmall");
      list.add(0x037E, "questiongreek");
      list.add(0xFF1F, "questionmonospace");
      list.add(0xF73F, "questionsmall");
      list.add(0x0022, "quotedbl");
      list.add(0x201E, "quotedblbase");
      list.add(0x201C, "quotedblleft");
      list.add(0xFF02, "quotedblmonospace");
      list.add(0x301E, "quotedblprime");
      list.add(0x301D, "quotedblprimereversed");
      list.add(0x201D, "quotedblright");
      list.add(0x2018, "quoteleft");
      list.add(0x201B, "quoteleftreversed");
      list.add(0x201B, "quotereversed");
      list.add(0x2019, "quoteright");
      list.add(0x0149, "quoterightn");
      list.add(0x201A, "quotesinglbase");
      list.add(0x0027, "quotesingle");
      list.add(0xFF07, "quotesinglemonospace");
      list.add(0x0072, "r");
      list.add(0x057C, "raarmenian");
      list.add(0x09B0, "rabengali");
      list.add(0x0155, "racute");
      list.add(0x0930, "radeva");
      list.add(0x221A, "radical");
      list.add(0xF8E5, "radicalex");
      list.add(0x33AE, "radoverssquare");
      list.add(0x33AF, "radoverssquaredsquare");
      list.add(0x33AD, "radsquare");
      list.add(0x05BF, "rafe");
      list.add(0x05BF, "rafehebrew");
      list.add(0x0AB0, "ragujarati");
      list.add(0x0A30, "ragurmukhi");
      list.add(0x3089, "rahiragana");
      list.add(0x30E9, "rakatakana");
      list.add(0xFF97, "rakatakanahalfwidth");
      list.add(0x09F1, "ralowerdiagonalbengali");
      list.add(0x09F0, "ramiddlediagonalbengali");
      list.add(0x0264, "ramshorn");
      list.add(0x2236, "ratio");
      list.add(0x3116, "rbopomofo");
      list.add(0x0159, "rcaron");
      list.add(0x0157, "rcedilla");
      list.add(0x24E1, "rcircle");
      list.add(0x0157, "rcommaaccent");
      list.add(0x0211, "rdblgrave");
      list.add(0x1E59, "rdotaccent");
      list.add(0x1E5B, "rdotbelow");
      list.add(0x1E5D, "rdotbelowmacron");
      list.add(0x203B, "referencemark");
      list.add(0x2286, "reflexsubset");
      list.add(0x2287, "reflexsuperset");
      list.add(0x00AE, "registered");
      list.add(0xF8E8, "registersans");
      list.add(0xF6DA, "registerserif");
      list.add(0x0631, "reharabic");
      list.add(0x0580, "reharmenian");
      list.add(0xFEAE, "rehfinalarabic");
      list.add(0x308C, "rehiragana");
      list.add(0x30EC, "rekatakana");
      list.add(0xFF9A, "rekatakanahalfwidth");
      list.add(0x05E8, "resh");
      list.add(0xFB48, "reshdageshhebrew");
      list.add(0x05E8, "reshhebrew");
      list.add(0x223D, "reversedtilde");
      list.add(0x0597, "reviahebrew");
      list.add(0x0597, "reviamugrashhebrew");
      list.add(0x2310, "revlogicalnot");
      list.add(0x027E, "rfishhook");
      list.add(0x027F, "rfishhookreversed");
      list.add(0x09DD, "rhabengali");
      list.add(0x095D, "rhadeva");
      list.add(0x03C1, "rho");
      list.add(0x027D, "rhook");
      list.add(0x027B, "rhookturned");
      list.add(0x02B5, "rhookturnedsuperior");
      list.add(0x03F1, "rhosymbolgreek");
      list.add(0x02DE, "rhotichookmod");
      list.add(0x3271, "rieulacirclekorean");
      list.add(0x3211, "rieulaparenkorean");
      list.add(0x3263, "rieulcirclekorean");
      list.add(0x3140, "rieulhieuhkorean");
      list.add(0x313A, "rieulkiyeokkorean");
      list.add(0x3169, "rieulkiyeoksioskorean");
      list.add(0x3139, "rieulkorean");
      list.add(0x313B, "rieulmieumkorean");
      list.add(0x316C, "rieulpansioskorean");
      list.add(0x3203, "rieulparenkorean");
      list.add(0x313F, "rieulphieuphkorean");
      list.add(0x313C, "rieulpieupkorean");
      list.add(0x316B, "rieulpieupsioskorean");
      list.add(0x313D, "rieulsioskorean");
      list.add(0x313E, "rieulthieuthkorean");
      list.add(0x316A, "rieultikeutkorean");
      list.add(0x316D, "rieulyeorinhieuhkorean");
      list.add(0x221F, "rightangle");
      list.add(0x0319, "righttackbelowcmb");
      list.add(0x22BF, "righttriangle");
      list.add(0x308A, "rihiragana");
      list.add(0x30EA, "rikatakana");
      list.add(0xFF98, "rikatakanahalfwidth");
      list.add(0x02DA, "ring");
      list.add(0x0325, "ringbelowcmb");
      list.add(0x030A, "ringcmb");
      list.add(0x02BF, "ringhalfleft");
      list.add(0x0559, "ringhalfleftarmenian");
      list.add(0x031C, "ringhalfleftbelowcmb");
      list.add(0x02D3, "ringhalfleftcentered");
      list.add(0x02BE, "ringhalfright");
      list.add(0x0339, "ringhalfrightbelowcmb");
      list.add(0x02D2, "ringhalfrightcentered");
      list.add(0x0213, "rinvertedbreve");
      list.add(0x3351, "rittorusquare");
      list.add(0x1E5F, "rlinebelow");
      list.add(0x027C, "rlongleg");
      list.add(0x027A, "rlonglegturned");
      list.add(0xFF52, "rmonospace");
      list.add(0x308D, "rohiragana");
      list.add(0x30ED, "rokatakana");
      list.add(0xFF9B, "rokatakanahalfwidth");
      list.add(0x0E23, "roruathai");
      list.add(0x24AD, "rparen");
      list.add(0x09DC, "rrabengali");
      list.add(0x0931, "rradeva");
      list.add(0x0A5C, "rragurmukhi");
      list.add(0x0691, "rreharabic");
      list.add(0xFB8D, "rrehfinalarabic");
      list.add(0x09E0, "rrvocalicbengali");
      list.add(0x0960, "rrvocalicdeva");
      list.add(0x0AE0, "rrvocalicgujarati");
      list.add(0x09C4, "rrvocalicvowelsignbengali");
      list.add(0x0944, "rrvocalicvowelsigndeva");
      list.add(0x0AC4, "rrvocalicvowelsigngujarati");
      list.add(0xF6F1, "rsuperior");
      list.add(0x2590, "rtblock");
      list.add(0x0279, "rturned");
      list.add(0x02B4, "rturnedsuperior");
      list.add(0x308B, "ruhiragana");
      list.add(0x30EB, "rukatakana");
      list.add(0xFF99, "rukatakanahalfwidth");
      list.add(0x09F2, "rupeemarkbengali");
      list.add(0x09F3, "rupeesignbengali");
      list.add(0xF6DD, "rupiah");
      list.add(0x0E24, "ruthai");
      list.add(0x098B, "rvocalicbengali");
      list.add(0x090B, "rvocalicdeva");
      list.add(0x0A8B, "rvocalicgujarati");
      list.add(0x09C3, "rvocalicvowelsignbengali");
      list.add(0x0943, "rvocalicvowelsigndeva");
      list.add(0x0AC3, "rvocalicvowelsigngujarati");
      list.add(0x0073, "s");
      list.add(0x09B8, "sabengali");
      list.add(0x015B, "sacute");
      list.add(0x1E65, "sacutedotaccent");
      list.add(0x0635, "sadarabic");
      list.add(0x0938, "sadeva");
      list.add(0xFEBA, "sadfinalarabic");
      list.add(0xFEBB, "sadinitialarabic");
      list.add(0xFEBC, "sadmedialarabic");
      list.add(0x0AB8, "sagujarati");
      list.add(0x0A38, "sagurmukhi");
      list.add(0x3055, "sahiragana");
      list.add(0x30B5, "sakatakana");
      list.add(0xFF7B, "sakatakanahalfwidth");
      list.add(0xFDFA, "sallallahoualayhewasallamarabic");
      list.add(0x05E1, "samekh");
      list.add(0xFB41, "samekhdagesh");
      list.add(0xFB41, "samekhdageshhebrew");
      list.add(0x05E1, "samekhhebrew");
      list.add(0x0E32, "saraaathai");
      list.add(0x0E41, "saraaethai");
      list.add(0x0E44, "saraaimaimalaithai");
      list.add(0x0E43, "saraaimaimuanthai");
      list.add(0x0E33, "saraamthai");
      list.add(0x0E30, "saraathai");
      list.add(0x0E40, "saraethai");
      list.add(0xF886, "saraiileftthai");
      list.add(0x0E35, "saraiithai");
      list.add(0xF885, "saraileftthai");
      list.add(0x0E34, "saraithai");
      list.add(0x0E42, "saraothai");
      list.add(0xF888, "saraueeleftthai");
      list.add(0x0E37, "saraueethai");
      list.add(0xF887, "saraueleftthai");
      list.add(0x0E36, "sarauethai");
      list.add(0x0E38, "sarauthai");
      list.add(0x0E39, "sarauuthai");
      list.add(0x3119, "sbopomofo");
      list.add(0x0161, "scaron");
      list.add(0x1E67, "scarondotaccent");
      list.add(0x015F, "scedilla");
      list.add(0x0259, "schwa");
      list.add(0x04D9, "schwacyrillic");
      list.add(0x04DB, "schwadieresiscyrillic");
      list.add(0x025A, "schwahook");
      list.add(0x24E2, "scircle");
      list.add(0x015D, "scircumflex");
      list.add(0x0219, "scommaaccent");
      list.add(0x1E61, "sdotaccent");
      list.add(0x1E63, "sdotbelow");
      list.add(0x1E69, "sdotbelowdotaccent");
      list.add(0x033C, "seagullbelowcmb");
      list.add(0x2033, "second");
      list.add(0x02CA, "secondtonechinese");
      list.add(0x00A7, "section");
      list.add(0x0633, "seenarabic");
      list.add(0xFEB2, "seenfinalarabic");
      list.add(0xFEB3, "seeninitialarabic");
      list.add(0xFEB4, "seenmedialarabic");
      list.add(0x05B6, "segol");
      list.add(0x05B6, "segol13");
      list.add(0x05B6, "segol1f");
      list.add(0x05B6, "segol2c");
      list.add(0x05B6, "segolhebrew");
      list.add(0x05B6, "segolnarrowhebrew");
      list.add(0x05B6, "segolquarterhebrew");
      list.add(0x0592, "segoltahebrew");
      list.add(0x05B6, "segolwidehebrew");
      list.add(0x057D, "seharmenian");
      list.add(0x305B, "sehiragana");
      list.add(0x30BB, "sekatakana");
      list.add(0xFF7E, "sekatakanahalfwidth");
      list.add(0x003B, "semicolon");
      list.add(0x061B, "semicolonarabic");
      list.add(0xFF1B, "semicolonmonospace");
      list.add(0xFE54, "semicolonsmall");
      list.add(0x309C, "semivoicedmarkkana");
      list.add(0xFF9F, "semivoicedmarkkanahalfwidth");
      list.add(0x3322, "sentisquare");
      list.add(0x3323, "sentosquare");
      list.add(0x0037, "seven");
      list.add(0x0667, "sevenarabic");
      list.add(0x09ED, "sevenbengali");
      list.add(0x2466, "sevencircle");
      list.add(0x2790, "sevencircleinversesansserif");
      list.add(0x096D, "sevendeva");
      list.add(0x215E, "seveneighths");
      list.add(0x0AED, "sevengujarati");
      list.add(0x0A6D, "sevengurmukhi");
      list.add(0x0667, "sevenhackarabic");
      list.add(0x3027, "sevenhangzhou");
      list.add(0x3226, "sevenideographicparen");
      list.add(0x2087, "seveninferior");
      list.add(0xFF17, "sevenmonospace");
      list.add(0xF737, "sevenoldstyle");
      list.add(0x247A, "sevenparen");
      list.add(0x248E, "sevenperiod");
      list.add(0x06F7, "sevenpersian");
      list.add(0x2176, "sevenroman");
      list.add(0x2077, "sevensuperior");
      list.add(0x2470, "seventeencircle");
      list.add(0x2484, "seventeenparen");
      list.add(0x2498, "seventeenperiod");
      list.add(0x0E57, "seventhai");
      list.add(0x00AD, "sfthyphen");
      list.add(0x0577, "shaarmenian");
      list.add(0x09B6, "shabengali");
      list.add(0x0448, "shacyrillic");
      list.add(0x0651, "shaddaarabic");
      list.add(0xFC61, "shaddadammaarabic");
      list.add(0xFC5E, "shaddadammatanarabic");
      list.add(0xFC60, "shaddafathaarabic");
      list.add(0xFC62, "shaddakasraarabic");
      list.add(0xFC5F, "shaddakasratanarabic");
      list.add(0x2592, "shade");
      list.add(0x2593, "shadedark");
      list.add(0x2591, "shadelight");
      list.add(0x2592, "shademedium");
      list.add(0x0936, "shadeva");
      list.add(0x0AB6, "shagujarati");
      list.add(0x0A36, "shagurmukhi");
      list.add(0x0593, "shalshelethebrew");
      list.add(0x3115, "shbopomofo");
      list.add(0x0449, "shchacyrillic");
      list.add(0x0634, "sheenarabic");
      list.add(0xFEB6, "sheenfinalarabic");
      list.add(0xFEB7, "sheeninitialarabic");
      list.add(0xFEB8, "sheenmedialarabic");
      list.add(0x03E3, "sheicoptic");
      list.add(0x20AA, "sheqel");
      list.add(0x20AA, "sheqelhebrew");
      list.add(0x05B0, "sheva");
      list.add(0x05B0, "sheva115");
      list.add(0x05B0, "sheva15");
      list.add(0x05B0, "sheva22");
      list.add(0x05B0, "sheva2e");
      list.add(0x05B0, "shevahebrew");
      list.add(0x05B0, "shevanarrowhebrew");
      list.add(0x05B0, "shevaquarterhebrew");
      list.add(0x05B0, "shevawidehebrew");
      list.add(0x04BB, "shhacyrillic");
      list.add(0x03ED, "shimacoptic");
      list.add(0x05E9, "shin");
      list.add(0xFB49, "shindagesh");
      list.add(0xFB49, "shindageshhebrew");
      list.add(0xFB2C, "shindageshshindot");
      list.add(0xFB2C, "shindageshshindothebrew");
      list.add(0xFB2D, "shindageshsindot");
      list.add(0xFB2D, "shindageshsindothebrew");
      list.add(0x05C1, "shindothebrew");
      list.add(0x05E9, "shinhebrew");
      list.add(0xFB2A, "shinshindot");
      list.add(0xFB2A, "shinshindothebrew");
      list.add(0xFB2B, "shinsindot");
      list.add(0xFB2B, "shinsindothebrew");
      list.add(0x0282, "shook");
      list.add(0x03C3, "sigma");
      list.add(0x03C2, "sigma1");
      list.add(0x03C2, "sigmafinal");
      list.add(0x03F2, "sigmalunatesymbolgreek");
      list.add(0x3057, "sihiragana");
      list.add(0x30B7, "sikatakana");
      list.add(0xFF7C, "sikatakanahalfwidth");
      list.add(0x05BD, "siluqhebrew");
      list.add(0x05BD, "siluqlefthebrew");
      list.add(0x223C, "similar");
      list.add(0x05C2, "sindothebrew");
      list.add(0x3274, "siosacirclekorean");
      list.add(0x3214, "siosaparenkorean");
      list.add(0x317E, "sioscieuckorean");
      list.add(0x3266, "sioscirclekorean");
      list.add(0x317A, "sioskiyeokkorean");
      list.add(0x3145, "sioskorean");
      list.add(0x317B, "siosnieunkorean");
      list.add(0x3206, "siosparenkorean");
      list.add(0x317D, "siospieupkorean");
      list.add(0x317C, "siostikeutkorean");
      list.add(0x0036, "six");
      list.add(0x0666, "sixarabic");
      list.add(0x09EC, "sixbengali");
      list.add(0x2465, "sixcircle");
      list.add(0x278F, "sixcircleinversesansserif");
      list.add(0x096C, "sixdeva");
      list.add(0x0AEC, "sixgujarati");
      list.add(0x0A6C, "sixgurmukhi");
      list.add(0x0666, "sixhackarabic");
      list.add(0x3026, "sixhangzhou");
      list.add(0x3225, "sixideographicparen");
      list.add(0x2086, "sixinferior");
      list.add(0xFF16, "sixmonospace");
      list.add(0xF736, "sixoldstyle");
      list.add(0x2479, "sixparen");
      list.add(0x248D, "sixperiod");
      list.add(0x06F6, "sixpersian");
      list.add(0x2175, "sixroman");
      list.add(0x2076, "sixsuperior");
      list.add(0x246F, "sixteencircle");
      list.add(0x09F9, "sixteencurrencydenominatorbengali");
      list.add(0x2483, "sixteenparen");
      list.add(0x2497, "sixteenperiod");
      list.add(0x0E56, "sixthai");
      list.add(0x002F, "slash");
      list.add(0xFF0F, "slashmonospace");
      list.add(0x017F, "slong");
      list.add(0x1E9B, "slongdotaccent");
      list.add(0x263A, "smileface");
      list.add(0xFF53, "smonospace");
      list.add(0x05C3, "sofpasuqhebrew");
      list.add(0x00AD, "softhyphen");
      list.add(0x044C, "softsigncyrillic");
      list.add(0x305D, "sohiragana");
      list.add(0x30BD, "sokatakana");
      list.add(0xFF7F, "sokatakanahalfwidth");
      list.add(0x0338, "soliduslongoverlaycmb");
      list.add(0x0337, "solidusshortoverlaycmb");
      list.add(0x0E29, "sorusithai");
      list.add(0x0E28, "sosalathai");
      list.add(0x0E0B, "sosothai");
      list.add(0x0E2A, "sosuathai");
      list.add(0x0020, "space");
      list.add(0x0020, "spacehackarabic");
      list.add(0x2660, "spade");
      list.add(0x2660, "spadesuitblack");
      list.add(0x2664, "spadesuitwhite");
      list.add(0x24AE, "sparen");
      list.add(0x033B, "squarebelowcmb");
      list.add(0x33C4, "squarecc");
      list.add(0x339D, "squarecm");
      list.add(0x25A9, "squarediagonalcrosshatchfill");
      list.add(0x25A4, "squarehorizontalfill");
      list.add(0x338F, "squarekg");
      list.add(0x339E, "squarekm");
      list.add(0x33CE, "squarekmcapital");
      list.add(0x33D1, "squareln");
      list.add(0x33D2, "squarelog");
      list.add(0x338E, "squaremg");
      list.add(0x33D5, "squaremil");
      list.add(0x339C, "squaremm");
      list.add(0x33A1, "squaremsquared");
      list.add(0x25A6, "squareorthogonalcrosshatchfill");
      list.add(0x25A7, "squareupperlefttolowerrightfill");
      list.add(0x25A8, "squareupperrighttolowerleftfill");
      list.add(0x25A5, "squareverticalfill");
      list.add(0x25A3, "squarewhitewithsmallblack");
      list.add(0x33DB, "srsquare");
      list.add(0x09B7, "ssabengali");
      list.add(0x0937, "ssadeva");
      list.add(0x0AB7, "ssagujarati");
      list.add(0x3149, "ssangcieuckorean");
      list.add(0x3185, "ssanghieuhkorean");
      list.add(0x3180, "ssangieungkorean");
      list.add(0x3132, "ssangkiyeokkorean");
      list.add(0x3165, "ssangnieunkorean");
      list.add(0x3143, "ssangpieupkorean");
      list.add(0x3146, "ssangsioskorean");
      list.add(0x3138, "ssangtikeutkorean");
      list.add(0xF6F2, "ssuperior");
      list.add(0x00A3, "sterling");
      list.add(0xFFE1, "sterlingmonospace");
      list.add(0x0336, "strokelongoverlaycmb");
      list.add(0x0335, "strokeshortoverlaycmb");
      list.add(0x2282, "subset");
      list.add(0x228A, "subsetnotequal");
      list.add(0x2286, "subsetorequal");
      list.add(0x227B, "succeeds");
      list.add(0x220B, "suchthat");
      list.add(0x3059, "suhiragana");
      list.add(0x30B9, "sukatakana");
      list.add(0xFF7D, "sukatakanahalfwidth");
      list.add(0x0652, "sukunarabic");
      list.add(0x2211, "summation");
      list.add(0x263C, "sun");
      list.add(0x2283, "superset");
      list.add(0x228B, "supersetnotequal");
      list.add(0x2287, "supersetorequal");
      list.add(0x33DC, "svsquare");
      list.add(0x337C, "syouwaerasquare");
      list.add(0x0074, "t");
      list.add(0x09A4, "tabengali");
      list.add(0x22A4, "tackdown");
      list.add(0x22A3, "tackleft");
      list.add(0x0924, "tadeva");
      list.add(0x0AA4, "tagujarati");
      list.add(0x0A24, "tagurmukhi");
      list.add(0x0637, "taharabic");
      list.add(0xFEC2, "tahfinalarabic");
      list.add(0xFEC3, "tahinitialarabic");
      list.add(0x305F, "tahiragana");
      list.add(0xFEC4, "tahmedialarabic");
      list.add(0x337D, "taisyouerasquare");
      list.add(0x30BF, "takatakana");
      list.add(0xFF80, "takatakanahalfwidth");
      list.add(0x0640, "tatweelarabic");
      list.add(0x03C4, "tau");
      list.add(0x05EA, "tav");
      list.add(0xFB4A, "tavdages");
      list.add(0xFB4A, "tavdagesh");
      list.add(0xFB4A, "tavdageshhebrew");
      list.add(0x05EA, "tavhebrew");
      list.add(0x0167, "tbar");
      list.add(0x310A, "tbopomofo");
      list.add(0x0165, "tcaron");
      list.add(0x02A8, "tccurl");
      list.add(0x0163, "tcedilla");
      list.add(0x0686, "tcheharabic");
      list.add(0xFB7B, "tchehfinalarabic");
      list.add(0xFB7C, "tchehinitialarabic");
      list.add(0xFB7D, "tchehmedialarabic");
      list.add(0x24E3, "tcircle");
      list.add(0x1E71, "tcircumflexbelow");
      list.add(0x0163, "tcommaaccent");
      list.add(0x1E97, "tdieresis");
      list.add(0x1E6B, "tdotaccent");
      list.add(0x1E6D, "tdotbelow");
      list.add(0x0442, "tecyrillic");
      list.add(0x04AD, "tedescendercyrillic");
      list.add(0x062A, "teharabic");
      list.add(0xFE96, "tehfinalarabic");
      list.add(0xFCA2, "tehhahinitialarabic");
      list.add(0xFC0C, "tehhahisolatedarabic");
      list.add(0xFE97, "tehinitialarabic");
      list.add(0x3066, "tehiragana");
      list.add(0xFCA1, "tehjeeminitialarabic");
      list.add(0xFC0B, "tehjeemisolatedarabic");
      list.add(0x0629, "tehmarbutaarabic");
      list.add(0xFE94, "tehmarbutafinalarabic");
      list.add(0xFE98, "tehmedialarabic");
      list.add(0xFCA4, "tehmeeminitialarabic");
      list.add(0xFC0E, "tehmeemisolatedarabic");
      list.add(0xFC73, "tehnoonfinalarabic");
      list.add(0x30C6, "tekatakana");
      list.add(0xFF83, "tekatakanahalfwidth");
      list.add(0x2121, "telephone");
      list.add(0x260E, "telephoneblack");
      list.add(0x05A0, "telishagedolahebrew");
      list.add(0x05A9, "telishaqetanahebrew");
      list.add(0x2469, "tencircle");
      list.add(0x3229, "tenideographicparen");
      list.add(0x247D, "tenparen");
      list.add(0x2491, "tenperiod");
      list.add(0x2179, "tenroman");
      list.add(0x02A7, "tesh");
      list.add(0x05D8, "tet");
      list.add(0xFB38, "tetdagesh");
      list.add(0xFB38, "tetdageshhebrew");
      list.add(0x05D8, "tethebrew");
      list.add(0x04B5, "tetsecyrillic");
      list.add(0x059B, "tevirhebrew");
      list.add(0x059B, "tevirlefthebrew");
      list.add(0x09A5, "thabengali");
      list.add(0x0925, "thadeva");
      list.add(0x0AA5, "thagujarati");
      list.add(0x0A25, "thagurmukhi");
      list.add(0x0630, "thalarabic");
      list.add(0xFEAC, "thalfinalarabic");
      list.add(0xF898, "thanthakhatlowleftthai");
      list.add(0xF897, "thanthakhatlowrightthai");
      list.add(0x0E4C, "thanthakhatthai");
      list.add(0xF896, "thanthakhatupperleftthai");
      list.add(0x062B, "theharabic");
      list.add(0xFE9A, "thehfinalarabic");
      list.add(0xFE9B, "thehinitialarabic");
      list.add(0xFE9C, "thehmedialarabic");
      list.add(0x2203, "thereexists");
      list.add(0x2234, "therefore");
      list.add(0x03B8, "theta");
      list.add(0x03D1, "theta1");
      list.add(0x03D1, "thetasymbolgreek");
      list.add(0x3279, "thieuthacirclekorean");
      list.add(0x3219, "thieuthaparenkorean");
      list.add(0x326B, "thieuthcirclekorean");
      list.add(0x314C, "thieuthkorean");
      list.add(0x320B, "thieuthparenkorean");
      list.add(0x246C, "thirteencircle");
      list.add(0x2480, "thirteenparen");
      list.add(0x2494, "thirteenperiod");
      list.add(0x0E11, "thonangmonthothai");
      list.add(0x01AD, "thook");
      list.add(0x0E12, "thophuthaothai");
      list.add(0x00FE, "thorn");
      list.add(0x0E17, "thothahanthai");
      list.add(0x0E10, "thothanthai");
      list.add(0x0E18, "thothongthai");
      list.add(0x0E16, "thothungthai");
      list.add(0x0482, "thousandcyrillic");
      list.add(0x066C, "thousandsseparatorarabic");
      list.add(0x066C, "thousandsseparatorpersian");
      list.add(0x0033, "three");
      list.add(0x0663, "threearabic");
      list.add(0x09E9, "threebengali");
      list.add(0x2462, "threecircle");
      list.add(0x278C, "threecircleinversesansserif");
      list.add(0x0969, "threedeva");
      list.add(0x215C, "threeeighths");
      list.add(0x0AE9, "threegujarati");
      list.add(0x0A69, "threegurmukhi");
      list.add(0x0663, "threehackarabic");
      list.add(0x3023, "threehangzhou");
      list.add(0x3222, "threeideographicparen");
      list.add(0x2083, "threeinferior");
      list.add(0xFF13, "threemonospace");
      list.add(0x09F6, "threenumeratorbengali");
      list.add(0xF733, "threeoldstyle");
      list.add(0x2476, "threeparen");
      list.add(0x248A, "threeperiod");
      list.add(0x06F3, "threepersian");
      list.add(0x00BE, "threequarters");
      list.add(0xF6DE, "threequartersemdash");
      list.add(0x2172, "threeroman");
      list.add(0x00B3, "threesuperior");
      list.add(0x0E53, "threethai");
      list.add(0x3394, "thzsquare");
      list.add(0x3061, "tihiragana");
      list.add(0x30C1, "tikatakana");
      list.add(0xFF81, "tikatakanahalfwidth");
      list.add(0x3270, "tikeutacirclekorean");
      list.add(0x3210, "tikeutaparenkorean");
      list.add(0x3262, "tikeutcirclekorean");
      list.add(0x3137, "tikeutkorean");
      list.add(0x3202, "tikeutparenkorean");
      list.add(0x02DC, "tilde");
      list.add(0x0330, "tildebelowcmb");
      list.add(0x0303, "tildecmb");
      list.add(0x0303, "tildecomb");
      list.add(0x0360, "tildedoublecmb");
      list.add(0x223C, "tildeoperator");
      list.add(0x0334, "tildeoverlaycmb");
      list.add(0x033E, "tildeverticalcmb");
      list.add(0x2297, "timescircle");
      list.add(0x0596, "tipehahebrew");
      list.add(0x0596, "tipehalefthebrew");
      list.add(0x0A70, "tippigurmukhi");
      list.add(0x0483, "titlocyrilliccmb");
      list.add(0x057F, "tiwnarmenian");
      list.add(0x1E6F, "tlinebelow");
      list.add(0xFF54, "tmonospace");
      list.add(0x0569, "toarmenian");
      list.add(0x3068, "tohiragana");
      list.add(0x30C8, "tokatakana");
      list.add(0xFF84, "tokatakanahalfwidth");
      list.add(0x02E5, "tonebarextrahighmod");
      list.add(0x02E9, "tonebarextralowmod");
      list.add(0x02E6, "tonebarhighmod");
      list.add(0x02E8, "tonebarlowmod");
      list.add(0x02E7, "tonebarmidmod");
      list.add(0x01BD, "tonefive");
      list.add(0x0185, "tonesix");
      list.add(0x01A8, "tonetwo");
      list.add(0x0384, "tonos");
      list.add(0x3327, "tonsquare");
      list.add(0x0E0F, "topatakthai");
      list.add(0x3014, "tortoiseshellbracketleft");
      list.add(0xFE5D, "tortoiseshellbracketleftsmall");
      list.add(0xFE39, "tortoiseshellbracketleftvertical");
      list.add(0x3015, "tortoiseshellbracketright");
      list.add(0xFE5E, "tortoiseshellbracketrightsmall");
      list.add(0xFE3A, "tortoiseshellbracketrightvertical");
      list.add(0x0E15, "totaothai");
      list.add(0x01AB, "tpalatalhook");
      list.add(0x24AF, "tparen");
      list.add(0x2122, "trademark");
      list.add(0xF8EA, "trademarksans");
      list.add(0xF6DB, "trademarkserif");
      list.add(0x0288, "tretroflexhook");
      list.add(0x25BC, "triagdn");
      list.add(0x25C4, "triaglf");
      list.add(0x25BA, "triagrt");
      list.add(0x25B2, "triagup");
      list.add(0x02A6, "ts");
      list.add(0x05E6, "tsadi");
      list.add(0xFB46, "tsadidagesh");
      list.add(0xFB46, "tsadidageshhebrew");
      list.add(0x05E6, "tsadihebrew");
      list.add(0x0446, "tsecyrillic");
      list.add(0x05B5, "tsere");
      list.add(0x05B5, "tsere12");
      list.add(0x05B5, "tsere1e");
      list.add(0x05B5, "tsere2b");
      list.add(0x05B5, "tserehebrew");
      list.add(0x05B5, "tserenarrowhebrew");
      list.add(0x05B5, "tserequarterhebrew");
      list.add(0x05B5, "tserewidehebrew");
      list.add(0x045B, "tshecyrillic");
      list.add(0xF6F3, "tsuperior");
      list.add(0x099F, "ttabengali");
      list.add(0x091F, "ttadeva");
      list.add(0x0A9F, "ttagujarati");
      list.add(0x0A1F, "ttagurmukhi");
      list.add(0x0679, "tteharabic");
      list.add(0xFB67, "ttehfinalarabic");
      list.add(0xFB68, "ttehinitialarabic");
      list.add(0xFB69, "ttehmedialarabic");
      list.add(0x09A0, "tthabengali");
      list.add(0x0920, "tthadeva");
      list.add(0x0AA0, "tthagujarati");
      list.add(0x0A20, "tthagurmukhi");
      list.add(0x0287, "tturned");
      list.add(0x3064, "tuhiragana");
      list.add(0x30C4, "tukatakana");
      list.add(0xFF82, "tukatakanahalfwidth");
      list.add(0x3063, "tusmallhiragana");
      list.add(0x30C3, "tusmallkatakana");
      list.add(0xFF6F, "tusmallkatakanahalfwidth");
      list.add(0x246B, "twelvecircle");
      list.add(0x247F, "twelveparen");
      list.add(0x2493, "twelveperiod");
      list.add(0x217B, "twelveroman");
      list.add(0x2473, "twentycircle");
      list.add(0x5344, "twentyhangzhou");
      list.add(0x2487, "twentyparen");
      list.add(0x249B, "twentyperiod");
      list.add(0x0032, "two");
      list.add(0x0662, "twoarabic");
      list.add(0x09E8, "twobengali");
      list.add(0x2461, "twocircle");
      list.add(0x278B, "twocircleinversesansserif");
      list.add(0x0968, "twodeva");
      list.add(0x2025, "twodotenleader");
      list.add(0x2025, "twodotleader");
      list.add(0xFE30, "twodotleadervertical");
      list.add(0x0AE8, "twogujarati");
      list.add(0x0A68, "twogurmukhi");
      list.add(0x0662, "twohackarabic");
      list.add(0x3022, "twohangzhou");
      list.add(0x3221, "twoideographicparen");
      list.add(0x2082, "twoinferior");
      list.add(0xFF12, "twomonospace");
      list.add(0x09F5, "twonumeratorbengali");
      list.add(0xF732, "twooldstyle");
      list.add(0x2475, "twoparen");
      list.add(0x2489, "twoperiod");
      list.add(0x06F2, "twopersian");
      list.add(0x2171, "tworoman");
      list.add(0x01BB, "twostroke");
      list.add(0x00B2, "twosuperior");
      list.add(0x0E52, "twothai");
      list.add(0x2154, "twothirds");
      list.add(0x0075, "u");
      list.add(0x00FA, "uacute");
      list.add(0x0289, "ubar");
      list.add(0x0989, "ubengali");
      list.add(0x3128, "ubopomofo");
      list.add(0x016D, "ubreve");
      list.add(0x01D4, "ucaron");
      list.add(0x24E4, "ucircle");
      list.add(0x00FB, "ucircumflex");
      list.add(0x1E77, "ucircumflexbelow");
      list.add(0x0443, "ucyrillic");
      list.add(0x0951, "udattadeva");
      list.add(0x0171, "udblacute");
      list.add(0x0215, "udblgrave");
      list.add(0x0909, "udeva");
      list.add(0x00FC, "udieresis");
      list.add(0x01D8, "udieresisacute");
      list.add(0x1E73, "udieresisbelow");
      list.add(0x01DA, "udieresiscaron");
      list.add(0x04F1, "udieresiscyrillic");
      list.add(0x01DC, "udieresisgrave");
      list.add(0x01D6, "udieresismacron");
      list.add(0x1EE5, "udotbelow");
      list.add(0x00F9, "ugrave");
      list.add(0x0A89, "ugujarati");
      list.add(0x0A09, "ugurmukhi");
      list.add(0x3046, "uhiragana");
      list.add(0x1EE7, "uhookabove");
      list.add(0x01B0, "uhorn");
      list.add(0x1EE9, "uhornacute");
      list.add(0x1EF1, "uhorndotbelow");
      list.add(0x1EEB, "uhorngrave");
      list.add(0x1EED, "uhornhookabove");
      list.add(0x1EEF, "uhorntilde");
      list.add(0x0171, "uhungarumlaut");
      list.add(0x04F3, "uhungarumlautcyrillic");
      list.add(0x0217, "uinvertedbreve");
      list.add(0x30A6, "ukatakana");
      list.add(0xFF73, "ukatakanahalfwidth");
      list.add(0x0479, "ukcyrillic");
      list.add(0x315C, "ukorean");
      list.add(0x016B, "umacron");
      list.add(0x04EF, "umacroncyrillic");
      list.add(0x1E7B, "umacrondieresis");
      list.add(0x0A41, "umatragurmukhi");
      list.add(0xFF55, "umonospace");
      list.add(0x005F, "underscore");
      list.add(0x2017, "underscoredbl");
      list.add(0xFF3F, "underscoremonospace");
      list.add(0xFE33, "underscorevertical");
      list.add(0xFE4F, "underscorewavy");
      list.add(0x222A, "union");
      list.add(0x2200, "universal");
      list.add(0x0173, "uogonek");
      list.add(0x24B0, "uparen");
      list.add(0x2580, "upblock");
      list.add(0x05C4, "upperdothebrew");
      list.add(0x03C5, "upsilon");
      list.add(0x03CB, "upsilondieresis");
      list.add(0x03B0, "upsilondieresistonos");
      list.add(0x028A, "upsilonlatin");
      list.add(0x03CD, "upsilontonos");
      list.add(0x031D, "uptackbelowcmb");
      list.add(0x02D4, "uptackmod");
      list.add(0x0A73, "uragurmukhi");
      list.add(0x016F, "uring");
      list.add(0x045E, "ushortcyrillic");
      list.add(0x3045, "usmallhiragana");
      list.add(0x30A5, "usmallkatakana");
      list.add(0xFF69, "usmallkatakanahalfwidth");
      list.add(0x04AF, "ustraightcyrillic");
      list.add(0x04B1, "ustraightstrokecyrillic");
      list.add(0x0169, "utilde");
      list.add(0x1E79, "utildeacute");
      list.add(0x1E75, "utildebelow");
      list.add(0x098A, "uubengali");
      list.add(0x090A, "uudeva");
      list.add(0x0A8A, "uugujarati");
      list.add(0x0A0A, "uugurmukhi");
      list.add(0x0A42, "uumatragurmukhi");
      list.add(0x09C2, "uuvowelsignbengali");
      list.add(0x0942, "uuvowelsigndeva");
      list.add(0x0AC2, "uuvowelsigngujarati");
      list.add(0x09C1, "uvowelsignbengali");
      list.add(0x0941, "uvowelsigndeva");
      list.add(0x0AC1, "uvowelsigngujarati");
      list.add(0x0076, "v");
      list.add(0x0935, "vadeva");
      list.add(0x0AB5, "vagujarati");
      list.add(0x0A35, "vagurmukhi");
      list.add(0x30F7, "vakatakana");
      list.add(0x05D5, "vav");
      list.add(0xFB35, "vavdagesh");
      list.add(0xFB35, "vavdagesh65");
      list.add(0xFB35, "vavdageshhebrew");
      list.add(0x05D5, "vavhebrew");
      list.add(0xFB4B, "vavholam");
      list.add(0xFB4B, "vavholamhebrew");
      list.add(0x05F0, "vavvavhebrew");
      list.add(0x05F1, "vavyodhebrew");
      list.add(0x24E5, "vcircle");
      list.add(0x1E7F, "vdotbelow");
      list.add(0x0432, "vecyrillic");
      list.add(0x06A4, "veharabic");
      list.add(0xFB6B, "vehfinalarabic");
      list.add(0xFB6C, "vehinitialarabic");
      list.add(0xFB6D, "vehmedialarabic");
      list.add(0x30F9, "vekatakana");
      list.add(0x2640, "venus");
      list.add(0x007C, "verticalbar");
      list.add(0x030D, "verticallineabovecmb");
      list.add(0x0329, "verticallinebelowcmb");
      list.add(0x02CC, "verticallinelowmod");
      list.add(0x02C8, "verticallinemod");
      list.add(0x057E, "vewarmenian");
      list.add(0x028B, "vhook");
      list.add(0x30F8, "vikatakana");
      list.add(0x09CD, "viramabengali");
      list.add(0x094D, "viramadeva");
      list.add(0x0ACD, "viramagujarati");
      list.add(0x0983, "visargabengali");
      list.add(0x0903, "visargadeva");
      list.add(0x0A83, "visargagujarati");
      list.add(0xFF56, "vmonospace");
      list.add(0x0578, "voarmenian");
      list.add(0x309E, "voicediterationhiragana");
      list.add(0x30FE, "voicediterationkatakana");
      list.add(0x309B, "voicedmarkkana");
      list.add(0xFF9E, "voicedmarkkanahalfwidth");
      list.add(0x30FA, "vokatakana");
      list.add(0x24B1, "vparen");
      list.add(0x1E7D, "vtilde");
      list.add(0x028C, "vturned");
      list.add(0x3094, "vuhiragana");
      list.add(0x30F4, "vukatakana");
      list.add(0x0077, "w");
      list.add(0x1E83, "wacute");
      list.add(0x3159, "waekorean");
      list.add(0x308F, "wahiragana");
      list.add(0x30EF, "wakatakana");
      list.add(0xFF9C, "wakatakanahalfwidth");
      list.add(0x3158, "wakorean");
      list.add(0x308E, "wasmallhiragana");
      list.add(0x30EE, "wasmallkatakana");
      list.add(0x3357, "wattosquare");
      list.add(0x301C, "wavedash");
      list.add(0xFE34, "wavyunderscorevertical");
      list.add(0x0648, "wawarabic");
      list.add(0xFEEE, "wawfinalarabic");
      list.add(0x0624, "wawhamzaabovearabic");
      list.add(0xFE86, "wawhamzaabovefinalarabic");
      list.add(0x33DD, "wbsquare");
      list.add(0x24E6, "wcircle");
      list.add(0x0175, "wcircumflex");
      list.add(0x1E85, "wdieresis");
      list.add(0x1E87, "wdotaccent");
      list.add(0x1E89, "wdotbelow");
      list.add(0x3091, "wehiragana");
      list.add(0x2118, "weierstrass");
      list.add(0x30F1, "wekatakana");
      list.add(0x315E, "wekorean");
      list.add(0x315D, "weokorean");
      list.add(0x1E81, "wgrave");
      list.add(0x25E6, "whitebullet");
      list.add(0x25CB, "whitecircle");
      list.add(0x25D9, "whitecircleinverse");
      list.add(0x300E, "whitecornerbracketleft");
      list.add(0xFE43, "whitecornerbracketleftvertical");
      list.add(0x300F, "whitecornerbracketright");
      list.add(0xFE44, "whitecornerbracketrightvertical");
      list.add(0x25C7, "whitediamond");
      list.add(0x25C8, "whitediamondcontainingblacksmalldiamond");
      list.add(0x25BF, "whitedownpointingsmalltriangle");
      list.add(0x25BD, "whitedownpointingtriangle");
      list.add(0x25C3, "whiteleftpointingsmalltriangle");
      list.add(0x25C1, "whiteleftpointingtriangle");
      list.add(0x3016, "whitelenticularbracketleft");
      list.add(0x3017, "whitelenticularbracketright");
      list.add(0x25B9, "whiterightpointingsmalltriangle");
      list.add(0x25B7, "whiterightpointingtriangle");
      list.add(0x25AB, "whitesmallsquare");
      list.add(0x263A, "whitesmilingface");
      list.add(0x25A1, "whitesquare");
      list.add(0x2606, "whitestar");
      list.add(0x260F, "whitetelephone");
      list.add(0x3018, "whitetortoiseshellbracketleft");
      list.add(0x3019, "whitetortoiseshellbracketright");
      list.add(0x25B5, "whiteuppointingsmalltriangle");
      list.add(0x25B3, "whiteuppointingtriangle");
      list.add(0x3090, "wihiragana");
      list.add(0x30F0, "wikatakana");
      list.add(0x315F, "wikorean");
      list.add(0xFF57, "wmonospace");
      list.add(0x3092, "wohiragana");
      list.add(0x30F2, "wokatakana");
      list.add(0xFF66, "wokatakanahalfwidth");
      list.add(0x20A9, "won");
      list.add(0xFFE6, "wonmonospace");
      list.add(0x0E27, "wowaenthai");
      list.add(0x24B2, "wparen");
      list.add(0x1E98, "wring");
      list.add(0x02B7, "wsuperior");
      list.add(0x028D, "wturned");
      list.add(0x01BF, "wynn");
      list.add(0x0078, "x");
      list.add(0x033D, "xabovecmb");
      list.add(0x3112, "xbopomofo");
      list.add(0x24E7, "xcircle");
      list.add(0x1E8D, "xdieresis");
      list.add(0x1E8B, "xdotaccent");
      list.add(0x056D, "xeharmenian");
      list.add(0x03BE, "xi");
      list.add(0xFF58, "xmonospace");
      list.add(0x24B3, "xparen");
      list.add(0x02E3, "xsuperior");
      list.add(0x0079, "y");
      list.add(0x334E, "yaadosquare");
      list.add(0x09AF, "yabengali");
      list.add(0x00FD, "yacute");
      list.add(0x092F, "yadeva");
      list.add(0x3152, "yaekorean");
      list.add(0x0AAF, "yagujarati");
      list.add(0x0A2F, "yagurmukhi");
      list.add(0x3084, "yahiragana");
      list.add(0x30E4, "yakatakana");
      list.add(0xFF94, "yakatakanahalfwidth");
      list.add(0x3151, "yakorean");
      list.add(0x0E4E, "yamakkanthai");
      list.add(0x3083, "yasmallhiragana");
      list.add(0x30E3, "yasmallkatakana");
      list.add(0xFF6C, "yasmallkatakanahalfwidth");
      list.add(0x0463, "yatcyrillic");
      list.add(0x24E8, "ycircle");
      list.add(0x0177, "ycircumflex");
      list.add(0x00FF, "ydieresis");
      list.add(0x1E8F, "ydotaccent");
      list.add(0x1EF5, "ydotbelow");
      list.add(0x064A, "yeharabic");
      list.add(0x06D2, "yehbarreearabic");
      list.add(0xFBAF, "yehbarreefinalarabic");
      list.add(0xFEF2, "yehfinalarabic");
      list.add(0x0626, "yehhamzaabovearabic");
      list.add(0xFE8A, "yehhamzaabovefinalarabic");
      list.add(0xFE8B, "yehhamzaaboveinitialarabic");
      list.add(0xFE8C, "yehhamzaabovemedialarabic");
      list.add(0xFEF3, "yehinitialarabic");
      list.add(0xFEF4, "yehmedialarabic");
      list.add(0xFCDD, "yehmeeminitialarabic");
      list.add(0xFC58, "yehmeemisolatedarabic");
      list.add(0xFC94, "yehnoonfinalarabic");
      list.add(0x06D1, "yehthreedotsbelowarabic");
      list.add(0x3156, "yekorean");
      list.add(0x00A5, "yen");
      list.add(0xFFE5, "yenmonospace");
      list.add(0x3155, "yeokorean");
      list.add(0x3186, "yeorinhieuhkorean");
      list.add(0x05AA, "yerahbenyomohebrew");
      list.add(0x05AA, "yerahbenyomolefthebrew");
      list.add(0x044B, "yericyrillic");
      list.add(0x04F9, "yerudieresiscyrillic");
      list.add(0x3181, "yesieungkorean");
      list.add(0x3183, "yesieungpansioskorean");
      list.add(0x3182, "yesieungsioskorean");
      list.add(0x059A, "yetivhebrew");
      list.add(0x1EF3, "ygrave");
      list.add(0x01B4, "yhook");
      list.add(0x1EF7, "yhookabove");
      list.add(0x0575, "yiarmenian");
      list.add(0x0457, "yicyrillic");
      list.add(0x3162, "yikorean");
      list.add(0x262F, "yinyang");
      list.add(0x0582, "yiwnarmenian");
      list.add(0xFF59, "ymonospace");
      list.add(0x05D9, "yod");
      list.add(0xFB39, "yoddagesh");
      list.add(0xFB39, "yoddageshhebrew");
      list.add(0x05D9, "yodhebrew");
      list.add(0x05F2, "yodyodhebrew");
      list.add(0xFB1F, "yodyodpatahhebrew");
      list.add(0x3088, "yohiragana");
      list.add(0x3189, "yoikorean");
      list.add(0x30E8, "yokatakana");
      list.add(0xFF96, "yokatakanahalfwidth");
      list.add(0x315B, "yokorean");
      list.add(0x3087, "yosmallhiragana");
      list.add(0x30E7, "yosmallkatakana");
      list.add(0xFF6E, "yosmallkatakanahalfwidth");
      list.add(0x03F3, "yotgreek");
      list.add(0x3188, "yoyaekorean");
      list.add(0x3187, "yoyakorean");
      list.add(0x0E22, "yoyakthai");
      list.add(0x0E0D, "yoyingthai");
      list.add(0x24B4, "yparen");
      list.add(0x037A, "ypogegrammeni");
      list.add(0x0345, "ypogegrammenigreekcmb");
      list.add(0x01A6, "yr");
      list.add(0x1E99, "yring");
      list.add(0x02B8, "ysuperior");
      list.add(0x1EF9, "ytilde");
      list.add(0x028E, "yturned");
      list.add(0x3086, "yuhiragana");
      list.add(0x318C, "yuikorean");
      list.add(0x30E6, "yukatakana");
      list.add(0xFF95, "yukatakanahalfwidth");
      list.add(0x3160, "yukorean");
      list.add(0x046B, "yusbigcyrillic");
      list.add(0x046D, "yusbigiotifiedcyrillic");
      list.add(0x0467, "yuslittlecyrillic");
      list.add(0x0469, "yuslittleiotifiedcyrillic");
      list.add(0x3085, "yusmallhiragana");
      list.add(0x30E5, "yusmallkatakana");
      list.add(0xFF6D, "yusmallkatakanahalfwidth");
      list.add(0x318B, "yuyekorean");
      list.add(0x318A, "yuyeokorean");
      list.add(0x09DF, "yyabengali");
      list.add(0x095F, "yyadeva");
      list.add(0x007A, "z");
      list.add(0x0566, "zaarmenian");
      list.add(0x017A, "zacute");
      list.add(0x095B, "zadeva");
      list.add(0x0A5B, "zagurmukhi");
      list.add(0x0638, "zaharabic");
      list.add(0xFEC6, "zahfinalarabic");
      list.add(0xFEC7, "zahinitialarabic");
      list.add(0x3056, "zahiragana");
      list.add(0xFEC8, "zahmedialarabic");
      list.add(0x0632, "zainarabic");
      list.add(0xFEB0, "zainfinalarabic");
      list.add(0x30B6, "zakatakana");
      list.add(0x0595, "zaqefgadolhebrew");
      list.add(0x0594, "zaqefqatanhebrew");
      list.add(0x0598, "zarqahebrew");
      list.add(0x05D6, "zayin");
      list.add(0xFB36, "zayindagesh");
      list.add(0xFB36, "zayindageshhebrew");
      list.add(0x05D6, "zayinhebrew");
      list.add(0x3117, "zbopomofo");
      list.add(0x017E, "zcaron");
      list.add(0x24E9, "zcircle");
      list.add(0x1E91, "zcircumflex");
      list.add(0x0291, "zcurl");
      list.add(0x017C, "zdot");
      list.add(0x017C, "zdotaccent");
      list.add(0x1E93, "zdotbelow");
      list.add(0x0437, "zecyrillic");
      list.add(0x0499, "zedescendercyrillic");
      list.add(0x04DF, "zedieresiscyrillic");
      list.add(0x305C, "zehiragana");
      list.add(0x30BC, "zekatakana");
      list.add(0x0030, "zero");
      list.add(0x0660, "zeroarabic");
      list.add(0x09E6, "zerobengali");
      list.add(0x0966, "zerodeva");
      list.add(0x0AE6, "zerogujarati");
      list.add(0x0A66, "zerogurmukhi");
      list.add(0x0660, "zerohackarabic");
      list.add(0x2080, "zeroinferior");
      list.add(0xFF10, "zeromonospace");
      list.add(0xF730, "zerooldstyle");
      list.add(0x06F0, "zeropersian");
      list.add(0x2070, "zerosuperior");
      list.add(0x0E50, "zerothai");
      list.add(0xFEFF, "zerowidthjoiner");
      list.add(0x200C, "zerowidthnonjoiner");
      list.add(0x200B, "zerowidthspace");
      list.add(0x03B6, "zeta");
      list.add(0x3113, "zhbopomofo");
      list.add(0x056A, "zhearmenian");
      list.add(0x04C2, "zhebrevecyrillic");
      list.add(0x0436, "zhecyrillic");
      list.add(0x0497, "zhedescendercyrillic");
      list.add(0x04DD, "zhedieresiscyrillic");
      list.add(0x3058, "zihiragana");
      list.add(0x30B8, "zikatakana");
      list.add(0x05AE, "zinorhebrew");
      list.add(0x1E95, "zlinebelow");
      list.add(0xFF5A, "zmonospace");
      list.add(0x305E, "zohiragana");
      list.add(0x30BE, "zokatakana");
      list.add(0x24B5, "zparen");
      list.add(0x0290, "zretroflexhook");
      list.add(0x01B6, "zstroke");
      list.add(0x305A, "zuhiragana");
      list.add(0x30BA, "zukatakana");
   }
}
